@@ -24,12 +24,16 @@ import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.ObjRelationship;
 import org.apache.velocity.VelocityContext;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 
 public class ClientSuperClassGenerationTest extends ClassGenerationCase {
 
+    Logger logger = LoggerFactory.getLogger(ClientSuperClassGenerationTest.class);
+
     @Test
     public void testNotContainsPropertyImport() throws Exception {
         ObjEntity objEntity = new ObjEntity("TEST1");
@@ -38,20 +42,27 @@ public class ClientSuperClassGenerationTest extends ClassGenerationCase {
         context.put(Artifact.OBJECT_KEY, objEntity);
 
         String res = renderTemplate(ClientClassGenerationAction.SUPERCLASS_TEMPLATE, context);
-        assertFalse(res.contains("org.apache.cayenne.exp.Property"));
+        assertFalse(res.contains("org.apache.cayenne.exp.property."));
     }
 
     @Test
     public void testContainsPropertyImportForAttributes() throws Exception {
         ObjEntity objEntity = new ObjEntity("TEST1");
         ObjAttribute attr = new ObjAttribute("attr");
+        attr.setType("int");
         objEntity.addAttribute(attr);
 
         VelocityContext context = new VelocityContext();
+        ImportUtils importUtils = new ImportUtils();
         context.put(Artifact.OBJECT_KEY, objEntity);
+        context.put(Artifact.IMPORT_UTILS_KEY, importUtils);
+        context.put(Artifact.STRING_UTILS_KEY, StringUtils.getInstance());
+        context.put(Artifact.PROPERTY_UTILS_KEY,
+                getInjector().getInstance(ToolsUtilsFactory.class)
+                        .createPropertyUtils(logger, importUtils));
 
         String res = renderTemplate(ClientClassGenerationAction.SUPERCLASS_TEMPLATE, context);
-        assertTrue(res.contains("org.apache.cayenne.exp.Property"));
+        assertTrue(res.contains("org.apache.cayenne.exp.property.NumericProperty"));
     }
 
     @Test
@@ -61,26 +72,38 @@ public class ClientSuperClassGenerationTest extends ClassGenerationCase {
         objEntity.addRelationship(rel);
 
         VelocityContext context = new VelocityContext();
+        ImportUtils importUtils = new ImportUtils();
         context.put(Artifact.OBJECT_KEY, objEntity);
+        context.put(Artifact.IMPORT_UTILS_KEY, importUtils);
+        context.put(Artifact.STRING_UTILS_KEY, StringUtils.getInstance());
+        context.put(Artifact.PROPERTY_UTILS_KEY, new PropertyUtils(importUtils));
 
         String res = renderTemplate(ClientClassGenerationAction.SUPERCLASS_TEMPLATE, context);
-        assertTrue(res.contains("org.apache.cayenne.exp.Property"));
+        assertTrue(res.contains("org.apache.cayenne.exp.property.EntityProperty"));
     }
 
     @Test
     public void testContainsPropertyImport() throws Exception {
         ObjEntity objEntity = new ObjEntity("TEST1");
         ObjAttribute attr = new ObjAttribute("attr");
+        attr.setType("int");
         ObjRelationship rel = new ObjRelationship("rel");
 
         objEntity.addAttribute(attr);
         objEntity.addRelationship(rel);
 
         VelocityContext context = new VelocityContext();
+        ImportUtils importUtils = new ImportUtils();
         context.put(Artifact.OBJECT_KEY, objEntity);
+        context.put(Artifact.IMPORT_UTILS_KEY, importUtils);
+        context.put(Artifact.STRING_UTILS_KEY, StringUtils.getInstance());
+        context.put(Artifact.PROPERTY_UTILS_KEY,
+                getInjector().getInstance(ToolsUtilsFactory.class)
+                        .createPropertyUtils(logger, importUtils));
 
         String res = renderTemplate(ClientClassGenerationAction.SUPERCLASS_TEMPLATE, context);
-        assertTrue(res.contains("org.apache.cayenne.exp.Property"));
+        assertTrue(res.contains("org.apache.cayenne.exp.property.NumericProperty"));
+        assertTrue(res.contains("org.apache.cayenne.exp.property.EntityProperty"));
     }
 
 }
