@@ -19,8 +19,7 @@
 package org.apache.cayenne;
 
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.exp.ExpressionFactory;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.mt.ClientMtTable1;
@@ -84,8 +83,7 @@ public class CayenneContextInheritanceIT extends ClientCase {
         tMtTable1.insert(2, "sub1", "zzz", "sa1");
         tMtTable1.insert(3, "1111", "aaa", null);
 
-        SelectQuery query = new SelectQuery(ClientMtTable1Subclass1.class);
-        List<ClientMtTable1Subclass1> objects = context.performQuery(query);
+        List<ClientMtTable1Subclass1> objects = ObjectSelect.query(ClientMtTable1Subclass1.class).select(context);
 
         assertEquals(1, objects.size());
         assertEquals("sa1", objects.get(0).getSubclass1Attribute1());
@@ -98,22 +96,18 @@ public class CayenneContextInheritanceIT extends ClientCase {
         tMtTable1.insert(2, "sub1", "zzz", "sa1");
         tMtTable1.insert(3, "z", "aaa", null);
 
-        SelectQuery query = new SelectQuery(ClientMtTable1.class);
-        List<ClientMtTable1> objects = context.performQuery(query);
+        List<ClientMtTable1> objects = ObjectSelect.query(ClientMtTable1.class).select(context);
 
         assertEquals(3, objects.size());
 
         int checkedFields = 0;
-        for (int i = 0; i < objects.size(); i++) {
-            Integer id = (Integer) objects.get(i).getObjectId().getIdSnapshot().get(
-                    "TABLE1_ID");
+        for (ClientMtTable1 object : objects) {
+            Integer id = (Integer) object.getObjectId().getIdSnapshot().get("TABLE1_ID");
             if (id == 1) {
-                assertEquals("a", objects.get(i).getGlobalAttribute1());
+                assertEquals("a", object.getGlobalAttribute1());
                 checkedFields++;
-            }
-            else if (id == 2) {
-                assertEquals("sa1", ((ClientMtTable1Subclass1) objects.get(i))
-                        .getSubclass1Attribute1());
+            } else if (id == 2) {
+                assertEquals("sa1", ((ClientMtTable1Subclass1) object).getSubclass1Attribute1());
                 checkedFields++;
             }
 
@@ -128,25 +122,20 @@ public class CayenneContextInheritanceIT extends ClientCase {
         tMtTable1.insert(2, "sub1", "XXA", "sa1");
         tMtTable1.insert(3, "z", "MM", null);
 
-        SelectQuery query = new SelectQuery(ClientMtTable1.class);
-        query.andQualifier(ExpressionFactory.likeExp(
-                ClientMtTable1.SERVER_ATTRIBUTE1_PROPERTY,
-                "X%"));
-        List<ClientMtTable1> objects = context.performQuery(query);
+        List<ClientMtTable1> objects = ObjectSelect.query(ClientMtTable1.class)
+                .where(ClientMtTable1.SERVER_ATTRIBUTE1.like("X%"))
+                .select(context);
 
         assertEquals(2, objects.size());
 
         int checkedFields = 0;
-        for (int i = 0; i < objects.size(); i++) {
-            Integer id = (Integer) objects.get(i).getObjectId().getIdSnapshot().get(
-                    "TABLE1_ID");
+        for (ClientMtTable1 object : objects) {
+            Integer id = (Integer) object.getObjectId().getIdSnapshot().get("TABLE1_ID");
             if (id == 1) {
-                assertEquals("a", objects.get(i).getGlobalAttribute1());
+                assertEquals("a", object.getGlobalAttribute1());
                 checkedFields++;
-            }
-            else if (id == 2) {
-                assertEquals("sa1", ((ClientMtTable1Subclass1) objects.get(i))
-                        .getSubclass1Attribute1());
+            } else if (id == 2) {
+                assertEquals("sa1", ((ClientMtTable1Subclass1) object).getSubclass1Attribute1());
                 checkedFields++;
             }
 
