@@ -19,11 +19,16 @@
 
 package org.apache.cayenne;
 
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.List;
+
 import org.apache.cayenne.configuration.rop.client.ClientRuntime;
 import org.apache.cayenne.di.Inject;
+import org.apache.cayenne.graph.ArcId;
 import org.apache.cayenne.graph.GraphChangeHandler;
 import org.apache.cayenne.graph.GraphDiff;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.remote.RemoteCayenneCase;
 import org.apache.cayenne.remote.service.LocalConnection;
 import org.apache.cayenne.testdo.toone.ClientTooneDep;
@@ -35,10 +40,6 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
-import java.util.Arrays;
-import java.util.Collection;
-import java.util.List;
-
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertSame;
@@ -81,59 +82,7 @@ public class NestedCayenneContextTooneIT extends RemoteCayenneCase {
 
         ObjectContext child = runtime.newContext(clientContext);
 
-        SelectQuery<ClientTooneMaster> query = new SelectQuery<ClientTooneMaster>(
-                ClientTooneMaster.class);
-        List<ClientTooneMaster> objects = child.select(query);
-
-        assertEquals(1, objects.size());
-
-        ClientTooneMaster childDeleted = (ClientTooneMaster) objects.get(0);
-
-        child.deleteObjects(childDeleted);
-
-        child.commitChangesToParent();
-
-        ClientTooneMaster parentDeleted = (ClientTooneMaster) clientContext
-                .getGraphManager().getNode(childDeleted.getObjectId());
-
-        assertNotNull(parentDeleted);
-        assertEquals(PersistenceState.DELETED,
-                parentDeleted.getPersistenceState());
-
-        clientContext.commitChanges();
-
-        SelectQuery<ClientTooneMaster> query2 = new SelectQuery<ClientTooneMaster>(
-                ClientTooneMaster.class);
-        List<ClientTooneMaster> objects2 = child.select(query2);
-
-        assertEquals(0, objects2.size());
-
-    }
-
-    @Test
-    public void testCAY1636_2() throws Exception {
-
-        ClientTooneMaster A = clientContext
-                .newObject(ClientTooneMaster.class);
-        clientContext.commitChanges();
-
-        ClientTooneDep B = clientContext.newObject(ClientTooneDep.class);
-        A.setToDependent(B);
-        clientContext.commitChanges();
-
-        ObjectContext child = runtime.newContext(clientContext);
-
-        SelectQuery<ClientTooneDep> queryB = new SelectQuery<ClientTooneDep>(
-                ClientTooneDep.class);
-        List<?> objectsB = child.performQuery(queryB);
-
-        assertEquals(1, objectsB.size());
-
-        ClientTooneDep childBDeleted = (ClientTooneDep) objectsB.get(0);
-        child.deleteObjects(childBDeleted);
-
-        SelectQuery<ClientTooneMaster> query = new SelectQuery<ClientTooneMaster>(
-                ClientTooneMaster.class);
+        ObjectSelect<ClientTooneMaster> query = ObjectSelect.query(ClientTooneMaster.class);
         List<ClientTooneMaster> objects = child.select(query);
 
         assertEquals(1, objects.size());
@@ -153,8 +102,55 @@ public class NestedCayenneContextTooneIT extends RemoteCayenneCase {
 
         clientContext.commitChanges();
 
-        SelectQuery<ClientTooneMaster> query2 = new SelectQuery<ClientTooneMaster>(
-                ClientTooneMaster.class);
+        ObjectSelect<ClientTooneMaster> query2 = ObjectSelect.query(ClientTooneMaster.class);
+        List<ClientTooneMaster> objects2 = child.select(query2);
+
+        assertEquals(0, objects2.size());
+
+    }
+
+    @Test
+    public void testCAY1636_2() throws Exception {
+
+        ClientTooneMaster A = clientContext
+                .newObject(ClientTooneMaster.class);
+        clientContext.commitChanges();
+
+        ClientTooneDep B = clientContext.newObject(ClientTooneDep.class);
+        A.setToDependent(B);
+        clientContext.commitChanges();
+
+        ObjectContext child = runtime.newContext(clientContext);
+
+        ObjectSelect<ClientTooneDep> queryB = ObjectSelect.query(ClientTooneDep.class);
+        List<?> objectsB = child.performQuery(queryB);
+
+        assertEquals(1, objectsB.size());
+
+        ClientTooneDep childBDeleted = (ClientTooneDep) objectsB.get(0);
+        child.deleteObjects(childBDeleted);
+
+        ObjectSelect<ClientTooneMaster> query = ObjectSelect.query(ClientTooneMaster.class);
+        List<ClientTooneMaster> objects = child.select(query);
+
+        assertEquals(1, objects.size());
+
+        ClientTooneMaster childDeleted = objects.get(0);
+
+        child.deleteObjects(childDeleted);
+
+        child.commitChangesToParent();
+
+        ClientTooneMaster parentDeleted = (ClientTooneMaster) clientContext
+                .getGraphManager().getNode(childDeleted.getObjectId());
+
+        assertNotNull(parentDeleted);
+        assertEquals(PersistenceState.DELETED,
+                parentDeleted.getPersistenceState());
+
+        clientContext.commitChanges();
+
+        ObjectSelect<ClientTooneMaster> query2 = ObjectSelect.query(ClientTooneMaster.class);
         List<ClientTooneMaster> objects2 = child.select(query2);
 
         assertEquals(0, objects2.size());
@@ -190,27 +186,30 @@ public class NestedCayenneContextTooneIT extends RemoteCayenneCase {
 
         diffs.apply(new GraphChangeHandler() {
 
-            public void arcCreated(Object nodeId, Object targetNodeId,
-                                   Object arcId) {
+            @Override
+            public void arcCreated(Object nodeId, Object targetNodeId, ArcId arcId) {
                 arcDiffs[0]++;
             }
 
-            public void arcDeleted(Object nodeId, Object targetNodeId,
-                                   Object arcId) {
+            @Override
+            public void arcDeleted(Object nodeId, Object targetNodeId, ArcId arcId) {
                 arcDiffs[0]--;
             }
 
+            @Override
             public void nodeCreated(Object nodeId) {
                 newNodes[0]++;
             }
 
+            @Override
             public void nodeIdChanged(Object nodeId, Object newId) {
             }
 
-            public void nodePropertyChanged(Object nodeId, String property,
-                                            Object oldValue, Object newValue) {
+            @Override
+            public void nodePropertyChanged(Object nodeId, String property, Object oldValue, Object newValue) {
             }
 
+            @Override
             public void nodeRemoved(Object nodeId) {
                 newNodes[0]--;
             }
