@@ -24,6 +24,7 @@ import org.apache.cayenne.ObjectId;
 import org.apache.cayenne.access.ClientServerChannel;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.event.MockEventManager;
+import org.apache.cayenne.graph.ArcId;
 import org.apache.cayenne.graph.GraphChangeHandler;
 import org.apache.cayenne.graph.GraphDiff;
 import org.apache.cayenne.map.LifecycleEvent;
@@ -103,7 +104,7 @@ public class ClientChannelServerDiffsIT extends ClientCase {
     @Test
     public void testReturnDiffInPrePersist() {
 
-        final List<GenericDiff> diffs = new ArrayList<GenericDiff>();
+        final List<GenericDiff> diffs = new ArrayList<>();
         final NoopGraphChangeHandler diffReader = new NoopGraphChangeHandler() {
 
             @Override
@@ -168,7 +169,7 @@ public class ClientChannelServerDiffsIT extends ClientCase {
             assertEquals(2, diffReader.size);
             assertEquals(1, diffs.size());
             assertEquals(tempId, diffs.get(0).sourceId);
-            assertEquals(ClientMtTable1.GLOBAL_ATTRIBUTE1_PROPERTY, diffs.get(0).property);
+            assertEquals(ClientMtTable1.GLOBAL_ATTRIBUTE1.getName(), diffs.get(0).property);
             assertNull(diffs.get(0).oldValue);
             assertEquals("XXX", diffs.get(0).newValue);
         }
@@ -227,6 +228,7 @@ public class ClientChannelServerDiffsIT extends ClientCase {
             size = 0;
         }
 
+        @Override
         public void nodePropertyChanged(
                 Object nodeId,
                 String property,
@@ -236,22 +238,27 @@ public class ClientChannelServerDiffsIT extends ClientCase {
             size++;
         }
 
-        public void arcCreated(Object nodeId, Object targetNodeId, Object arcId) {
+        @Override
+        public void arcCreated(Object nodeId, Object targetNodeId, ArcId arcId) {
             size++;
         }
 
-        public void arcDeleted(Object nodeId, Object targetNodeId, Object arcId) {
+        @Override
+        public void arcDeleted(Object nodeId, Object targetNodeId, ArcId arcId) {
             size++;
         }
 
+        @Override
         public void nodeCreated(Object nodeId) {
             size++;
         }
 
+        @Override
         public void nodeIdChanged(Object nodeId, Object newId) {
             size++;
         }
 
+        @Override
         public void nodeRemoved(Object nodeId) {
             size++;
         }
