@@ -20,9 +20,10 @@ package org.apache.cayenne.crypto;
 
 import org.apache.cayenne.ObjectContext;
 import org.apache.cayenne.crypto.db.Table2;
+import org.apache.cayenne.crypto.db.Table8;
 import org.apache.cayenne.crypto.transformer.bytes.Header;
 import org.apache.cayenne.crypto.unit.CryptoUnitUtils;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -152,8 +153,8 @@ public class Runtime_AES128_GZIP_IT extends Runtime_AES128_Base {
 
         context.commitChanges();
 
-        SelectQuery<Table2> select = SelectQuery.query(Table2.class);
-        select.addOrdering(Table2.PLAIN_BYTES.asc());
+        ObjectSelect<Table2> select = ObjectSelect.query(Table2.class)
+                .orderBy(Table2.PLAIN_BYTES.asc());
 
         List<Table2> result = runtime.newContext().select(select);
 
@@ -162,5 +163,99 @@ public class Runtime_AES128_GZIP_IT extends Runtime_AES128_Base {
         assertArrayEquals(cryptoBytes2, result.get(1).getCryptoBytes());
         assertArrayEquals(null, result.get(2).getCryptoBytes());
     }
+    
+    @Test
+    public void test_SelectQueryWithOptimisticLocking() throws SQLException {
+        ObjectContext context = runtime.newContext();
+        
+        StringBuilder builder = new StringBuilder();
+        for (int i = 1; i <= 10; i++) {
+            builder.append("ABCDEFGHIJKLMNOPQRSTUVWXYZ");
+        }
+        
+        String str = builder.toString();
+        
+        Table8 t1 = context.newObject(Table8.class);
+        t1.setCryptoString(str);
+        context.commitChanges();
+
+        ObjectSelect<Table8> select = ObjectSelect.query(Table8.class);
+        List<Table8> result = context.select(select);
+        assertEquals(str, result.get(0).getCryptoString());
+        
+        t1.setCryptoString(str + "A");
+        context.commitChanges(); // the update should execute without any locking in the WHERE clause
+        
+        result = context.select(select);
+        assertEquals(str+"A", result.get(0).getCryptoString());
+    }
+
+    @Test
+    public void test_ScalarColumnQuery() throws SQLException {
+        // make sure compression is on...
+        byte[] cryptoBytes1 = CryptoUnitUtils.bytesOfSize(GZIP_THRESHOLD + 101);
+        byte[] cryptoBytes2 = CryptoUnitUtils.bytesOfSize(GZIP_THRESHOLD + 102);
+
+        ObjectContext context = runtime.newContext();
+
+        Table2 t1 = context.newObject(Table2.class);
+        t1.setPlainBytes("a".getBytes());
+        t1.setCryptoBytes(cryptoBytes1);
+
+        Table2 t2 = context.newObject(Table2.class);
+        t2.setPlainBytes("b".getBytes());
+        t2.setCryptoBytes(cryptoBytes2);
+
+        Table2 t3 = context.newObject(Table2.class);
+        t3.setPlainBytes("c".getBytes());
+        t3.setCryptoBytes(null);
+
+        context.commitChanges();
+
+        List<byte[]> result = ObjectSelect.query(Table2.class)
+                .column(Table2.CRYPTO_BYTES)
+                .orderBy(Table2.PLAIN_BYTES.asc())
+                .select(runtime.newContext());
+
+        assertEquals(3, result.size());
+        assertArrayEquals(cryptoBytes1, result.get(0));
+        assertArrayEquals(cryptoBytes2, result.get(1));
+        assertArrayEquals(null, result.get(2));
+    }
+
+    @Test
+    public void test_MultipleColumnsQuery() throws SQLException {
+        // make sure compression is on...
+        byte[] cryptoBytes1 = CryptoUnitUtils.bytesOfSize(GZIP_THRESHOLD + 101);
+        byte[] cryptoBytes2 = CryptoUnitUtils.bytesOfSize(GZIP_THRESHOLD + 102);
+
+        ObjectContext context = runtime.newContext();
+
+        Table2 t1 = context.newObject(Table2.class);
+        t1.setPlainBytes("a".getBytes());
+        t1.setCryptoBytes(cryptoBytes1);
+
+        Table2 t2 = context.newObject(Table2.class);
+        t2.setPlainBytes("b".getBytes());
+        t2.setCryptoBytes(cryptoBytes2);
+
+        Table2 t3 = context.newObject(Table2.class);
+        t3.setPlainBytes("c".getBytes());
+        t3.setCryptoBytes(null);
+
+        context.commitChanges();
+
+        List<Object[]> result = ObjectSelect.query(Table2.class)
+                .columns(Table2.CRYPTO_BYTES, Table2.PLAIN_BYTES)
+                .orderBy(Table2.PLAIN_BYTES.asc())
+                .select(runtime.newContext());
+
+        assertEquals(3, result.size());
+        assertArrayEquals(cryptoBytes1, (byte[])result.get(0)[0]);
+        assertArrayEquals("a".getBytes(), (byte[])result.get(0)[1]);
+        assertArrayEquals(cryptoBytes2, (byte[])result.get(1)[0]);
+        assertArrayEquals("b".getBytes(), (byte[])result.get(1)[1]);
+        assertArrayEquals(null, (byte[])result.get(2)[0]);
+    }
 
 }
