@@ -30,10 +30,17 @@ import org.apache.cayenne.dbsync.merge.factory.MergerTokenFactory;
 import org.apache.cayenne.dbsync.merge.token.MergerToken;
 import org.apache.cayenne.map.DbAttribute;
 import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.map.DetectedDbEntity;
+import org.apache.cayenne.dbsync.model.DetectedDbEntity;
 
 class DbAttributeMerger extends AbstractMerger<DbEntity, DbAttribute> {
 
+    static int[] typesWithMaxLength = {
+            Types.NCHAR, Types.NVARCHAR,
+            Types.CHAR, Types.VARCHAR,
+            Types.BINARY, Types.VARBINARY,
+            Types.TIME, Types.TIMESTAMP
+    };
+
     private final ValueForNullProvider valueForNull;
 
     DbAttributeMerger(MergerTokenFactory tokenFactory, ValueForNullProvider valueForNull) {
@@ -133,15 +140,10 @@ class DbAttributeMerger extends AbstractMerger<DbEntity, DbAttribute> {
                 (imported.getType() == Types.DECIMAL || imported.getType() == Types.NUMERIC)) {
                 return false;
             }
-            return true;
+            return getTokenFactory().needUpdateSpecificType(original, imported);
         }
 
         if(original.getMaxLength() != imported.getMaxLength()) {
-            int[] typesWithMaxLength = {
-                    Types.NCHAR, Types.NVARCHAR,
-                    Types.CHAR, Types.VARCHAR,
-                    Types.BINARY, Types.VARBINARY
-            };
             for(int type : typesWithMaxLength) {
                 if(original.getType() == type) {
                     return true;
