@@ -53,9 +53,7 @@ import org.apache.cayenne.dbsync.reverse.dbload.DbLoaderConfiguration;
 import org.apache.cayenne.dbsync.reverse.dbload.ModelMergeDelegate;
 import org.apache.cayenne.dbsync.reverse.dbload.ProxyModelMergeDelegate;
 import org.apache.cayenne.dbsync.reverse.filters.CatalogFilter;
-import org.apache.cayenne.dbsync.reverse.filters.FiltersConfig;
 import org.apache.cayenne.dbsync.reverse.filters.FiltersConfigBuilder;
-import org.apache.cayenne.dbsync.reverse.filters.PatternFilter;
 import org.apache.cayenne.dbsync.reverse.filters.SchemaFilter;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.map.DataMap;
@@ -63,7 +61,6 @@ import org.apache.cayenne.map.DbEntity;
 import org.apache.cayenne.map.EntityResolver;
 import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.ObjRelationship;
-import org.apache.cayenne.map.Procedure;
 import org.apache.cayenne.project.Project;
 import org.apache.cayenne.project.ProjectSaver;
 import org.apache.cayenne.resource.URLResource;
@@ -91,7 +88,6 @@ public class DefaultDbImportAction implements DbImportAction {
     private final DataChannelDescriptorLoader dataChannelDescriptorLoader;
     private final DataChannelMetaData metaData;
     private boolean hasChanges;
-    private FiltersConfig filters;
     private Collection<MergerToken> tokens;
     private DataMap loadedDataMap;
 
@@ -166,7 +162,6 @@ public class DefaultDbImportAction implements DbImportAction {
 
             syncDataMapProperties(targetDataMap, config);
             applyTokens(targetDataMap, tokens, config);
-            syncProcedures(targetDataMap, sourceDataMap, filters);
 
             saveLoaded(targetDataMap, config);
             this.loadedDataMap = null;
@@ -216,7 +211,7 @@ public class DefaultDbImportAction implements DbImportAction {
         }
         this.loadedDataMap = targetDataMap;
 
-        // In that moment our data map fills with sorce map
+        // In that moment our data map fills with source map
         // transform source DataMap before merging
         transformSourceBeforeMerge(sourceDataMap, targetDataMap, config);
 
@@ -230,11 +225,9 @@ public class DefaultDbImportAction implements DbImportAction {
            .build()
            .createMergeTokens(targetDataMap, sourceDataMap);
         tokens = log(sort(reverse(mergerTokenFactory, tokens)));
-        filters = loaderConfig.getFiltersConfig();
 
         hasChanges |= checkDataMapProperties(targetDataMap, config);
         hasChanges |= hasTokensToImport(tokens);
-        hasChanges |= checkIncludedProcedures(sourceDataMap, filters);
         return sourceDataMap;
     }
 
@@ -297,24 +290,6 @@ public class DefaultDbImportAction implements DbImportAction {
         return defaultPackage.equals(targetDataMap.getDefaultPackage());
     }
 
-    protected boolean hasChangesForProcedure(Procedure procedure) {
-        PatternFilter proceduresFilter = filters.proceduresFilter(procedure.getCatalog(), procedure.getSchema());
-        return proceduresFilter != null && proceduresFilter.isIncluded(procedure.getName());
-    }
-
-    protected boolean checkIncludedProcedures(DataMap loadedDataMap, FiltersConfig filters) {
-        Collection<Procedure> procedures = loadedDataMap.getProcedures();
-        boolean hasChanges = false;
-        for (Procedure procedure : procedures) {
-            if(!hasChangesForProcedure(procedure)) {
-                continue;
-            }
-            hasChanges = true;
-        }
-        return hasChanges;
-    }
-
-
     private void syncDataMapProperties(DataMap targetDataMap, DbImportConfiguration config) {
         String defaultPackage = config.getDefaultPackage();
         if (defaultPackage == null || isBlank(defaultPackage)) {
@@ -409,8 +384,7 @@ public class DefaultDbImportAction implements DbImportAction {
         return dataMap;
     }
 
-    private List<MergerToken> reverse(MergerTokenFactory mergerTokenFactory, Iterable<MergerToken> mergeTokens)
-            throws IOException {
+    private List<MergerToken> reverse(MergerTokenFactory mergerTokenFactory, Iterable<MergerToken> mergeTokens) {
 
         List<MergerToken> tokens = new LinkedList<>();
         for (MergerToken token : mergeTokens) {
@@ -474,38 +448,10 @@ public class DefaultDbImportAction implements DbImportAction {
         relationshipsSanity(targetDataMap);
     }
 
-    protected void addMessageToLogs(String message, List<String> messages) {
-        messages.add(message);
-    }
-
     protected void logMessages(List<String> messages) {
         messages.forEach(logger::info);
     }
 
-
-    protected void syncProcedures(DataMap targetDataMap, DataMap loadedDataMap, FiltersConfig filters) {
-        Collection<Procedure> procedures = loadedDataMap.getProcedures();
-        List<String> messages = new LinkedList<>();
-
-        for (Procedure procedure : procedures) {
-            PatternFilter proceduresFilter = filters.proceduresFilter(procedure.getCatalog(), procedure.getSchema());
-            if (proceduresFilter == null || !proceduresFilter.isIncluded(procedure.getName())) {
-                continue;
-            }
-
-            Procedure oldProcedure = targetDataMap.getProcedure(procedure.getName());
-            // maybe we need to compare oldProcedure's and procedure's fully qualified names?
-            if (oldProcedure != null) {
-                targetDataMap.removeProcedure(procedure.getName());
-                addMessageToLogs("Replace procedure " + procedure.getName(), messages);
-            } else {
-                addMessageToLogs("Add new procedure " + procedure.getName(), messages);
-            }
-            targetDataMap.addProcedure(procedure);
-        }
-        logMessages(messages);
-    }
-
     /**
      * Save imported data.
      * This can create DataMap and/or Project files.
