@@ -29,7 +29,7 @@ import org.apache.cayenne.dba.DbAdapter;
 import org.apache.cayenne.dbsync.reverse.filters.CatalogFilter;
 import org.apache.cayenne.dbsync.reverse.filters.SchemaFilter;
 import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.map.DetectedDbEntity;
+import org.apache.cayenne.dbsync.model.DetectedDbEntity;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -65,9 +65,7 @@ class EntityLoader extends PerCatalogAndSchemaLoader {
             return;
         }
 
-        // check catalogName for null was added because postgres
-        // for some reasons returns null for table's catalog
-        if (!(catalog.name == null || catalogName == null || catalog.name.equals(catalogName))
+        if (!(catalog.name == null || catalog.name.equals(catalogName))
                 || !(schema.name == null || schema.name.equals(schemaName))) {
             LOGGER.error(catalogName + "." + schema + "." + schemaName + " wrongly loaded for catalog/schema : "
                     + catalog.name + "." + schema.name);
