@@ -22,7 +22,7 @@ import org.apache.cayenne.map.DataMap;
 
 /**
  * Factory for test data see pattern definition:
- * http://martinfowler.com/bliki/ObjectMother.html
+ * https://martinfowler.com/bliki/ObjectMother.html
  *
  * @since 4.0.
  */
@@ -67,4 +67,12 @@ public class ObjectMother {
         return new DbAttributeBuilder();
     }
 
+    public static ProcedureBuilder procedure(String name) {
+        return procedure().name(name);
+    }
+
+    public static ProcedureBuilder procedure() {
+        return new ProcedureBuilder();
+    }
+
 }
