@@ -23,12 +23,11 @@ import groovy.lang.Reference;
 import org.apache.cayenne.configuration.xml.DataChannelMetaData;
 import org.apache.cayenne.dbsync.filter.NamePatternMatcher;
 import org.apache.cayenne.dbsync.reverse.configuration.ToolsModule;
-import org.apache.cayenne.di.DIBootstrap;
 import org.apache.cayenne.di.Injector;
 import org.apache.cayenne.gen.ArtifactsGenerationMode;
 import org.apache.cayenne.gen.CgenConfiguration;
-import org.apache.cayenne.gen.CgenModule;
 import org.apache.cayenne.gen.ClassGenerationAction;
+import org.apache.cayenne.gen.ClassGenerationActionFactory;
 import org.apache.cayenne.gen.ClientClassGenerationAction;
 import org.apache.cayenne.map.DataMap;
 import org.gradle.api.Action;
@@ -36,7 +35,6 @@ import org.gradle.api.GradleException;
 import org.gradle.api.InvalidUserDataException;
 import org.gradle.api.plugins.JavaPlugin;
 import org.gradle.api.tasks.*;
-import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.io.File;
@@ -144,17 +142,30 @@ public class CgenTask extends BaseCayenneTask {
     @Optional
     private Boolean createPKProperties;
 
+    /**
+     * Optional path (classpath or filesystem) to external velocity tool configuration file
+     * @since 4.2
+     */
+    @Input
+    @Optional
+    private String externalToolConfig;
+
     private String destDirName;
 
     private DataChannelMetaData metaData;
 
     private boolean useConfigFromDataMap;
 
+    private transient Injector injector;
+
     @TaskAction
     public void generate() {
         File dataMapFile = getDataMapFile();
 
-        final Injector injector = DIBootstrap.createInjector(new CgenModule(), new ToolsModule(LoggerFactory.getLogger(CgenTask.class)));
+        injector = new ToolsInjectorBuilder()
+                .addModule(new ToolsModule(LoggerFactory.getLogger(CgenTask.class)))
+                .create();
+
         metaData = injector.getInstance(DataChannelMetaData.class);
 
         CayenneGeneratorMapLoaderAction loaderAction = new CayenneGeneratorMapLoaderAction(injector);
@@ -206,10 +217,7 @@ public class CgenTask extends BaseCayenneTask {
 
     ClassGenerationAction createGenerator(DataMap dataMap) {
         CgenConfiguration cgenConfiguration = buildConfiguration(dataMap);
-        ClassGenerationAction classGenerationAction = cgenConfiguration.isClient() ? new ClientClassGenerationAction() :
-                new ClassGenerationAction();
-        classGenerationAction.setCgenConfiguration(cgenConfiguration);
-        return classGenerationAction;
+        return injector.getInstance(ClassGenerationActionFactory.class).createAction(cgenConfiguration);
     }
 
     CgenConfiguration buildConfiguration(DataMap dataMap) {
@@ -253,6 +261,7 @@ public class CgenTask extends BaseCayenneTask {
         cgenConfiguration.setQueryTemplate(queryTemplate != null ? queryTemplate : cgenConfiguration.getQueryTemplate());
         cgenConfiguration.setQuerySuperTemplate(querySuperTemplate != null ? querySuperTemplate : cgenConfiguration.getQuerySuperTemplate());
         cgenConfiguration.setCreatePKProperties(createPKProperties != null ? createPKProperties : cgenConfiguration.isCreatePKProperties());
+        cgenConfiguration.setExternalToolConfig(externalToolConfig != null ? externalToolConfig : cgenConfiguration.getExternalToolConfig());
         if(!cgenConfiguration.isMakePairs()) {
             if(template == null) {
                 cgenConfiguration.setTemplate(cgenConfiguration.isClient() ? ClientClassGenerationAction.SINGLE_CLASS_TEMPLATE : ClassGenerationAction.SINGLE_CLASS_TEMPLATE);
@@ -279,7 +288,7 @@ public class CgenTask extends BaseCayenneTask {
                 makePairs != null || mode != null || outputPattern != null || overwrite != null || superPkg != null ||
                 superTemplate != null || template != null || embeddableTemplate != null || embeddableSuperTemplate != null ||
                 usePkgPath != null || createPropertyNames != null || force || queryTemplate != null ||
-                querySuperTemplate != null || createPKProperties != null;
+                querySuperTemplate != null || createPKProperties != null || externalToolConfig != null;
     }
 
     @OutputDirectory
@@ -426,6 +435,10 @@ public class CgenTask extends BaseCayenneTask {
         return createPKProperties;
     }
 
+    public String getExternalToolConfig() {
+        return externalToolConfig;
+    }
+
     public String getQueryTemplate() {
         return queryTemplate;
     }
@@ -435,8 +448,8 @@ public class CgenTask extends BaseCayenneTask {
     }
 
     /**
+     * @param excludeEmbeddables pattern to use for embeddable exclusion
      * @since 4.1
-     * @param excludeEmbeddables
      */
     public void excludeEmbeddables(String excludeEmbeddables) {
         setExcludeEmbeddables(excludeEmbeddables);
@@ -593,5 +606,12 @@ public class CgenTask extends BaseCayenneTask {
     public void createPKProperties(boolean createPKProperties) {
         setCreatePKProperties(createPKProperties);
     }
+    
+    public void setExternalToolConfig(String externalToolConfig) {
+    	this.externalToolConfig = externalToolConfig;
+    }
 
+    public void externalToolConfig(String externalToolConfig) {
+    	setExternalToolConfig(externalToolConfig);
+    }
 }
\ No newline at end of file
