@@ -48,6 +48,7 @@ import org.gradle.api.tasks.Optional;
 import org.gradle.api.tasks.OutputFile;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.api.tasks.TaskExecutionException;
+import org.apache.cayenne.di.spi.DefaultClassLoaderManager;
 
 /**
  * @since 4.0
@@ -78,7 +79,9 @@ public class DbImportTask extends BaseCayenneTask {
     public void runImport() {
         dataSource.validate();
 
-        final Injector injector = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(getLogger()), new DbImportModule());
+        final Injector injector = DIBootstrap.createInjector(new DbSyncModule(), new ToolsModule(getLogger()), new DbImportModule(),
+                binder -> binder.bind(ClassLoaderManager.class).toInstance(new DefaultClassLoaderManager()));
+
         final DbImportConfiguration config = createConfig();
 
         DataSourceFactory dataSourceFactory = injector.getInstance(DataSourceFactory.class);
