@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -28,8 +28,11 @@ import org.apache.cayenne.DataChannelSyncFilter;
 import org.apache.cayenne.DataChannelSyncFilterChain;
 import org.apache.cayenne.ObjectContext;
 import org.apache.cayenne.QueryResponse;
+import org.apache.cayenne.access.flush.DataDomainFlushAction;
+import org.apache.cayenne.access.flush.DataDomainFlushActionFactory;
 import org.apache.cayenne.cache.QueryCache;
 import org.apache.cayenne.configuration.Constants;
+import org.apache.cayenne.di.AdhocObjectFactory;
 import org.apache.cayenne.di.BeforeScopeEnd;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.event.EventManager;
@@ -107,6 +110,18 @@ public class DataDomain implements QueryEngine, DataChannel {
 	 */
 	protected List<DataChannelSyncFilter> syncFilters;
 
+	/**
+	 * @since 4.2
+	 */
+	@Inject
+	protected DataDomainFlushActionFactory flushActionFactory;
+
+	/**
+	 * @since 4.2
+	 */
+	@Inject
+	protected AdhocObjectFactory objectFactory;
+
 	protected Map<String, DataNode> nodes;
 	protected Map<String, DataNode> nodesByDataMapName;
 	protected DataNode defaultNode;
@@ -618,9 +633,7 @@ public class DataDomain implements QueryEngine, DataChannel {
 							+ "Unsupported context: %s", originatingContext);
 		}
 
-		DataDomainFlushAction action = new DataDomainFlushAction(this);
-		action.setJdbcEventLogger(jdbcEventLogger);
-
+		DataDomainFlushAction action = flushActionFactory.createFlushAction(this);
 		return action.flush((DataContext) originatingContext, childChanges);
 	}
 
@@ -867,4 +880,8 @@ public class DataDomain implements QueryEngine, DataChannel {
 	TransactionManager getTransactionManager() {
 		return transactionManager;
 	}
+
+	AdhocObjectFactory getObjectFactory() {
+		return objectFactory;
+	}
 }
