@@ -22,6 +22,7 @@ package org.apache.cayenne.access;
 import org.apache.cayenne.ObjectId;
 import org.apache.cayenne.access.DataDomainSyncBucket.PropagatedValueFactory;
 import org.apache.cayenne.exp.parser.ASTDbPath;
+import org.apache.cayenne.graph.ArcId;
 import org.apache.cayenne.graph.GraphChangeHandler;
 import org.apache.cayenne.graph.GraphDiff;
 import org.apache.cayenne.map.DbAttribute;
@@ -33,7 +34,6 @@ import org.apache.cayenne.map.ObjEntity;
 import org.apache.cayenne.map.ObjRelationship;
 
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
 
@@ -42,7 +42,9 @@ import java.util.Map.Entry;
  * INSERT.
  * 
  * @since 1.2
+ * @deprecated since 4.2 as part of deprecated {@link LegacyDataDomainFlushAction}
  */
+@Deprecated
 class DataDomainDBDiffBuilder implements GraphChangeHandler {
 
     private ObjEntity objEntity;
@@ -151,6 +153,7 @@ class DataDomainDBDiffBuilder implements GraphChangeHandler {
     // GraphChangeHandler methods.
     // ==================================================
 
+    @Override
     public void nodePropertyChanged(Object nodeId, String property, Object oldValue, Object newValue) {
         // note - no checking for phantom mod... assuming there is no phantom
         // diffs
@@ -162,7 +165,8 @@ class DataDomainDBDiffBuilder implements GraphChangeHandler {
         currentPropertyDiff.put(property, newValue);
     }
 
-    public void arcCreated(Object nodeId, Object targetNodeId, Object arcId) {
+    @Override
+    public void arcCreated(Object nodeId, Object targetNodeId, ArcId arcId) {
         String arcIdString = arcId.toString();
         ObjRelationship relationship = objEntity.getRelationship(arcIdString);
 
@@ -179,22 +183,21 @@ class DataDomainDBDiffBuilder implements GraphChangeHandler {
             }
 
         } else {
-            List<DbRelationship> dbRelationships = relationship.getDbRelationships();
-            DbRelationship lastDbRelationship = dbRelationships.get(dbRelationships.size() - 1);
-            if (!relationship.isToMany() && lastDbRelationship.isToPK() && !lastDbRelationship.isToDependentPK()) {
+            if (!relationship.isToMany() && relationship.isToPK()) {
                 doArcCreated(targetNodeId, arcId);
             }
         }
     }
 
-    private void doArcCreated(Object targetNodeId, Object arcId) {
+    private void doArcCreated(Object targetNodeId, ArcId arcId) {
         if (currentArcDiff == null) {
             currentArcDiff = new HashMap<>();
         }
         currentArcDiff.put(arcId, targetNodeId);
     }
 
-    public void arcDeleted(Object nodeId, Object targetNodeId, Object arcId) {
+    @Override
+    public void arcDeleted(Object nodeId, Object targetNodeId, ArcId arcId) {
 
         String arcIdString = arcId.toString();
         ObjRelationship relationship = objEntity.getRelationship(arcIdString);
@@ -212,16 +215,12 @@ class DataDomainDBDiffBuilder implements GraphChangeHandler {
                 throw new IllegalArgumentException("Bad arcId: " + arcId);
             }
 
-        } else {
-            List<DbRelationship> dbRelationships = relationship.getDbRelationships();
-            DbRelationship lastDbRelationship = dbRelationships.get(dbRelationships.size() - 1);
-            if (!relationship.isToMany() && lastDbRelationship.isToPK() && !lastDbRelationship.isToDependentPK()) {
-                doArcDeleted(targetNodeId, arcId);
-            }
+        } else if (!relationship.isSourceIndependentFromTargetChange()) {
+            doArcDeleted(targetNodeId, arcId);
         }
     }
 
-    private void doArcDeleted(Object targetNodeId, Object arcId) {
+    private void doArcDeleted(Object targetNodeId, ArcId arcId) {
         if (currentArcDiff == null) {
             currentArcDiff = new HashMap<>();
             currentArcDiff.put(arcId, null);
@@ -235,16 +234,10 @@ class DataDomainDBDiffBuilder implements GraphChangeHandler {
         }
     }
 
+    @Override
     public void nodeCreated(Object nodeId) {
         // need to append PK columns
         this.currentId = nodeId;
     }
 
-    public void nodeRemoved(Object nodeId) {
-        // noop
-    }
-
-    public void nodeIdChanged(Object nodeId, Object newId) {
-        // noop
-    }
 }
