@@ -145,6 +145,11 @@ class DataDomainQuery implements Query, QueryMetadata {
         return 0;
     }
 
+    @Override
+    public int getQueryTimeout() {
+        return QueryMetadata.QUERY_TIMEOUT_DEFAULT;
+    }
+
     @Override
     public boolean isSuppressingDistinct() {
         return false;
