@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -52,56 +52,17 @@ import java.util.concurrent.ConcurrentMap;
  */
 public class DataRowStore implements Serializable {
 
-    private static Logger logger = LoggerFactory.getLogger(DataRowStore.class);
-
-    /**
-     * @deprecated since 4.0, never used actually
-     */
-    @Deprecated
-    public static final String SNAPSHOT_EXPIRATION_PROPERTY = "cayenne.DataRowStore.snapshot.expiration";
-
-    /**
-     * @deprecated since 4.0, use {@link org.apache.cayenne.configuration.Constants#SNAPSHOT_CACHE_SIZE_PROPERTY}
-     */
-    @Deprecated
-    public static final String SNAPSHOT_CACHE_SIZE_PROPERTY = "cayenne.DataRowStore.snapshot.size";
-
-    /**
-     * @deprecated since 4.0 does nothing. Previously it used to check if need to create {@link EventBridge}.
-     */
-    @Deprecated
-    public static final String REMOTE_NOTIFICATION_PROPERTY = "cayenne.DataRowStore.remote.notify";
-
-    /**
-     * @deprecated since 4.0 {@link DataRowStoreFactory} establishes {@link EventBridge}.
-     */
-    @Deprecated
-    public static final String EVENT_BRIDGE_FACTORY_PROPERTY = "cayenne.DataRowStore.EventBridge.factory";
+    private static final Logger logger = LoggerFactory.getLogger(DataRowStore.class);
 
     // default property values
 
     public static final long SNAPSHOT_EXPIRATION_DEFAULT = 2 * 60 * 60; // default expiration time is 2 hours
     public static final int SNAPSHOT_CACHE_SIZE_DEFAULT = 10000;
 
-    @Deprecated
-    public static final boolean REMOTE_NOTIFICATION_DEFAULT = false;
-
-    /**
-     * @deprecated since 4.0 does nothing.
-     */
-    @Deprecated
-    public static final String EVENT_BRIDGE_FACTORY_DEFAULT = "org.apache.cayenne.event.JavaGroupsBridgeFactory";
-
     protected String name;
     private int maxSize;
     protected ConcurrentMap<ObjectId, DataRow> snapshots;
 
-    /**
-     * @deprecated since 4.0 does nothing. Previously it used to check if need to create {@link EventBridge}.
-     */
-    @Deprecated
-    protected boolean notifyingRemoteListeners;
-
     protected transient EventManager eventManager;
     protected transient EventBridge remoteNotificationsHandler;
 
@@ -227,9 +188,9 @@ public class DataRowStore implements Serializable {
             processSnapshotChanges(
                     eventPostedBy,
                     modified,
-                    Collections.<ObjectId>emptyList(),
-                    Collections.<ObjectId>emptyList(),
-                    Collections.<ObjectId>emptyList());
+                    Collections.emptyList(),
+                    Collections.emptyList(),
+                    Collections.emptyList());
         }
     }
 
@@ -375,7 +336,7 @@ public class DataRowStore implements Serializable {
         if (deletedSnapshotIds.isEmpty()
                 && invalidatedSnapshotIds.isEmpty()
                 && updatedSnapshots.isEmpty()
-                && indirectlyModifiedIds.isEmpty()) {
+                && (indirectlyModifiedIds == null || indirectlyModifiedIds.isEmpty())) {
             logger.warn("postSnapshotsChangeEvent.. bogus call... no changes.");
             return;
         }
@@ -520,16 +481,6 @@ public class DataRowStore implements Serializable {
         }
     }
 
-    @Deprecated
-    public boolean isNotifyingRemoteListeners() {
-        return notifyingRemoteListeners;
-    }
-
-    @Deprecated
-    public void setNotifyingRemoteListeners(boolean notifyingRemoteListeners) {
-        this.notifyingRemoteListeners = notifyingRemoteListeners;
-    }
-
     // deserialization support
     private void readObject(ObjectInputStream in) throws IOException,
             ClassNotFoundException {
