@@ -192,9 +192,9 @@ class ObjectResolver {
             String path = entry.getKey();
             int lastDot = path.lastIndexOf('.');
             String prefix = lastDot == -1 ? path : path.substring(lastDot + 1);
-            ObjectId objectId = createObjectId(row, dbEntity.getName(), dbEntity.getPrimaryKeys(), prefix + '.', false);
+            ObjectId objectId = createObjectId(row, "db:" + dbEntity.getName(), dbEntity.getPrimaryKeys(), prefix + '.', false);
             if(objectId != null) {
-				context.getObjectStore().markFlattenedPath(object.getObjectId(), path);
+				context.getObjectStore().markFlattenedPath(object.getObjectId(), path, objectId);
             }
         }
     }
@@ -244,7 +244,7 @@ class ObjectResolver {
 			}
 
 			// PUT without a prefix
-			return new ObjectId(name, attribute.getName(), val);
+			return ObjectId.of(name, attribute.getName(), val);
 		}
 
 		// ... handle generic case - PK.size > 1
@@ -268,7 +268,7 @@ class ObjectResolver {
 			idMap.put(attribute.getName(), val);
 		}
 
-		return new ObjectId(name, idMap);
+		return ObjectId.of(name, idMap);
 	}
 
 	interface DescriptorResolutionStrategy {
