@@ -44,6 +44,8 @@ import org.apache.cayenne.reflect.ClassDescriptor;
 import org.apache.cayenne.reflect.PropertyVisitor;
 import org.apache.cayenne.reflect.ToManyProperty;
 import org.apache.cayenne.reflect.ToOneProperty;
+import org.apache.cayenne.util.SoftValueMap;
+import org.apache.cayenne.util.WeakValueMap;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -53,7 +55,6 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
 /**
@@ -109,13 +110,23 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
      */
     public ObjectStore(DataRowStore dataRowCache, Map<Object, Persistent> objectMap) {
         setDataRowCache(dataRowCache);
-        if (objectMap != null) {
-            this.objectMap = objectMap;
-        }
-        else {
+        setObjectMap(objectMap);
+        this.changes = new HashMap<>();
+    }
+
+    /**
+     * @since 4.2.2
+     */
+    void setObjectMap(Map<Object, Persistent> objectMap) {
+        if(objectMap == null) {
             throw new CayenneRuntimeException("Object map is null.");
         }
-        this.changes = new HashMap<>();
+        this.objectMap = objectMap;
+        if(objectMap instanceof SoftValueMap) {
+            ((SoftValueMap<Object, Persistent>) objectMap).setKeyCleanupCallback(this::onObjectKeyCleanup);
+        } else if(objectMap instanceof WeakValueMap) {
+            ((WeakValueMap<Object, Persistent>) objectMap).setKeyCleanupCallback(this::onObjectKeyCleanup);
+        }
     }
 
     /**
@@ -138,7 +149,7 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
     Collection<GraphDiff> getLifecycleEventInducedChanges() {
         return lifecycleEventInducedChanges != null
                 ? lifecycleEventInducedChanges
-                : Collections.<GraphDiff>emptyList();
+                : Collections.emptyList();
     }
 
     void registerLifecycleEventInducedChange(GraphDiff diff) {
@@ -416,6 +427,9 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
             switch (object.getPersistenceState()) {
                 case PersistenceState.DELETED:
                     objectMap.remove(id);
+                    if(trackedFlattenedPaths != null) {
+                        trackedFlattenedPaths.remove(id);
+                    }
                     object.setObjectContext(null);
                     object.setPersistenceState(PersistenceState.TRANSIENT);
                     break;
@@ -429,35 +443,10 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
         // re-register changed object ids
         if (!parentChanges.isNoop()) {
             parentChanges.apply(new GraphChangeHandler() {
-
-                @Override
-                public void arcCreated(Object nodeId, Object targetNodeId, ArcId arcId) {
-                }
-
-                @Override
-                public void arcDeleted(Object nodeId, Object targetNodeId, ArcId arcId) {
-                }
-
-                @Override
-                public void nodeCreated(Object nodeId) {
-                }
-
                 @Override
                 public void nodeIdChanged(Object nodeId, Object newId) {
                     processIdChange(nodeId, newId);
                 }
-
-                @Override
-                public void nodePropertyChanged(
-                        Object nodeId,
-                        String property,
-                        Object oldValue,
-                        Object newValue) {
-                }
-
-                @Override
-                public void nodeRemoved(Object nodeId) {
-                }
             });
         }
 
@@ -640,9 +629,11 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
                     if (dataObject == null || delegate.shouldProcessDelete(dataObject)) {
                         objectMap.remove(nodeId);
                         changes.remove(nodeId);
+                        if(trackedFlattenedPaths != null) {
+                            trackedFlattenedPaths.remove(nodeId);
+                        }
 
-                        // setting DataContext to null will also set
-                        // state to transient
+                        // setting DataContext to null will also set state to transient
                         object.setObjectContext(null);
 
                         if (dataObject != null) {
@@ -1049,6 +1040,16 @@ public class ObjectStore implements Serializable, SnapshotEventListener, GraphMa
                 .put(path, id);
     }
 
+    /**
+     * @param key object id that was removed from the {@link #objectMap}
+     * @since 4.2.2
+     */
+    void onObjectKeyCleanup(Object key) {
+        if(trackedFlattenedPaths != null) {
+            trackedFlattenedPaths.remove(key);
+        }
+    }
+
     // an ObjectIdQuery optimized for retrieval of multiple snapshots - it can be reset
     // with the new id
     final class CachedSnapshotQuery extends ObjectIdQuery {
