@@ -19,6 +19,18 @@
 
 package org.apache.cayenne.access.jdbc;
 
+import java.sql.Connection;
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import java.sql.Statement;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.ResultIterator;
 import org.apache.cayenne.access.DataNode;
@@ -39,18 +51,6 @@ import org.apache.cayenne.query.SQLAction;
 import org.apache.cayenne.query.SQLTemplate;
 import org.apache.cayenne.util.Util;
 
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.sql.Statement;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-
 /**
  * Implements a strategy for execution of SQLTemplates.
  *
@@ -188,6 +188,7 @@ public class SQLTemplateAction implements SQLAction {
 		boolean iteratedResult = callback.isIteratedResult();
 		int generatedKeys = query.isReturnGeneratedKeys() ? Statement.RETURN_GENERATED_KEYS : Statement.NO_GENERATED_KEYS;
 		PreparedStatement statement = connection.prepareStatement(compiled.getSql(), generatedKeys);
+
 		try {
 			bind(statement, compiled.getBindings());
 
@@ -355,7 +356,7 @@ public class SQLTemplateAction implements SQLAction {
 		if (dbEntity != null && isResultColumnTypesEmpty()) {
 			for (DbAttribute attribute : dbEntity.getAttributes()) {
 				if (!builder.isOverriden(attribute.getName()) && TypesMapping.isNumeric(attribute.getType())) {
-					builder.overrideColumnType(attribute.getName(), TypesMapping.getJavaBySqlType(attribute.getType()));
+					builder.overrideColumnType(attribute.getName(), TypesMapping.getJavaBySqlType(attribute));
 				}
 			}
 		}
@@ -403,6 +404,11 @@ public class SQLTemplateAction implements SQLAction {
 		if (queryMetadata.getStatementFetchSize() != 0) {
 			preparedStatement.setFetchSize(queryMetadata.getStatementFetchSize());
 		}
+
+		int queryTimeout = queryMetadata.getQueryTimeout();
+		if(queryTimeout != QueryMetadata.QUERY_TIMEOUT_DEFAULT) {
+			preparedStatement.setQueryTimeout(queryTimeout);
+		}
 	}
 
 	/**
