@@ -20,7 +20,7 @@ package org.apache.cayenne.access.translator.select;
 
 import org.apache.cayenne.dba.DbAdapter;
 import org.apache.cayenne.map.EntityResolver;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.Select;
 
 /**
  * A factory for {@link SelectTranslator} objects.
@@ -32,6 +32,6 @@ public interface SelectTranslatorFactory {
 	/**
 	 * Creates a proper translator for a BatchQuery
 	 */
-	SelectTranslator translator(SelectQuery<?> query, DbAdapter adapter, EntityResolver entityResolver);
+	SelectTranslator translator(Select<?> query, DbAdapter adapter, EntityResolver entityResolver);
 
 }
