@@ -1,5 +1,5 @@
 /*
- *     Licensed to the Apache Software Foundation (ASF) under one
+ * Licensed to the Apache Software Foundation (ASF) under one
  *    or more contributor license agreements.  See the NOTICE file
  *    distributed with this work for additional information
  *    regarding copyright ownership.  The ASF licenses this file
@@ -19,15 +19,23 @@
 
 package org.apache.cayenne.dba;
 
+import java.net.URL;
+import java.sql.PreparedStatement;
+import java.sql.Types;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Comparator;
+import java.util.Iterator;
+import java.util.List;
+
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.access.DataNode;
+import org.apache.cayenne.access.sqlbuilder.sqltree.SQLTreeProcessor;
 import org.apache.cayenne.access.translator.ParameterBinding;
 import org.apache.cayenne.access.translator.batch.BatchTranslatorFactory;
 import org.apache.cayenne.access.translator.ejbql.EJBQLTranslatorFactory;
 import org.apache.cayenne.access.translator.ejbql.JdbcEJBQLTranslatorFactory;
 import org.apache.cayenne.access.translator.select.DefaultSelectTranslator;
-import org.apache.cayenne.access.translator.select.QualifierTranslator;
-import org.apache.cayenne.access.translator.select.QueryAssembler;
 import org.apache.cayenne.access.translator.select.SelectTranslator;
 import org.apache.cayenne.access.types.ExtendedType;
 import org.apache.cayenne.access.types.ExtendedTypeFactory;
@@ -43,6 +51,7 @@ import org.apache.cayenne.map.DbEntity;
 import org.apache.cayenne.map.DbJoin;
 import org.apache.cayenne.map.DbRelationship;
 import org.apache.cayenne.map.EntityResolver;
+import org.apache.cayenne.query.FluentSelect;
 import org.apache.cayenne.query.Query;
 import org.apache.cayenne.query.SQLAction;
 import org.apache.cayenne.query.SelectQuery;
@@ -50,15 +59,6 @@ import org.apache.cayenne.resource.Resource;
 import org.apache.cayenne.resource.ResourceLocator;
 import org.apache.cayenne.util.Util;
 
-import java.net.URL;
-import java.sql.PreparedStatement;
-import java.sql.SQLException;
-import java.sql.Types;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Iterator;
-import java.util.List;
-
 /**
  * A generic DbAdapter implementation. Can be used as a default adapter or as a
  * superclass of a concrete adapter implementation.
@@ -396,9 +396,17 @@ public class JdbcAdapter implements DbAdapter {
     }
 
     public static String getType(DbAdapter adapter, DbAttribute column) {
-        String[] types = adapter.externalTypesForJdbcType(column.getType());
+        int columnType = column.getType();
+        if(columnType == Types.OTHER) {
+            // TODO: warn that this is unsupported yet
+            return "OTHER";
+        }
+
+        String[] types = adapter.externalTypesForJdbcType(columnType);
         if (types == null || types.length == 0) {
-            String entityName = column.getEntity() != null ? column.getEntity().getFullyQualifiedName() : "<null>";
+            String entityName = column.getEntity() != null
+                    ? column.getEntity().getFullyQualifiedName()
+                    : "<null>";
             throw new CayenneRuntimeException("Undefined type for attribute '%s.%s': %s."
                     , entityName, column.getName(), column.getType());
         }
@@ -456,7 +464,14 @@ public class JdbcAdapter implements DbAdapter {
 
         boolean first = true;
 
-        for (DbJoin join : rel.getJoins()) {
+        // sort joins in the order PK are set in target, to avoid errors on some DBs
+        List<DbJoin> joins = rel.getJoins();
+        if(rel.isToPK()) {
+            List<DbAttribute> pks = rel.getTargetEntity().getPrimaryKeys();
+            joins.sort(Comparator.comparingInt(join -> pks.indexOf(join.getTarget())));
+        }
+
+        for (DbJoin join : joins) {
             if (first) {
                 first = false;
             } else {
@@ -515,16 +530,6 @@ public class JdbcAdapter implements DbAdapter {
         return "VIEW";
     }
 
-    /**
-     * Creates and returns a default implementation of a qualifier translator.
-     */
-    @Override
-    public QualifierTranslator getQualifierTranslator(QueryAssembler queryAssembler) {
-        QualifierTranslator translator = new QualifierTranslator(queryAssembler);
-        translator.setCaseInsensitive(caseInsensitiveCollations);
-        return translator;
-    }
-
     /**
      * Uses JdbcActionBuilder to create the right action.
      *
@@ -536,14 +541,24 @@ public class JdbcAdapter implements DbAdapter {
     }
 
     @Override
+    @Deprecated
     public SelectTranslator getSelectTranslator(SelectQuery<?> query, EntityResolver entityResolver) {
         return new DefaultSelectTranslator(query, this, entityResolver);
     }
 
     @Override
+    public SelectTranslator getSelectTranslator(FluentSelect<?> query, EntityResolver entityResolver) {
+        return new DefaultSelectTranslator(query, this, entityResolver);
+    }
+
+    @Override
+    public SQLTreeProcessor getSqlTreeProcessor() {
+        return node -> node;
+    }
+
     @SuppressWarnings("unchecked")
-    public void bindParameter(PreparedStatement statement, ParameterBinding binding)
-            throws SQLException, Exception {
+    @Override
+    public void bindParameter(PreparedStatement statement, ParameterBinding binding) throws Exception {
 
         if (binding.getValue() == null) {
             statement.setNull(binding.getStatementPosition(), binding.getJdbcType());
