@@ -20,9 +20,9 @@
 package org.apache.cayenne.dba.firebird;
 
 import org.apache.cayenne.CayenneRuntimeException;
+import org.apache.cayenne.access.DataNode;
+import org.apache.cayenne.access.sqlbuilder.sqltree.SQLTreeProcessor;
 import org.apache.cayenne.access.translator.ejbql.EJBQLTranslatorFactory;
-import org.apache.cayenne.access.translator.select.QualifierTranslator;
-import org.apache.cayenne.access.translator.select.QueryAssembler;
 import org.apache.cayenne.access.types.ByteArrayType;
 import org.apache.cayenne.access.types.CharType;
 import org.apache.cayenne.access.types.ExtendedType;
@@ -34,12 +34,14 @@ import org.apache.cayenne.configuration.RuntimeProperties;
 import org.apache.cayenne.dba.JdbcAdapter;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.map.DbAttribute;
+import org.apache.cayenne.query.Query;
+import org.apache.cayenne.query.SQLAction;
 import org.apache.cayenne.resource.ResourceLocator;
 
 import java.util.List;
 
 /**
- * DbAdapter implementation for <a href="http://www.firebirdsql.org">FirebirdSQL
+ * DbAdapter implementation for <a href="https://www.firebirdsql.org">FirebirdSQL
  * RDBMS </a>. Sample connection settings to use with Firebird are shown
  * below:
  * 
@@ -82,20 +84,12 @@ public class FirebirdAdapter extends JdbcAdapter {
     }
 
     public void createTableAppendColumn(StringBuffer sqlBuffer, DbAttribute column) {
-
-        String[] types = externalTypesForJdbcType(column.getType());
-        if (types == null || types.length == 0) {
-            String entityName = column.getEntity() != null ? column.getEntity().getFullyQualifiedName() : "<null>";
-            throw new CayenneRuntimeException("Undefined type for attribute '%s.%s': %s"
-                    , entityName, column.getName(), column.getType());
-        }
+        String type = getType(this, column);
+        String length = sizeAndPrecision(this, column);
 
         sqlBuffer.append(quotingStrategy.quotedName(column));
         sqlBuffer.append(' ');
 
-        String type = types[0];
-        String length = sizeAndPrecision(this, column);
-
         int suffixIndex = type.indexOf(NCHAR_SUFFIX);
         if (!length.isEmpty() && suffixIndex > 0) {
             sqlBuffer.append(type.substring(0, suffixIndex)).append(length).append(NCHAR_SUFFIX);
@@ -105,14 +99,22 @@ public class FirebirdAdapter extends JdbcAdapter {
 
         sqlBuffer.append(column.isMandatory() ? " NOT NULL" : "");
     }
-    
+
+    /**
+     * @since 4.2
+     */
     @Override
-    public QualifierTranslator getQualifierTranslator(QueryAssembler queryAssembler) {
-        return new FirebirdQualifierTranslator(queryAssembler);
+    public SQLTreeProcessor getSqlTreeProcessor() {
+        return new FirebirdSQLTreeProcessor();
     }
 
     @Override
     public EJBQLTranslatorFactory getEjbqlTranslatorFactory() {
         return new FirebirdEJBQLTranslatorFactory();
     }
+
+    @Override
+    public SQLAction getAction(Query query, DataNode node) {
+        return query.createSQLAction(new FirebirdActionBuilder(node));
+    }
 }
