@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -157,7 +157,7 @@ public class MySQLPkGenerator extends JdbcPkGenerator {
         statement.execute(lockString);
 
         // select
-        String selectString = super.pkSelectString(entityName);
+        String selectString = pkSelectString(entityName);
         adapter.getJdbcEventLogger().log(selectString);
         long pk;
         try (ResultSet rs = statement.executeQuery(selectString)) {
@@ -172,7 +172,7 @@ public class MySQLPkGenerator extends JdbcPkGenerator {
         }
 
         // update
-        String updateString = super.pkUpdateString(entityName) + " AND NEXT_ID = " + pk;
+        String updateString = pkUpdateString(entityName) + " AND NEXT_ID = " + pk;
         adapter.getJdbcEventLogger().log(updateString);
         int updated = statement.executeUpdate(updateString);
         // optimistic lock failure...
