@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -20,14 +20,14 @@ package org.apache.cayenne.dba.mysql;
 
 import org.apache.cayenne.access.DataNode;
 import org.apache.cayenne.access.jdbc.SelectAction;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.Select;
 
 /**
  * @since 3.0
  */
 class MySQLSelectAction extends SelectAction {
 
-	<T> MySQLSelectAction(SelectQuery<T> query, DataNode dataNode) {
+	<T> MySQLSelectAction(Select<T> query, DataNode dataNode) {
 		super(query, dataNode);
 	}
 
