@@ -20,8 +20,10 @@ package org.apache.cayenne.dba.sqlite;
 
 import org.apache.cayenne.access.DataNode;
 import org.apache.cayenne.dba.JdbcActionBuilder;
+import org.apache.cayenne.query.FluentSelect;
 import org.apache.cayenne.query.SQLAction;
 import org.apache.cayenne.query.SQLTemplate;
+import org.apache.cayenne.query.SelectQuery;
 
 /**
  * @since 3.0
@@ -36,4 +38,20 @@ class SQLiteActionBuilder extends JdbcActionBuilder {
     public SQLAction sqlAction(SQLTemplate query) {
         return new SQLiteSQLTemplateAction(query, dataNode);
     }
+
+    /**
+     * @since 4.1
+     */
+    @Override
+    public <T> SQLAction objectSelectAction(SelectQuery<T> query) {
+        return new SQLiteSelectAction(query, dataNode);
+    }
+
+    /**
+     * @since 4.2
+     */
+    @Override
+    public <T> SQLAction objectSelectAction(FluentSelect<T> query) {
+        return new SQLiteSelectAction(query, dataNode);
+    }
 }
