@@ -21,9 +21,7 @@ package org.apache.cayenne.dba.sqlserver;
 
 import org.apache.cayenne.access.DataNode;
 import org.apache.cayenne.dba.JdbcActionBuilder;
-import org.apache.cayenne.query.BatchQuery;
-import org.apache.cayenne.query.ProcedureQuery;
-import org.apache.cayenne.query.SQLAction;
+import org.apache.cayenne.query.*;
 
 /**
  * @since 1.2
@@ -31,20 +29,36 @@ import org.apache.cayenne.query.SQLAction;
 public class SQLServerActionBuilder extends JdbcActionBuilder {
 
 	/**
+	 * Stores the major version of the database.
+	 *
+	 * @since 4.2
+	 */
+	private final Integer version;
+
+	/**
+	 * @param dataNode current data node
 	 * @since 4.0
 	 */
 	public SQLServerActionBuilder(DataNode dataNode) {
+		this(dataNode, null);
+	}
+
+	/**
+	 * @param dataNode current data node
+	 * @param version database server version
+	 * @since 4.2
+	 */
+	public SQLServerActionBuilder(DataNode dataNode, Integer version) {
 		super(dataNode);
+		this.version = version;
 	}
 
 	@Override
 	public SQLAction batchAction(BatchQuery query) {
 		// check run strategy...
 
-		// optimistic locking is not supported in batches due to JDBC driver
-		// limitations
+		// optimistic locking is not supported in batches due to JDBC driver limitations
 		boolean useOptimisticLock = query.isUsingOptimisticLocking();
-
 		boolean runningAsBatch = !useOptimisticLock && dataNode.getAdapter().supportsBatchUpdates();
 		return new SQLServerBatchAction(query, dataNode, runningAsBatch);
 	}
@@ -53,4 +67,30 @@ public class SQLServerActionBuilder extends JdbcActionBuilder {
 	public SQLAction procedureAction(ProcedureQuery query) {
 		return new SQLServerProcedureAction(query, dataNode);
 	}
+
+	/**
+	 * @since 4.2
+	 */
+	@Override
+	public <T> SQLAction objectSelectAction(SelectQuery<T> query) {
+		return new SQLServerSelectAction(query, dataNode, needInMemoryOffset(query));
+	}
+
+	/**
+	 * @since 4.2
+	 */
+	@Override
+	public <T> SQLAction objectSelectAction(FluentSelect<T> query) {
+		return new SQLServerSelectAction(query, dataNode, needInMemoryOffset(query));
+	}
+
+	private boolean needInMemoryOffset(SelectQuery<?> query) {
+		return query.getOrderings() == null || query.getOrderings().size() == 0
+				|| version == null || version < 12;
+	}
+
+	private boolean needInMemoryOffset(FluentSelect<?> query) {
+		return query.getOrderings() == null || query.getOrderings().size() == 0
+				|| version == null || version < 12;
+	}
 }
