@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -19,25 +19,23 @@
 
 package org.apache.cayenne.exp;
 
-import static org.apache.cayenne.exp.ExpressionFactory.exp;
-
 import java.io.IOException;
-import java.io.PrintWriter;
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.function.Function;
 
 import org.apache.cayenne.CayenneRuntimeException;
+import org.apache.cayenne.configuration.ConfigurationNodeVisitor;
 import org.apache.cayenne.exp.parser.ASTScalar;
 import org.apache.cayenne.util.ConversionUtil;
 import org.apache.cayenne.util.HashCodeBuilder;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.util.XMLEncoder;
 import org.apache.cayenne.util.XMLSerializable;
-import org.apache.commons.collections.Transformer;
 
 /**
  * Superclass of Cayenne expressions that defines basic API for expressions use.
@@ -166,20 +164,37 @@ public abstract class Expression implements Serializable, XMLSerializable {
 	 */
 	public static final int FULL_OBJECT = 47;
 
-	protected int type;
+	/**
+	 * @since 4.2
+	 */
+	public static final int ENCLOSING_OBJECT = 48;
 
 	/**
-	 * Parses string, converting it to Expression. If string does not represent
-	 * a semantically correct expression, an ExpressionException is thrown.
-	 * 
-	 * @since 1.1
-	 * @deprecated since 4.0 use
-	 *             {@link ExpressionFactory#exp(String, Object...)}
+	 * @since 4.2
 	 */
-	@Deprecated
-	public static Expression fromString(String expressionString) {
-		return exp(expressionString);
-	}
+	public static final int EXISTS = 49;
+
+	/**
+	 * @since 4.2
+	 */
+	public static final int NOT_EXISTS = 50;
+
+	/**
+	 * @since 4.2
+	 */
+	public static final int SUBQUERY = 51;
+
+	/**
+	 * @since 4.2
+	 */
+	public static final int DBID_PATH = 52;
+
+	/**
+	 * @since 4.2
+	 */
+	public static final int CUSTOM_OP = 53;
+
+	protected int type;
 
 	/**
 	 * Returns a map of path aliases for this expression. It returns a non-empty
@@ -348,45 +363,6 @@ public abstract class Expression implements Serializable, XMLSerializable {
 		return transform(new NamedParamTransformer(parameters, pruneMissing));
 	}
 
-	/**
-	 * A shortcut for <code>expWithParams(params, true)</code>.
-	 * 
-	 * @deprecated since 4.0 use {@link #params(Map)}
-	 */
-	@Deprecated
-	public Expression expWithParameters(Map<String, ?> parameters) {
-		return expWithParameters(parameters, true);
-	}
-
-	/**
-	 * Creates and returns a new Expression instance using this expression as a
-	 * prototype. All ExpressionParam operands are substituted with the values
-	 * in the <code>params</code> map.
-	 * <p>
-	 * <i>Null values in the <code>params</code> map should be explicitly
-	 * created in the map for the corresponding key. </i>
-	 * </p>
-	 * 
-	 * @param parameters
-	 *            a map of parameters, with each key being a string name of an
-	 *            expression parameter, and value being the value that should be
-	 *            used in the final expression.
-	 * @param pruneMissing
-	 *            If <code>true</code>, subexpressions that rely on missing
-	 *            parameters will be pruned from the resulting tree. If
-	 *            <code>false</code> , any missing values will generate an
-	 *            exception.
-	 * @return Expression resulting from the substitution of parameters with
-	 *         real values, or null if the whole expression was pruned, due to
-	 *         the missing parameters.
-	 * 
-	 * @deprecated since 4.0 use {@link #params(Map, boolean)} instead.
-	 */
-	@Deprecated
-	public Expression expWithParameters(Map<String, ?> parameters, boolean pruneMissing) {
-		return params(parameters, pruneMissing);
-	}
-
 	/**
 	 * Creates a new expression that joins this object with another expression,
 	 * using specified join type. It is very useful for incrementally building
@@ -515,7 +491,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 			return new LinkedList<>(); // returning Collections.emptyList() could cause random client exceptions if they try to mutate the resulting list
 		}
 
-		return (List<T>) filter(objects, new LinkedList<T>());
+		return (List<T>) filter(objects, new LinkedList<>());
 	}
 
 	/**
@@ -621,7 +597,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 	 * 
 	 * @since 1.1
 	 */
-	public Expression transform(Transformer transformer) {
+	public Expression transform(Function<Object, Object> transformer) {
 		Object transformed = transformExpression(transformer);
 
 		if (transformed == PRUNED_NODE || transformed == null) {
@@ -640,7 +616,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 	 * @return null, Expression.PRUNED_NODE or transformed expression.
 	 * @since 1.2
 	 */
-	protected Object transformExpression(Transformer transformer) {
+	protected Object transformExpression(Function<Object, Object> transformer) {
 		Expression copy = shallowCopy();
 		int count = getOperandCount();
 		for (int i = 0, j = 0; i < count; i++) {
@@ -650,7 +626,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 			if (operand instanceof Expression) {
 				transformedChild = ((Expression) operand).transformExpression(transformer);
 			} else if (transformer != null) {
-				transformedChild = transformer.transform(operand);
+				transformedChild = transformer.apply(operand);
 			} else {
 				transformedChild = operand;
 			}
@@ -671,7 +647,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 		}
 
 		// all the children are processed, only now transform this copy
-		return (transformer != null) ? transformer.transform(copy) : copy;
+		return (transformer != null) ? transformer.apply(copy) : copy;
 	}
 
 	/**
@@ -679,26 +655,17 @@ public abstract class Expression implements Serializable, XMLSerializable {
 	 * 
 	 * @since 1.1
 	 */
-	public void encodeAsXML(XMLEncoder encoder) {
-		encoder.print("<![CDATA[");
+	@Override
+	public void encodeAsXML(XMLEncoder encoder, ConfigurationNodeVisitor delegate) {
+		StringBuilder sb = new StringBuilder();
 		try {
-			appendAsString(encoder.getPrintWriter());
+			appendAsString(sb);
 		} catch (IOException e) {
 			throw new CayenneRuntimeException("Unexpected IO exception appending to PrintWriter", e);
 		}
-		encoder.print("]]>");
+		encoder.cdata(sb.toString(), true);
 	}
 
-	/**
-	 * Stores a String representation of Expression using a provided
-	 * PrintWriter.
-	 * 
-	 * @since 1.1
-	 * @deprecated since 4.0 use {@link #appendAsString(Appendable)}.
-	 */
-	@Deprecated
-	public abstract void encodeAsString(PrintWriter pw);
-
 	/**
 	 * Appends own content as a String to the provided Appendable.
 	 * 
@@ -707,17 +674,6 @@ public abstract class Expression implements Serializable, XMLSerializable {
 	 */
 	public abstract void appendAsString(Appendable out) throws IOException;
 
-	/**
-	 * Stores a String representation of Expression as EJBQL using a provided
-	 * PrintWriter. DB path expressions produce non-standard EJBQL path
-	 * expressions.
-	 * 
-	 * @since 3.0
-	 * @deprecated since 4.0 use {@link #appendAsEJBQL(Appendable, String)}
-	 */
-	@Deprecated
-	public abstract void encodeAsEJBQL(PrintWriter pw, String rootId);
-
 	/**
 	 * Stores a String representation of Expression as EJBQL using a provided
 	 * Appendable. DB path expressions produce non-standard EJBQL path
@@ -791,7 +747,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 		return toEJBQL(null, rootId);
 	}
 
-	final class NamedParamTransformer implements Transformer {
+	final class NamedParamTransformer implements Function<Object, Object> {
 
 		private Map<String, ?> parameters;
 		private boolean pruneMissing;
@@ -802,7 +758,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 		}
 
 		@Override
-		public Object transform(Object object) {
+		public Object apply(Object object) {
 			if (!(object instanceof ExpressionParameter)) {
 
 				// normally Object[] is an ASTList child
@@ -813,7 +769,7 @@ public abstract class Expression implements Serializable, XMLSerializable {
 					Object[] target = new Object[len];
 
 					for (int i = 0; i < len; i++) {
-						target[i] = transform(source[i]);
+						target[i] = apply(source[i]);
 					}
 
 					return target;
