@@ -29,9 +29,12 @@ import org.apache.cayenne.exp.parser.ASTBitwiseNot;
 import org.apache.cayenne.exp.parser.ASTBitwiseOr;
 import org.apache.cayenne.exp.parser.ASTBitwiseRightShift;
 import org.apache.cayenne.exp.parser.ASTBitwiseXor;
+import org.apache.cayenne.exp.parser.ASTDbIdPath;
 import org.apache.cayenne.exp.parser.ASTDbPath;
 import org.apache.cayenne.exp.parser.ASTDivide;
+import org.apache.cayenne.exp.parser.ASTEnclosingObject;
 import org.apache.cayenne.exp.parser.ASTEqual;
+import org.apache.cayenne.exp.parser.ASTExists;
 import org.apache.cayenne.exp.parser.ASTFalse;
 import org.apache.cayenne.exp.parser.ASTFullObject;
 import org.apache.cayenne.exp.parser.ASTGreater;
@@ -47,6 +50,7 @@ import org.apache.cayenne.exp.parser.ASTNegate;
 import org.apache.cayenne.exp.parser.ASTNot;
 import org.apache.cayenne.exp.parser.ASTNotBetween;
 import org.apache.cayenne.exp.parser.ASTNotEqual;
+import org.apache.cayenne.exp.parser.ASTNotExists;
 import org.apache.cayenne.exp.parser.ASTNotIn;
 import org.apache.cayenne.exp.parser.ASTNotLike;
 import org.apache.cayenne.exp.parser.ASTNotLikeIgnoreCase;
@@ -54,6 +58,7 @@ import org.apache.cayenne.exp.parser.ASTObjPath;
 import org.apache.cayenne.exp.parser.ASTOr;
 import org.apache.cayenne.exp.parser.ASTPath;
 import org.apache.cayenne.exp.parser.ASTScalar;
+import org.apache.cayenne.exp.parser.ASTSubquery;
 import org.apache.cayenne.exp.parser.ASTSubtract;
 import org.apache.cayenne.exp.parser.ASTTrue;
 import org.apache.cayenne.exp.parser.ExpressionParser;
@@ -61,6 +66,8 @@ import org.apache.cayenne.exp.parser.ExpressionParserTokenManager;
 import org.apache.cayenne.exp.parser.JavaCharStream;
 import org.apache.cayenne.exp.parser.SimpleNode;
 import org.apache.cayenne.map.Entity;
+import org.apache.cayenne.query.ColumnSelect;
+import org.apache.cayenne.query.FluentSelect;
 
 import java.io.Reader;
 import java.io.StringReader;
@@ -70,6 +77,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.function.Function;
 
 /**
  * Helper class to build expressions.
@@ -321,6 +329,14 @@ public class ExpressionFactory {
 			return new ASTTrue();
 		}
 
+		Function<Object, ASTPath> pathProvider;
+		if (path.startsWith(ASTDbPath.DB_PREFIX)) {
+			pathProvider = ASTDbPath::new;
+			path = path.substring(ASTDbPath.DB_PREFIX.length());
+		} else {
+			pathProvider = ASTObjPath::new;
+		}
+
 		int split = path.indexOf(SPLIT_SEPARATOR);
 
 		List<Expression> matches = new ArrayList<>(values.length);
@@ -329,7 +345,7 @@ public class ExpressionFactory {
 
 			int splitEnd = path.indexOf(Entity.PATH_SEPARATOR, split + 1);
 
-			String beforeSplit = split > 0 ? path.substring(0, split) + "." : "";
+			String beforeSplit = split > 0 ? path.substring(0, split) : "";
 			String afterSplit = splitEnd > 0 ? "." + path.substring(splitEnd + 1) : "";
 			String aliasBase = "split" + autoAliasId++ + "_";
 			String splitChunk = splitEnd > 0 ? path.substring(split + 1, splitEnd) : path.substring(split + 1);
@@ -346,13 +362,13 @@ public class ExpressionFactory {
 				String aliasedPath = beforeSplit + alias + afterSplit;
 				i++;
 
-				ASTPath pathExp = new ASTObjPath(aliasedPath);
+				ASTPath pathExp = pathProvider.apply(aliasedPath);
 				pathExp.setPathAliases(Collections.singletonMap(alias, splitChunk));
 				matches.add(new ASTEqual(pathExp, value));
 			}
 		} else {
 			for (Object value : values) {
-				matches.add(new ASTEqual(new ASTObjPath(path), value));
+				matches.add(new ASTEqual(pathProvider.apply(path), value));
 			}
 		}
 
@@ -384,7 +400,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#matchExp(String, Object)
 	 */
-	static Expression matchExp(Expression exp, Object value) {
+	public static Expression matchExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -402,13 +418,29 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#noMatchExp(String, Object)
 	 */
-	static Expression noMatchExp(Expression exp, Object value) {
+	public static Expression noMatchExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
 		return new ASTNotEqual((SimpleNode)exp, value);
 	}
 
+	/**
+	 * A convenience method to create an DBID_PATH "equal to" expression.
+	 * @since 4.2
+	 */
+	public static Expression matchDbIdExp(String pathSpec, Object value) {
+		return matchExp(new ASTDbIdPath(pathSpec), value);
+	}
+
+	/**
+	 * A convenience method to create an DBID_PATH "not equal to" expression.
+	 * @since 4.2
+	 */
+	public static Expression noMatchDbIdExp(String pathSpec, Object value) {
+		return noMatchExp(new ASTDbIdPath(pathSpec), value);
+	}
+
 	/**
 	 * A convenience method to create an OBJ_PATH "less than" expression.
 	 */
@@ -420,7 +452,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#lessExp(String, Object)
 	 */
-	static Expression lessExp(Expression exp, Object value) {
+	public static Expression lessExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -448,7 +480,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#lessOrEqualExp(String, Object)
 	 */
-	static Expression lessOrEqualExp(Expression exp, Object value) {
+	public static Expression lessOrEqualExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -476,7 +508,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#greaterExp(String, Object)
 	 */
-	static Expression greaterExp(Expression exp, Object value) {
+	public static Expression greaterExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -504,7 +536,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#greaterOrEqualExp(String, Object)
 	 */
-	static Expression greaterOrEqualExp(Expression exp, Object value) {
+	public static Expression greaterOrEqualExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -533,7 +565,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#inExp(String, Object[])
 	 */
-	static Expression inExp(Expression exp, Object... values) {
+	public static Expression inExp(Expression exp, Object... values) {
 		if (values.length == 0) {
 			return new ASTFalse();
 		}
@@ -562,11 +594,23 @@ public class ExpressionFactory {
 		return inExp(new ASTObjPath(pathSpec), values);
 	}
 
+	/**
+	 * A convenience shortcut for building IN DBID expression. Return ASTFalse for
+	 * empty collection.
+	 * @since 4.2
+	 */
+	public static Expression inDbIdExp(String pathSpec, Object... values) {
+		if (values.length == 0) {
+			return new ASTFalse();
+		}
+		return new ASTIn(new ASTDbIdPath(pathSpec), new ASTList(values));
+	}
+
 	/**
 	 * @since 4.0
 	 * @see ExpressionFactory#inExp(String, Collection)
 	 */
-	static Expression inExp(Expression exp, Collection<?> values) {
+	public static Expression inExp(Expression exp, Collection<?> values) {
 		if (values.isEmpty()) {
 			return new ASTFalse();
 		}
@@ -587,6 +631,18 @@ public class ExpressionFactory {
 		return new ASTIn(new ASTDbPath(pathSpec), new ASTList(values));
 	}
 
+	/**
+	 * A convenience shortcut for building IN DBID expression. Return ASTFalse for
+	 * empty collection.
+	 * @since 4.2
+	 */
+	public static Expression inDbIdExp(String pathSpec, Collection<?> values) {
+		if (values.isEmpty()) {
+			return new ASTFalse();
+		}
+		return new ASTIn(new ASTDbIdPath(pathSpec), new ASTList(values));
+	}
+
 	/**
 	 * A convenience shortcut for building NOT_IN expression. Return ASTTrue for
 	 * empty collection.
@@ -599,7 +655,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notInExp(String, Collection)
 	 */
-	static Expression notInExp(Expression exp, Collection<?> values) {
+	public static Expression notInExp(Expression exp, Collection<?> values) {
 		if (values.isEmpty()) {
 			return new ASTTrue();
 		}
@@ -622,6 +678,19 @@ public class ExpressionFactory {
 		return new ASTNotIn(new ASTDbPath(pathSpec), new ASTList(values));
 	}
 
+	/**
+	 * A convenience shortcut for building NOT_IN expression. Return ASTTrue for
+	 * empty collection.
+	 *
+	 * @since 4.2
+	 */
+	public static Expression notInDbIdExp(String pathSpec, Collection<?> values) {
+		if (values.isEmpty()) {
+			return new ASTTrue();
+		}
+		return new ASTNotIn(new ASTDbIdPath(pathSpec), new ASTList(values));
+	}
+
 	/**
 	 * A convenience shortcut for building NOT_IN expression. Return ASTTrue for
 	 * empty collection.
@@ -636,7 +705,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notInExp(String, Object[])
 	 */
-	static Expression notInExp(Expression exp, Object... values) {
+	public static Expression notInExp(Expression exp, Object... values) {
 		if (values.length == 0) {
 			return new ASTTrue();
 		}
@@ -659,6 +728,19 @@ public class ExpressionFactory {
 		return new ASTNotIn(new ASTDbPath(pathSpec), new ASTList(values));
 	}
 
+	/**
+	 * A convenience shortcut for building NOT_IN expression. Return ASTTrue for
+	 * empty collection.
+	 *
+	 * @since 4.2
+	 */
+	public static Expression notInDbIdExp(String pathSpec, Object... values) {
+		if (values.length == 0) {
+			return new ASTTrue();
+		}
+		return new ASTNotIn(new ASTDbIdPath(pathSpec), new ASTList(values));
+	}
+
 	/**
 	 * A convenience shortcut for building BETWEEN expressions.
 	 */
@@ -670,7 +752,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#betweenExp(String, Object, Object)
 	 */
-	static Expression betweenExp(Expression exp, Object value1, Object value2) {
+	public static Expression betweenExp(Expression exp, Object value1, Object value2) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -697,7 +779,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notBetweenExp(String, Object, Object)
 	 */
-	static Expression notBetweenExp(Expression exp, Object value1, Object value2) {
+	public static Expression notBetweenExp(Expression exp, Object value1, Object value2) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -724,7 +806,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#likeExp(String, Object)
 	 */
-	static Expression likeExp(Expression exp, Object value) {
+	public static Expression likeExp(Expression exp, Object value) {
 		return likeExpInternal(exp, value, (char) 0);
 	}
 
@@ -748,7 +830,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#likeExp(String, Object)
 	 */
-	static Expression likeExp(Expression exp, Object value, char escapeChar) {
+	public static Expression likeExp(Expression exp, Object value, char escapeChar) {
 		return likeExpInternal(exp, value, escapeChar);
 	}
 
@@ -799,7 +881,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notLikeExp(String, Object)
 	 */
-	static Expression notLikeExp(Expression exp, Object value) {
+	public static Expression notLikeExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -826,7 +908,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notLikeExp(String, Object)
 	 */
-	static Expression notLikeExp(Expression exp, Object value, char escapeChar) {
+	public static Expression notLikeExp(Expression exp, Object value, char escapeChar) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -869,7 +951,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#likeIgnoreCaseExp(String, Object)
 	 */
-	static Expression likeIgnoreCaseExp(Expression exp, Object value) {
+	public static Expression likeIgnoreCaseExp(Expression exp, Object value) {
 		return likeIgnoreCaseExp(exp, value, (char) 0);
 	}
 
@@ -936,7 +1018,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notLikeIgnoreCaseExp(String, Object)
 	 */
-	static Expression notLikeIgnoreCaseExp(Expression exp, Object value) {
+	public static Expression notLikeIgnoreCaseExp(Expression exp, Object value) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -963,7 +1045,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#notLikeIgnoreCaseExp(String, Object, char)
 	 */
-	static Expression notLikeIgnoreCaseExp(Expression exp, Object value, char escapeChar) {
+	public static Expression notLikeIgnoreCaseExp(Expression exp, Object value, char escapeChar) {
 		if(!(exp instanceof SimpleNode)) {
 			throw new IllegalArgumentException("exp should be instance of SimpleNode");
 		}
@@ -1010,7 +1092,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#containsExp(String, String)
 	 */
-	static Expression containsExp(Expression exp, String value) {
+	public static Expression containsExp(Expression exp, String value) {
 		ASTLike like = likeExpInternal(exp, value, (char) 0);
 		LikeExpressionHelper.toContains(like);
 		return like;
@@ -1031,7 +1113,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#startsWithExp(String, String)
 	 */
-	static Expression startsWithExp(Expression exp, String value) {
+	public static Expression startsWithExp(Expression exp, String value) {
 		ASTLike like = likeExpInternal(exp, value, (char) 0);
 		LikeExpressionHelper.toStartsWith(like);
 		return like;
@@ -1052,7 +1134,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#endsWithExp(String, String)
 	 */
-	static Expression endsWithExp(Expression exp, String value) {
+	public static Expression endsWithExp(Expression exp, String value) {
 		ASTLike like = likeExpInternal(exp, value, (char) 0);
 		LikeExpressionHelper.toEndsWith(like);
 		return like;
@@ -1074,7 +1156,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#containsIgnoreCaseExp(String, String)
 	 */
-	static Expression containsIgnoreCaseExp(Expression exp, String value) {
+	public static Expression containsIgnoreCaseExp(Expression exp, String value) {
 		ASTLikeIgnoreCase like = likeIgnoreCaseExp(exp, value, (char) 0);
 		LikeExpressionHelper.toContains(like);
 		return like;
@@ -1096,7 +1178,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#startsWithIgnoreCaseExp(String, String)
 	 */
-	static Expression startsWithIgnoreCaseExp(Expression exp, String value) {
+	public static Expression startsWithIgnoreCaseExp(Expression exp, String value) {
 		ASTLikeIgnoreCase like = likeIgnoreCaseExp(exp, value, (char) 0);
 		LikeExpressionHelper.toStartsWith(like);
 		return like;
@@ -1118,7 +1200,7 @@ public class ExpressionFactory {
 	 * @since 4.0
 	 * @see ExpressionFactory#endsWithIgnoreCaseExp(String, String)
 	 */
-	static Expression endsWithIgnoreCaseExp(Expression exp, String value) {
+	public static Expression endsWithIgnoreCaseExp(Expression exp, String value) {
 		ASTLikeIgnoreCase like = likeIgnoreCaseExp(exp, value, (char) 0);
 		LikeExpressionHelper.toEndsWith(like);
 		return like;
@@ -1142,6 +1224,15 @@ public class ExpressionFactory {
 		return new ASTDbPath(pathSpec);
 	}
 
+	/**
+	 * @param pathSpec a String "dbid:" path
+	 * @return a new "dbid:" path expressiob fofr the specified String path
+	 * @since 4.2
+	 */
+	public static Expression dbIdPathExp(String pathSpec) {
+		return new ASTDbIdPath(pathSpec);
+	}
+
 	/**
 	 * A convenience shortcut for boolean true expression.
 	 * 
@@ -1256,6 +1347,13 @@ public class ExpressionFactory {
 		return new ASTFullObject(exp);
 	}
 
+	/**
+	 * @since 4.2
+	 */
+	public static Expression enclosingObjectExp(Expression exp) {
+		return new ASTEnclosingObject(exp);
+	}
+
 	/**
 	 * @since 4.0
 	 */
@@ -1310,7 +1408,7 @@ public class ExpressionFactory {
 	 * Wrap value into ASTScalar
 	 * @since 4.0
 	 */
-	static Expression wrapScalarValue(Object value) {
+	public static Expression wrapScalarValue(Object value) {
 		return new ASTScalar(value);
 	}
 
@@ -1343,4 +1441,40 @@ public class ExpressionFactory {
 			throw new ExpressionException("%s", th, message != null ? message : "");
 		}
 	}
+
+	/**
+	 * @param subQuery {@link org.apache.cayenne.query.ObjectSelect} or {@link ColumnSelect}
+	 * @since 4.2
+	 */
+	public static Expression exists(FluentSelect<?> subQuery) {
+		return new ASTExists(new ASTSubquery(subQuery));
+	}
+
+	/**
+	 * @param subQuery {@link org.apache.cayenne.query.ObjectSelect} or {@link ColumnSelect}
+	 * @since 4.2
+	 */
+	public static Expression notExists(FluentSelect<?> subQuery) {
+		return new ASTNotExists(new ASTSubquery(subQuery));
+	}
+
+	/**
+	 * @since 4.2
+	 */
+	public static Expression inExp(Expression exp, ColumnSelect<?> subQuery) {
+		if(!(exp instanceof SimpleNode)) {
+			throw new IllegalArgumentException("exp should be instance of SimpleNode");
+		}
+		return new ASTIn((SimpleNode)exp, new ASTSubquery(subQuery));
+	}
+
+	/**
+	 * @since 4.2
+	 */
+	public static Expression notInExp(Expression exp, ColumnSelect<?> subQuery) {
+		if(!(exp instanceof SimpleNode)) {
+			throw new IllegalArgumentException("exp should be instance of SimpleNode");
+		}
+		return new ASTNotIn((SimpleNode)exp, new ASTSubquery(subQuery));
+	}
 }
