@@ -19,6 +19,8 @@
 
 package org.apache.cayenne.exp.parser;
 
+import java.util.Collection;
+
 import org.apache.cayenne.exp.Expression;
 
 /**
@@ -42,4 +44,9 @@ public class ASTCount extends ASTAggregateFunctionCall {
     public Expression shallowCopy() {
         return new ASTCount(id);
     }
+
+    @Override
+    protected Object evaluateCollection(Collection<?> values) {
+        return values.size();
+    }
 }
