@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -19,6 +19,9 @@
 
 package org.apache.cayenne.exp.parser;
 
+import java.util.Collection;
+import java.util.Collections;
+
 import org.apache.cayenne.exp.Expression;
 
 /**
@@ -38,4 +41,10 @@ public class ASTMax extends ASTAggregateFunctionCall {
     public Expression shallowCopy() {
         return new ASTMax(id);
     }
+
+    @SuppressWarnings({"rawtypes", "unchecked"})
+    @Override
+    protected Object evaluateCollection(Collection<?> values) {
+        return Collections.max((Collection)values);
+    }
 }
