@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -32,7 +32,8 @@ import org.apache.cayenne.map.event.ObjEntityListener;
 import org.apache.cayenne.util.CayenneMapEntry;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.util.XMLEncoder;
-import org.apache.commons.collections.Transformer;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -43,8 +44,8 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.SortedMap;
 import java.util.TreeMap;
+import java.util.function.Function;
 
 /**
  * ObjEntity is a mapping descriptor for a DataObject Java class. It contains
@@ -53,11 +54,12 @@ import java.util.TreeMap;
  */
 public class ObjEntity extends Entity implements ObjEntityListener, ConfigurationNode {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(ObjEntity.class);
+
     public static final int LOCK_TYPE_NONE = 0;
     public static final int LOCK_TYPE_OPTIMISTIC = 1;
 
-    // do not import CayenneDataObject as it introduces unneeded client
-    // dependency
+    // do not import CayenneDataObject as it introduces unneeded client dependency
     private static final String CAYENNE_DATA_OBJECT_CLASS = "org.apache.cayenne.CayenneDataObject";
     /**
      * A collection of default "generic" entity classes excluded from class
@@ -80,16 +82,8 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
     protected String clientClassName;
     protected String clientSuperClassName;
 
-    @Deprecated
-    protected List<EntityListener> entityListeners;
     protected CallbackMap callbacks;
 
-    @Deprecated
-    protected boolean excludingDefaultListeners;
-
-    @Deprecated
-    protected boolean excludingSuperclassListeners;
-
     protected Map<String, String> attributeOverrides;
 
     public ObjEntity() {
@@ -100,7 +94,6 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
         setName(name);
         this.lockType = LOCK_TYPE_NONE;
         this.callbacks = new CallbackMap();
-        this.entityListeners = new ArrayList<>(2);
         this.attributeOverrides = new TreeMap<>();
     }
 
@@ -118,103 +111,72 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
      * @since 1.1
      */
     @Override
-    public void encodeAsXML(XMLEncoder encoder) {
-        encoder.print("<obj-entity name=\"");
-        encoder.print(getName());
+    public void encodeAsXML(XMLEncoder encoder, ConfigurationNodeVisitor delegate) {
+        encoder.start("obj-entity").attribute("name", getName());
 
-        // additionally validate that superentity exists
+        // additionally validate that super entity exists
         if (getSuperEntityName() != null && getSuperEntity() != null) {
-            encoder.print("\" superEntityName=\"");
-            encoder.print(getSuperEntityName());
+            encoder.attribute("superEntityName", getSuperEntityName());
         }
 
-        if (isAbstract()) {
-            encoder.print("\" abstract=\"true");
-        }
-
-        if (isServerOnly()) {
-            encoder.print("\" serverOnly=\"true");
-        }
-
-        if (getClassName() != null) {
-            encoder.print("\" className=\"");
-            encoder.print(getClassName());
-        }
-
-        if (getClientClassName() != null) {
-            encoder.print("\" clientClassName=\"");
-            encoder.print(getClientClassName());
-        }
-
-        if (isReadOnly()) {
-            encoder.print("\" readOnly=\"true");
-        }
+        encoder.attribute("abstract", isAbstract())
+                .attribute("serverOnly", isServerOnly())
+                .attribute("className", getClassName())
+                .attribute("clientClassName", getClientClassName())
+                .attribute("readOnly", isReadOnly());
 
         if (getDeclaredLockType() == LOCK_TYPE_OPTIMISTIC) {
-            encoder.print("\" lock-type=\"optimistic");
+            encoder.attribute("lock-type", "optimistic");
         }
 
         if (getDbEntityName() != null && getDbEntity() != null) {
-
             // not writing DbEntity name if sub entity has same DbEntity
             // as super entity, see CAY-1477
             if (!(getSuperEntity() != null && getSuperEntity().getDbEntity() == getDbEntity())) {
-                encoder.print("\" dbEntityName=\"");
-                encoder.print(Util.encodeXmlAttribute(getDbEntityName()));
+                encoder.attribute("dbEntityName", getDbEntityName());
             }
         }
 
         if (getSuperEntityName() == null && getSuperClassName() != null) {
-            encoder.print("\" superClassName=\"");
-            encoder.print(getSuperClassName());
+            encoder.attribute("superClassName", getSuperClassName());
         }
 
         if (getSuperEntityName() == null && getClientSuperClassName() != null) {
-            encoder.print("\" clientSuperClassName=\"");
-            encoder.print(getClientSuperClassName());
+            encoder.attribute("clientSuperClassName", getClientSuperClassName());
         }
 
-        // deprecated
-        if (isExcludingSuperclassListeners()) {
-            encoder.print("\" exclude-superclass-listeners=\"true");
-        }
-
-        // deprecated
-        if (isExcludingDefaultListeners()) {
-            encoder.print("\" exclude-default-listeners=\"true");
-        }
-
-        encoder.println("\">");
-        encoder.indent(1);
-
         if (qualifier != null) {
-            encoder.print("<qualifier>");
-            qualifier.encodeAsXML(encoder);
-            encoder.println("</qualifier>");
+            encoder.start("qualifier").nested(qualifier, delegate).end();
         }
 
+        // divide attributes by type
+        TreeMap<String, Attribute> embAttributes = new TreeMap<>();
+        TreeMap<String, Attribute> objAttributes = new TreeMap<>();
+
+        attributes.forEach((key, value) -> {
+            if (value instanceof EmbeddedAttribute) {
+                embAttributes.put(key, value);
+            } else {
+                objAttributes.put(key, value);
+            }
+        });
+
         // store attributes
-        encoder.print(getDeclaredAttributes());
+        encoder.nested(embAttributes, delegate);
+        encoder.nested(objAttributes, delegate);
 
         for (Map.Entry<String, String> override : attributeOverrides.entrySet()) {
-            encoder.print("<attribute-override name=\"" + override.getKey() + '\"');
-            encoder.print(" db-attribute-path=\"");
-            encoder.print(Util.encodeXmlAttribute(override.getValue()));
-            encoder.print('\"');
-            encoder.println("/>");
-        }
-
-        // deprecated
-        // write entity listeners
-        for (EntityListener entityListener : entityListeners) {
-            entityListener.encodeAsXML(encoder);
+            encoder.start("attribute-override")
+                    .attribute("name", override.getKey())
+                    .attribute("db-attribute-path", override.getValue())
+                    .end();
         }
 
         // write entity-level callbacks
         getCallbackMap().encodeCallbacksAsXML(encoder);
 
-        encoder.indent(-1);
-        encoder.println("</obj-entity>");
+        delegate.visitObjEntity(this);
+        encoder.end();
     }
 
     /**
@@ -322,75 +284,6 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
         }
     }
 
-    /**
-     * Returns an unmodifiable list of registered {@link EntityListener}
-     * objects. Note that since the order of listeners is significant a list,
-     * not just a generic Collection is returned.
-     * 
-     * @since 3.0
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public List<EntityListener> getEntityListeners() {
-        return Collections.unmodifiableList(entityListeners);
-    }
-
-    /**
-     * Adds a new EntityListener.
-     * 
-     * @since 3.0
-     * @throws IllegalArgumentException
-     *             if a listener for the same class name is already registered.
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public void addEntityListener(EntityListener listener) {
-        for (EntityListener next : entityListeners) {
-            if (listener.getClassName().equals(next.getClassName())) {
-                throw new IllegalArgumentException("Duplicate listener for " + next.getClassName());
-            }
-        }
-
-        entityListeners.add(listener);
-    }
-
-    /**
-     * Removes a listener matching class name.
-     * 
-     * @since 3.0
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public void removeEntityListener(String className) {
-        Iterator<EntityListener> it = entityListeners.iterator();
-        while (it.hasNext()) {
-            EntityListener next = it.next();
-            if (className.equals(next.getClassName())) {
-                it.remove();
-                break;
-            }
-        }
-    }
-
-    /**
-     * @since 3.0
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public EntityListener getEntityListener(String className) {
-        for (EntityListener next : entityListeners) {
-            if (className.equals(next.getClassName())) {
-                return next;
-            }
-        }
-
-        return null;
-    }
-
     /**
      * Returns an object that stores callback methods of this entity.
      * 
@@ -678,7 +571,7 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
             if (attribute == null) {
                 attribute = new SyntheticPKObjAttribute(Util.underscoredToJava(pk.getName(), false));
                 attribute.setDbAttributePath(pk.getName());
-                attribute.setType(TypesMapping.getJavaBySqlType(pk.getType()));
+                attribute.setType(TypesMapping.getJavaBySqlType(pk));
             }
 
             attributes.add(attribute);
@@ -736,16 +629,16 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
     }
 
     /**
-     * Returns a SortedMap of all attributes that either belong to this
+     * Returns a Map of all attributes that either belong to this
      * ObjEntity or inherited.
      */
     @Override
-    public SortedMap<String, ObjAttribute> getAttributeMap() {
+    public Map<String, ObjAttribute> getAttributeMap() {
         if (superEntityName == null) {
             return getAttributeMapInternal();
         }
 
-        SortedMap<String, ObjAttribute> attributeMap = new TreeMap<>();
+        Map<String, ObjAttribute> attributeMap = new HashMap<>();
         appendAttributes(attributeMap);
         return attributeMap;
     }
@@ -758,25 +651,37 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
 
         ObjEntity superEntity = getSuperEntity();
         if (superEntity != null) {
-            SortedMap<String, ObjAttribute> attributeMap = new TreeMap<>();
+            Map<String, ObjAttribute> attributeMap = new HashMap<>();
             superEntity.appendAttributes(attributeMap);
             for (String attributeName : attributeMap.keySet()) {
 
                 String overridedDbPath = attributeOverrides.get(attributeName);
 
-                ObjAttribute attribute = new ObjAttribute(attributeMap.get(attributeName));
-                attribute.setEntity(this);
-                if (overridedDbPath != null) {
-                    attribute.setDbAttributePath(overridedDbPath);
+                ObjAttribute superAttribute = attributeMap.get(attributeName);
+                ObjAttribute attribute;
+
+                if(superAttribute instanceof EmbeddedAttribute) {
+                    EmbeddedAttribute embeddedAttribute = new EmbeddedAttribute((EmbeddedAttribute)superAttribute);
+                    if(overridedDbPath != null) {
+                        LOGGER.warn("'{}.{}': DB path override for an embedded attribute is not supported.",
+                                getName(), attributeName);
+                    }
+                    attribute = embeddedAttribute;
+                } else {
+                    attribute = new ObjAttribute(superAttribute);
+                    if (overridedDbPath != null) {
+                        attribute.setDbAttributePath(overridedDbPath);
+                    }
                 }
+                attribute.setEntity(this);
                 map.put(attributeName, attribute);
             }
         }
     }
 
     @SuppressWarnings("unchecked")
-    final SortedMap<String, ObjAttribute> getAttributeMapInternal() {
-        return (SortedMap<String, ObjAttribute>) super.getAttributeMap();
+    final Map<String, ObjAttribute> getAttributeMapInternal() {
+        return (Map<String, ObjAttribute>) super.getAttributeMap();
     }
 
     /**
@@ -855,12 +760,12 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
     }
 
     @Override
-    public SortedMap<String, ObjRelationship> getRelationshipMap() {
+    public Map<String, ObjRelationship> getRelationshipMap() {
         if (superEntityName == null) {
             return getRelationshipMapInternal();
         }
 
-        SortedMap<String, ObjRelationship> relationshipMap = new TreeMap<>();
+        Map<String, ObjRelationship> relationshipMap = new HashMap<>();
         appendRelationships(relationshipMap);
         return relationshipMap;
     }
@@ -884,8 +789,8 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
     }
 
     @SuppressWarnings("unchecked")
-    final SortedMap<String, ObjRelationship> getRelationshipMapInternal() {
-        return (SortedMap<String, ObjRelationship>) super.getRelationshipMap();
+    final Map<String, ObjRelationship> getRelationshipMapInternal() {
+        return (Map<String, ObjRelationship>) super.getRelationshipMap();
     }
 
     /**
@@ -1126,15 +1031,14 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
 
         DBPathConverter transformer = new DBPathConverter();
 
-        String dbPath = transformer.toDbPath(createPathIterator(relationshipPath));
+        String dbPath = transformer.toDbPath(createPathIterator(relationshipPath, expression.getPathAliases()));
         Expression dbClone = expression.transform(transformer);
 
         return getDbEntity().translateToRelatedEntity(dbClone, dbPath);
     }
 
-    private PathComponentIterator createPathIterator(String path) {
-        return new PathComponentIterator(ObjEntity.this, path, new HashMap<String, String>());
-        // TODO: do we need aliases here?
+    private PathComponentIterator createPathIterator(String path, Map<String, String> aliasMap) {
+        return new PathComponentIterator(ObjEntity.this, path, aliasMap);
     }
 
     /**
@@ -1148,7 +1052,7 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
         return res;
     }
 
-    final class DBPathConverter implements Transformer {
+    final class DBPathConverter implements Function<Object, Object> {
 
         // TODO: make it a public method - resolveDBPathComponents or
         // something...
@@ -1160,34 +1064,44 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
                 PathComponent<Attribute, Relationship> component = objectPathComponents.next();
 
                 Iterator<?> dbSubpath;
-
-                if (component.getAttribute() != null) {
+                if(component.getAttribute() != null) {
                     dbSubpath = ((ObjAttribute) component.getAttribute()).getDbPathIterator();
-                } else if (component.getRelationship() != null) {
+                    buildPath(dbSubpath, component, buf);
+                } else if(component.getRelationship() != null) {
                     dbSubpath = ((ObjRelationship) component.getRelationship()).getDbRelationships().iterator();
+                    buildPath(dbSubpath, component, buf);
+                } else if(component.getAliasedPath() != null) {
+                    for(PathComponent<Attribute, Relationship> pathComponent : component.getAliasedPath()) {
+                       if(pathComponent.getRelationship() != null) {
+                           dbSubpath = ((ObjRelationship) pathComponent.getRelationship()).getDbRelationships().iterator();
+                           buildPath(dbSubpath, pathComponent, buf);
+                       }
+                    }
                 } else {
                     throw new CayenneRuntimeException("Unknown path component: %s", component);
                 }
-
-                while (dbSubpath.hasNext()) {
-                    CayenneMapEntry subComponent = (CayenneMapEntry) dbSubpath.next();
-                    if (buf.length() > 0) {
-                        buf.append(Entity.PATH_SEPARATOR);
-                    }
-
-                    buf.append(subComponent.getName());
-                    
-                    // use OUTER join for all components of the path is Obj path is OUTER
-                    if (component.getJoinType() == JoinType.LEFT_OUTER) {
-                        buf.append(OUTER_JOIN_INDICATOR);
-                    }
-                }
             }
 
             return buf.toString();
         }
 
-        public Object transform(Object input) {
+        private void buildPath(Iterator<?> dbSubpath, PathComponent<Attribute, Relationship> component, StringBuilder buf) {
+            while (dbSubpath.hasNext()) {
+                CayenneMapEntry subComponent = (CayenneMapEntry) dbSubpath.next();
+                if (buf.length() > 0) {
+                    buf.append(Entity.PATH_SEPARATOR);
+                }
+
+                buf.append(subComponent.getName());
+
+                // use OUTER join for all components of the path is Obj path is OUTER
+                if (component.getJoinType() == JoinType.LEFT_OUTER) {
+                    buf.append(OUTER_JOIN_INDICATOR);
+                }
+            }
+        }
+
+        public Object apply(Object input) {
 
             if (!(input instanceof Expression)) {
                 return input;
@@ -1200,11 +1114,8 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
             }
 
             // convert obj_path to db_path
-
-            String converted = toDbPath(createPathIterator((String) expression.getOperand(0)));
-            Expression exp = ExpressionFactory.expressionOfType(Expression.DB_PATH);
-            exp.setOperand(0, converted);
-            return exp;
+            String converted = toDbPath(createPathIterator((String) expression.getOperand(0), expression.getPathAliases()));
+            return ExpressionFactory.dbPathExp(converted);
         }
     }
 
@@ -1267,47 +1178,4 @@ public class ObjEntity extends Entity implements ObjEntityListener, Configuratio
         // does nothing currently
     }
 
-    /**
-     * Returns true if the default lifecycle listeners should not be notified of
-     * this entity lifecycle events.
-     * 
-     * @since 3.0
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public boolean isExcludingDefaultListeners() {
-        return excludingDefaultListeners;
-    }
-
-    /**
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public void setExcludingDefaultListeners(boolean excludingDefaultListeners) {
-        this.excludingDefaultListeners = excludingDefaultListeners;
-    }
-
-    /**
-     * Returns true if the lifeycle listeners defined on the superclasses should
-     * not be notified of this entity lifecycle events.
-     * 
-     * @since 3.0
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public boolean isExcludingSuperclassListeners() {
-        return excludingSuperclassListeners;
-    }
-
-    /**
-     * @deprecated since 4.0 unused, as listeners are no longer mapped in a
-     *             DataMap.
-     */
-    @Deprecated
-    public void setExcludingSuperclassListeners(boolean excludingSuperclassListeners) {
-        this.excludingSuperclassListeners = excludingSuperclassListeners;
-    }
 }
