@@ -19,6 +19,12 @@
 
 package org.apache.cayenne.map;
 
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Iterator;
+import java.util.List;
+import java.util.ListIterator;
+
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.configuration.ConfigurationNode;
 import org.apache.cayenne.configuration.ConfigurationNodeVisitor;
@@ -29,12 +35,6 @@ import org.apache.cayenne.util.ToStringBuilder;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.util.XMLEncoder;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.Iterator;
-import java.util.List;
-import java.util.ListIterator;
-
 /**
  * Describes an association between two Java classes mapped as source and target
  * ObjEntity. Maps to a path of DbRelationships.
@@ -193,11 +193,11 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
             return null;
         }
 
-        Entity source = getSourceEntity();
+        ObjEntity source = getSourceEntity();
 
         for (ObjRelationship relationship : target.getRelationships()) {
-
-            if (relationship.getTargetEntity() != source) {
+            ObjEntity maybeSameSource = relationship.getTargetEntity();
+            if (maybeSameSource != source && !source.isSubentityOf(maybeSameSource)) {
                 continue;
             }
 
@@ -272,7 +272,6 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
 
         dbRelationships.add(dbRel);
 
-        this.recalculateReadOnlyValue();
         this.recalculateToManyValue();
     }
 
@@ -283,7 +282,6 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
     public void removeDbRelationship(DbRelationship dbRel) {
         refreshFromDeferredPath();
         if (dbRelationships.remove(dbRel)) {
-            this.recalculateReadOnlyValue();
             this.recalculateToManyValue();
         }
     }
@@ -308,10 +306,9 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
             return true;
         }
 
-        // entities with qualifiers may result in filtering even existing target
-        // rows, so
-        // such relationships are optional
-        if (isQualifiedEntity((ObjEntity) getTargetEntity())) {
+        // entities with qualifiers may result in filtering even existing target rows,
+        // so such relationships are optional
+        if (isQualifiedEntity(getTargetEntity())) {
             return true;
         }
 
@@ -419,7 +416,6 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
      */
     public boolean isReadOnly() {
         refreshFromDeferredPath();
-        recalculateReadOnlyValue();
         return readOnly;
     }
 
@@ -591,7 +587,7 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
             return null;
         }
 
-        ObjEntity entity = (ObjEntity) getSourceEntity();
+        ObjEntity entity = getSourceEntity();
         if (entity == null) {
             throw new CayenneRuntimeException("Can't resolve DbRelationships, null source ObjEntity");
         }
@@ -628,7 +624,7 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
 
             if (dbRelationshipPath != null) {
 
-                ObjEntity entity = (ObjEntity) getSourceEntity();
+                ObjEntity entity = getSourceEntity();
                 if (entity == null) {
                     throw new CayenneRuntimeException("Can't resolve DbRelationships, null source ObjEntity");
                 }
@@ -650,7 +646,6 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
             }
 
             recalculateToManyValue();
-            recalculateReadOnlyValue();
     }
 
     /**
@@ -675,7 +670,9 @@ public class ObjRelationship extends Relationship implements ConfigurationNode {
     /**
      * Recalculates a new readonly value based on the underlying
      * DbRelationships.
+     * @deprecated since 4.2
      */
+    @Deprecated
     public void recalculateReadOnlyValue() {
         // not flattened, always read/write
         if (dbRelationships.size() < 2) {
