@@ -24,11 +24,16 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.function.Function;
 
 import org.apache.cayenne.ObjectContext;
+import org.apache.cayenne.exp.property.BaseProperty;
 import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
-import org.apache.cayenne.exp.Property;
+import org.apache.cayenne.exp.property.ComparableProperty;
+import org.apache.cayenne.exp.property.NumericProperty;
+import org.apache.cayenne.exp.property.Property;
+import org.apache.cayenne.exp.property.PropertyFactory;
 import org.apache.cayenne.map.DbEntity;
 import org.apache.cayenne.map.EntityResolver;
 import org.apache.cayenne.map.ObjEntity;
@@ -63,46 +68,25 @@ import org.apache.cayenne.map.ObjEntity;
 public class ColumnSelect<T> extends FluentSelect<T> {
 
     private Collection<Property<?>> columns;
-    private boolean havingExpressionIsActive = false;
     // package private for tests
     boolean singleColumn = true;
-    private Expression having;
-    boolean distinct;
-    boolean suppressDistinct;
+
+    ColumnSelectMetadata metaData = new ColumnSelectMetadata();
 
     protected ColumnSelect() {
-        super();
     }
 
     /**
      * Copy constructor to convert ObjectSelect to ColumnSelect
      */
     protected ColumnSelect(ObjectSelect<T> select) {
-        super();
-        this.name = select.name;
         this.entityType = select.entityType;
         this.entityName = select.entityName;
         this.dbEntityName = select.dbEntityName;
         this.where = select.where;
+        this.having = select.having;
         this.orderings = select.orderings;
-        this.prefetches = select.prefetches;
-        this.limit = select.limit;
-        this.offset = select.offset;
-        this.pageSize = select.pageSize;
-        this.statementFetchSize = select.statementFetchSize;
-        this.cacheStrategy = select.cacheStrategy;
-        this.cacheGroup = select.cacheGroup;
-    }
-
-    @Override
-    protected Query createReplacementQuery(EntityResolver resolver) {
-        SelectQuery<?> replacement = (SelectQuery)super.createReplacementQuery(resolver);
-        replacement.setColumns(columns);
-        replacement.setHavingQualifier(having);
-        replacement.setCanReturnScalarValue(singleColumn);
-        replacement.setDistinct(distinct);
-        replacement.setSuppressDistinct(suppressDistinct);
-        return replacement;
+        this.metaData.copyFromInfo(select.metaData);
     }
 
     /**
@@ -137,12 +121,10 @@ public class ColumnSelect<T> extends FluentSelect<T> {
         return resetEntity(null, null, dbEntityName);
     }
 
-    @SuppressWarnings("unchecked")
     private ColumnSelect<T> resetEntity(Class<?> entityType, String entityName, String dbEntityName) {
         this.entityType = entityType;
         this.entityName = entityName;
         this.dbEntityName = dbEntityName;
-        this.replacementQuery = null;
         return this;
     }
 
@@ -185,7 +167,6 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      *
      * @return this object
      */
-    @SuppressWarnings("unchecked")
     public ColumnSelect<T> or(Expression... expressions) {
         if (expressions == null || expressions.length == 0) {
             return this;
@@ -233,7 +214,6 @@ public class ColumnSelect<T> extends FluentSelect<T> {
         }
 
         Collections.addAll(this.orderings, orderings);
-        replacementQuery = null;
         return this;
     }
 
@@ -253,7 +233,6 @@ public class ColumnSelect<T> extends FluentSelect<T> {
         }
 
         this.orderings.addAll(orderings);
-        replacementQuery = null;
         return this;
     }
 
@@ -263,17 +242,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * @return this object
      */
     public ColumnSelect<T> prefetch(PrefetchTreeNode prefetch) {
-
-        if (prefetch == null) {
-            return this;
-        }
-
-        if (prefetches == null) {
-            prefetches = new PrefetchTreeNode();
-        }
-
-        prefetches.merge(prefetch);
-        replacementQuery = null;
+        metaData.mergePrefetch(prefetch);
         return this;
     }
 
@@ -284,17 +253,10 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * @return this object
      */
     public ColumnSelect<T> prefetch(String path, int semantics) {
-
         if (path == null) {
             return this;
         }
-
-        if (prefetches == null) {
-            prefetches = new PrefetchTreeNode();
-        }
-
-        prefetches.addPath(path).setSemantics(semantics);
-        replacementQuery = null;
+        metaData.addPrefetch(path, semantics);
         return this;
     }
 
@@ -303,11 +265,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * that should be ever be fetched from the database.
      */
     public ColumnSelect<T> limit(int fetchLimit) {
-        if (this.limit != fetchLimit) {
-            this.limit = fetchLimit;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setFetchLimit(fetchLimit);
         return this;
     }
 
@@ -316,11 +274,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * should be skipped when reading data from the database.
      */
     public ColumnSelect<T> offset(int fetchOffset) {
-        if (this.offset != fetchOffset) {
-            this.offset = fetchOffset;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setFetchOffset(fetchOffset);
         return this;
     }
 
@@ -330,11 +284,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * parts of the result are ever going to be accessed.
      */
     public ColumnSelect<T> pageSize(int pageSize) {
-        if (this.pageSize != pageSize) {
-            this.pageSize = pageSize;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setPageSize(pageSize);
         return this;
     }
 
@@ -345,25 +295,22 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * @see Statement#setFetchSize(int)
      */
     public ColumnSelect<T> statementFetchSize(int size) {
-        if (this.statementFetchSize != size) {
-            this.statementFetchSize = size;
-            this.replacementQuery = null;
-        }
+        this.metaData.setStatementFetchSize(size);
+        return this;
+    }
 
+    /**
+     * Sets query timeout of PreparedStatement generated for this query.
+     * @see Statement#setQueryTimeout(int)
+     */
+    public ColumnSelect<T> queryTimeout(int timeout) {
+        this.metaData.setQueryTimeout(timeout);
         return this;
     }
 
     public ColumnSelect<T> cacheStrategy(QueryCacheStrategy strategy) {
-        if (this.cacheStrategy != strategy) {
-            this.cacheStrategy = strategy;
-            this.replacementQuery = null;
-        }
-
-        if(this.cacheGroup != null) {
-            this.cacheGroup = null;
-            this.replacementQuery = null;
-        }
-
+        setCacheStrategy(strategy);
+        setCacheGroup(null);
         return this;
     }
 
@@ -372,8 +319,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
     }
 
     public ColumnSelect<T> cacheGroup(String cacheGroup) {
-        this.cacheGroup = cacheGroup;
-        this.replacementQuery = null;
+        setCacheGroup(cacheGroup);
         return this;
     }
 
@@ -438,20 +384,20 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * }
      * </pre>
      *
-     * @param firstProperty first property
-     * @param otherProperties array of properties to select
+     * @param properties array of properties to select
      * @see ColumnSelect#column(Property)
      * @see ColumnSelect#columns(Collection)
      */
     @SuppressWarnings("unchecked")
-    public ColumnSelect<Object[]> columns(Property<?> firstProperty, Property<?>... otherProperties) {
-        if (columns == null) {
-            columns = new ArrayList<>(otherProperties.length + 1);
+    public ColumnSelect<Object[]> columns(Property<?>... properties) {
+        if (properties.length == 0) {
+            throw new IllegalArgumentException("properties must contain at least one element");
         }
-        columns.add(firstProperty);
-        Collections.addAll(columns, otherProperties);
+        if (columns == null) {
+            columns = new ArrayList<>(properties.length);
+        }
+        Collections.addAll(columns, properties);
         singleColumn = false;
-        replacementQuery = null;
         return (ColumnSelect<Object[]>)this;
     }
 
@@ -461,7 +407,7 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * (root entity properties, function call expressions, properties of relationships, etc).</p>
      * <p>
      * @param properties collection of properties, <b>must</b> contain at least one element
-     * @see ColumnSelect#columns(Property, Property[])
+     * @see ColumnSelect#columns(Property[])
      */
     @SuppressWarnings("unchecked")
     public ColumnSelect<Object[]> columns(Collection<Property<?>> properties) {
@@ -478,7 +424,6 @@ public class ColumnSelect<T> extends FluentSelect<T> {
 
         columns.addAll(properties);
         singleColumn = false;
-        replacementQuery = null;
         return (ColumnSelect<Object[]>)this;
     }
 
@@ -490,15 +435,14 @@ public class ColumnSelect<T> extends FluentSelect<T> {
             this.columns.clear(); // if we don't clear then return type will be incorrect
         }
         this.columns.add(property);
-        this.replacementQuery = null;
         return (ColumnSelect<E>) this;
     }
 
     /**
-     * <p>Shortcut for {@link #columns(Property, Property[])} columns}(Property.COUNT)</p>
+     * <p>Shortcut for {@link #columns(Property[])} columns}(Property.COUNT)</p>
      */
     public ColumnSelect<Object[]> count() {
-        return columns(Property.COUNT);
+        return columns(PropertyFactory.COUNT);
     }
 
     /**
@@ -506,39 +450,59 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * <p>Can return different result than COUNT(*) as it will count only non null values</p>
      * @see ColumnSelect#count()
      */
-    public ColumnSelect<Object[]> count(Property<?> property) {
+    public ColumnSelect<Object[]> count(BaseProperty<?> property) {
         return columns(property.count());
     }
 
     /**
      * <p>Select minimum value of property</p>
-     * @see ColumnSelect#columns(Property, Property[])
+     * @see ColumnSelect#columns(Property[])
      */
-    public ColumnSelect<Object[]> min(Property<?> property) {
+    public ColumnSelect<Object[]> min(ComparableProperty<?> property) {
         return columns(property.min());
     }
 
     /**
      * <p>Select maximum value of property</p>
-     * @see ColumnSelect#columns(Property, Property[])
+     * @see ColumnSelect#columns(Property[])
      */
-    public ColumnSelect<Object[]> max(Property<?> property) {
+    public ColumnSelect<Object[]> max(ComparableProperty<?> property) {
         return columns(property.max());
     }
 
     /**
      * <p>Select average value of property</p>
-     * @see ColumnSelect#columns(Property, Property[])
+     * @see ColumnSelect#columns(Property[])
+     * @deprecated since 4.2 use {@link #avg(NumericProperty)}
      */
-    public ColumnSelect<Object[]> avg(Property<?> property) {
+    @Deprecated
+    public ColumnSelect<Object[]> avg(org.apache.cayenne.exp.Property<?> property) {
+        return columns(property.avg());
+    }
+
+    /**
+     * <p>Select average value of property</p>
+     * @see ColumnSelect#columns(Property[])
+     */
+    public ColumnSelect<Object[]> avg(NumericProperty<?> property) {
         return columns(property.avg());
     }
 
     /**
      * <p>Select sum of values</p>
-     * @see ColumnSelect#columns(Property, Property[])
+     * @see ColumnSelect#columns(Property[])
+     * @deprecated since 4.2 use {@link #sum(NumericProperty)}
      */
-    public <E extends Number> ColumnSelect<Object[]> sum(Property<E> property) {
+    @Deprecated
+    public <E extends Number> ColumnSelect<Object[]> sum(org.apache.cayenne.exp.Property<E> property) {
+        return columns(property.sum());
+    }
+
+    /**
+     * <p>Select sum of values</p>
+     * @see ColumnSelect#columns(Property[])
+     */
+    public <E extends Number> ColumnSelect<Object[]> sum(NumericProperty<E> property) {
         return columns(property.sum());
     }
 
@@ -620,9 +584,8 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * Explicitly request distinct in query.
      */
     public ColumnSelect<T> distinct() {
-        this.suppressDistinct = false;
+        metaData.setSuppressingDistinct(false);
         this.distinct = true;
-        this.replacementQuery = null;
         return this;
     }
 
@@ -630,42 +593,52 @@ public class ColumnSelect<T> extends FluentSelect<T> {
      * Explicitly suppress distinct in query.
      */
     public ColumnSelect<T> suppressDistinct() {
-        this.suppressDistinct = true;
+        metaData.setSuppressingDistinct(true);
         this.distinct = false;
-        this.replacementQuery = null;
         return this;
     }
 
-    private void setActiveExpression(Expression exp) {
-        if(havingExpressionIsActive) {
-            having = exp;
-        } else {
-            where = exp;
-        }
-        replacementQuery = null;
-    }
-
-    private Expression getActiveExpression() {
-        if(havingExpressionIsActive) {
-            return having;
-        } else {
-            return where;
-        }
-    }
-
+    @Override
     public Collection<Property<?>> getColumns() {
         return columns;
     }
 
-    /**
-     * Returns a HAVING clause Expression of this query.
-     */
-    public Expression getHaving() {
-        return having;
-    }
-
     @Override
     public T selectFirst(ObjectContext context) {
         return context.selectFirst(limit(1));
     }
+
+    boolean isSingleColumn() {
+        return singleColumn;
+    }
+
+    @Override
+    public QueryMetadata getMetaData(EntityResolver resolver) {
+        Object root = resolveRoot(resolver);
+        metaData.resolve(root, resolver, this);
+        return metaData;
+    }
+
+    @Override
+    protected BaseQueryMetadata getBaseMetaData() {
+        return metaData;
+    }
+
+    /**
+     * Maps result of this query by processing with a given function.
+     * <br/>
+     * Could be used to map plain Object[] to some domain-specific object.
+     * <br/>
+     * <b>Note:</b> this method could be called multiple time, result will be mapped by all functions in the call order.
+     * @param mapper function that maps result to the required type.
+     * @return this query with changed result type
+     * @param <E> new result type
+     *
+     * @since 4.2
+     */
+    @SuppressWarnings("unchecked")
+    public <E> ColumnSelect<E> map(Function<T, E> mapper) {
+        this.metaData.setResultMapper(mapper);
+        return (ColumnSelect<E>)this;
+    }
 }
