@@ -18,21 +18,26 @@
  ****************************************************************/
 package org.apache.cayenne.query;
 
-import org.apache.cayenne.DataRow;
-import org.apache.cayenne.ObjectContext;
-import org.apache.cayenne.exp.Expression;
-import org.apache.cayenne.exp.ExpressionFactory;
-import org.apache.cayenne.exp.Property;
-import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.map.EntityResolver;
-import org.apache.cayenne.map.ObjEntity;
-
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
+
+import org.apache.cayenne.DataRow;
+import org.apache.cayenne.ObjectContext;
+import org.apache.cayenne.exp.Expression;
+import org.apache.cayenne.exp.ExpressionFactory;
+import org.apache.cayenne.exp.property.BaseProperty;
+import org.apache.cayenne.exp.property.ComparableProperty;
+import org.apache.cayenne.exp.property.NumericProperty;
+import org.apache.cayenne.exp.property.Property;
+import org.apache.cayenne.exp.property.PropertyFactory;
+import org.apache.cayenne.map.DbEntity;
+import org.apache.cayenne.map.EntityResolver;
+import org.apache.cayenne.map.ObjEntity;
 
 /**
  * A selecting query providing chainable API. This is an alternative to
@@ -49,11 +54,11 @@ import java.util.List;
  *
  * @since 4.0
  */
-public class ObjectSelect<T> extends FluentSelect<T> {
+public class ObjectSelect<T> extends FluentSelect<T> implements ParameterizedQuery {
 
     private static final long serialVersionUID = -156124021150949227L;
 
-    protected boolean fetchingDataRows;
+    protected ObjectSelectMetadata metaData = new ObjectSelectMetadata();
 
     /**
      * Creates a ObjectSelect that selects objects of a given persistent class.
@@ -139,27 +144,15 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * Creates a ColumnSelect that will fetch multiple columns of a given {@link ObjEntity}
      *
      * @param entityType base persistent class that will be used as a root for this query
-     * @param firstColumn column to select
-     * @param otherColumns columns to select
+     * @param columns columns to select
      */
-    public static ColumnSelect<Object[]> columnQuery(Class<?> entityType, Property<?> firstColumn, Property<?>... otherColumns) {
-        return new ColumnSelect<Object[]>().entityType(entityType).columns(firstColumn, otherColumns);
+    public static ColumnSelect<Object[]> columnQuery(Class<?> entityType, Property<?>... columns) {
+        return new ColumnSelect<Object[]>().entityType(entityType).columns(columns);
     }
 
     protected ObjectSelect() {
     }
 
-    /**
-     * Translates self to a SelectQuery.
-     */
-    @SuppressWarnings({"deprecation", "unchecked"})
-    @Override
-    protected Query createReplacementQuery(EntityResolver resolver) {
-        SelectQuery<?> replacement = (SelectQuery<?>) super.createReplacementQuery(resolver);
-        replacement.setFetchingDataRows(fetchingDataRows);
-        return replacement;
-    }
-
     /**
      * Sets the type of the entity to fetch without changing the return type of
      * the query.
@@ -220,6 +213,31 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         return and(ExpressionFactory.exp(expressionString, parameters));
     }
 
+    /**
+     * Appends a having qualifier expression of this query. An equivalent to
+     * {@link #and(Expression...)} that can be used a syntactic sugar.
+     *
+     * @return this object
+     * @since 4.2
+     */
+    public ObjectSelect<T> having(Expression expression) {
+        havingExpressionIsActive = true;
+        return and(expression);
+    }
+
+    /**
+     * Appends a having qualifier expression of this query, using provided expression
+     * String and an array of position parameters. This is an equivalent to
+     * calling "and".
+     *
+     * @return this object
+     * @since 4.2
+     */
+    public ObjectSelect<T> having(String expressionString, Object... parameters) {
+        havingExpressionIsActive = true;
+        return and(ExpressionFactory.exp(expressionString, parameters));
+    }
+
     /**
      * AND's provided expressions to the existing WHERE clause expression.
      *
@@ -245,17 +263,17 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         }
 
         Collection<Expression> all;
+        Expression activeExpression = getActiveExpression();
 
-        if (where != null) {
+        if(activeExpression != null) {
             all = new ArrayList<>(expressions.size() + 1);
-            all.add(where);
+            all.add(activeExpression);
             all.addAll(expressions);
         } else {
             all = expressions;
         }
 
-        where = ExpressionFactory.and(all);
-        replacementQuery = null;
+        setActiveExpression(ExpressionFactory.and(all));
         return this;
     }
 
@@ -283,17 +301,17 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         }
 
         Collection<Expression> all;
+        Expression activeExpression = getActiveExpression();
 
-        if (where != null) {
+        if(activeExpression != null) {
             all = new ArrayList<>(expressions.size() + 1);
-            all.add(where);
+            all.add(activeExpression);
             all.addAll(expressions);
         } else {
             all = expressions;
         }
 
-        where = ExpressionFactory.or(all);
-        replacementQuery = null;
+        setActiveExpression(ExpressionFactory.or(all));
         return this;
     }
 
@@ -336,7 +354,6 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         }
 
         Collections.addAll(this.orderings, orderings);
-        replacementQuery = null;
 
         return this;
     }
@@ -357,7 +374,6 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         }
 
         this.orderings.addAll(orderings);
-        replacementQuery = null;
 
         return this;
     }
@@ -368,17 +384,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @return this object
      */
     public ObjectSelect<T> prefetch(PrefetchTreeNode prefetch) {
-
-        if (prefetch == null) {
-            return this;
-        }
-
-        if (prefetches == null) {
-            prefetches = new PrefetchTreeNode();
-        }
-
-        prefetches.merge(prefetch);
-        replacementQuery = null;
+        metaData.mergePrefetch(prefetch);
         return this;
     }
 
@@ -389,19 +395,10 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @return this object
      */
     public ObjectSelect<T> prefetch(String path, int semantics) {
-
         if (path == null) {
             return this;
         }
-
-        if (prefetches == null) {
-            prefetches = new PrefetchTreeNode();
-        }
-
-        PrefetchTreeNode prefetchTreeNode = prefetches.addPath(path);
-        prefetchTreeNode.setSemantics(semantics);
-        prefetchTreeNode.setPhantom(false);
-        replacementQuery = null;
+        metaData.addPrefetch(path, semantics);
         return this;
     }
 
@@ -409,13 +406,8 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * Resets query fetch limit - a parameter that defines max number of objects
      * that should be ever be fetched from the database.
      */
-    @SuppressWarnings("unchecked")
     public ObjectSelect<T> limit(int fetchLimit) {
-        if (this.limit != fetchLimit) {
-            this.limit = fetchLimit;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setFetchLimit(fetchLimit);
         return this;
     }
 
@@ -424,11 +416,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * should be skipped when reading data from the database.
      */
     public ObjectSelect<T> offset(int fetchOffset) {
-        if (this.offset != fetchOffset) {
-            this.offset = fetchOffset;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setFetchOffset(fetchOffset);
         return this;
     }
 
@@ -438,11 +426,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * parts of the result are ever going to be accessed.
      */
     public ObjectSelect<T> pageSize(int pageSize) {
-        if (this.pageSize != pageSize) {
-            this.pageSize = pageSize;
-            this.replacementQuery = null;
-        }
-
+        this.metaData.setPageSize(pageSize);
         return this;
     }
 
@@ -453,25 +437,24 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @see Statement#setFetchSize(int)
      */
     public ObjectSelect<T> statementFetchSize(int size) {
-        if (this.statementFetchSize != size) {
-            this.statementFetchSize = size;
-            this.replacementQuery = null;
-        }
+        this.metaData.setStatementFetchSize(size);
+        return this;
+    }
 
+    /**
+     * Sets query timeout for PreparedStatement generated for this query.
+     *
+     * @see Statement#setQueryTimeout(int)
+     * @since 4.2
+     */
+    public ObjectSelect<T> queryTimeout(int timeout) {
+        this.metaData.setQueryTimeout(timeout);
         return this;
     }
 
     public ObjectSelect<T> cacheStrategy(QueryCacheStrategy strategy) {
-        if (this.cacheStrategy != strategy) {
-            this.cacheStrategy = strategy;
-            this.replacementQuery = null;
-        }
-
-        if(this.cacheGroup != null) {
-            this.cacheGroup = null;
-            this.replacementQuery = null;
-        }
-
+        setCacheStrategy(strategy);
+        setCacheGroup(null);
         return this;
     }
 
@@ -480,8 +463,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
     }
 
     public ObjectSelect<T> cacheGroup(String cacheGroup) {
-        this.cacheGroup = cacheGroup;
-        this.replacementQuery = null;
+        setCacheGroup(cacheGroup);
         return this;
     }
 
@@ -541,10 +523,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      */
     @SuppressWarnings("unchecked")
     public ObjectSelect<DataRow> fetchDataRows() {
-        if(!fetchingDataRows) {
-            fetchingDataRows = true;
-            replacementQuery = null;
-        }
+        metaData.setFetchingDataRows(true);
         return (ObjectSelect<DataRow>) this;
     }
 
@@ -564,15 +543,15 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @param properties array of properties to select
      * @see ObjectSelect#column(Property)
      */
-    public ColumnSelect<Object[]> columns(Property<?> firstProperty, Property<?>... properties) {
-        return new ColumnSelect<>(this).columns(firstProperty, properties);
+    public ColumnSelect<Object[]> columns(Property<?>... properties) {
+        return new ColumnSelect<>(this).columns(properties);
     }
 
     /**
      * <p>Select one specific property.</p>
      * <p>Can be any property that can be resolved against root entity type
      * (root entity's property, function call expression, property of relationships, etc)</p>
-     * <p>If you need several columns use {@link ObjectSelect#columns(Property, Property[])} method.</p>
+     * <p>If you need several columns use {@link ObjectSelect#columns(Property[])} method.</p>
      * <p>
      * <pre>
      * {@code
@@ -583,7 +562,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * </pre>
      * </p>
      * @param property single property to select
-     * @see ObjectSelect#columns(Property, Property[])
+     * @see ObjectSelect#columns(Property[])
      */
     public <E> ColumnSelect<E> column(Property<E> property) {
         return new ColumnSelect<>(this).column(property);
@@ -594,7 +573,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @see ObjectSelect#column(Property)
      */
     public ColumnSelect<Long> count() {
-        return column(Property.COUNT);
+        return column(PropertyFactory.COUNT);
     }
 
     /**
@@ -603,7 +582,7 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @see ObjectSelect#count()
      * @see ObjectSelect#column(Property)
      */
-    public ColumnSelect<Long> count(Property<?> property) {
+    public ColumnSelect<Long> count(BaseProperty<?> property) {
         return column(property.count());
     }
 
@@ -611,7 +590,15 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * <p>Select minimum value of property</p>
      * @see ObjectSelect#column(Property)
      */
-    public <E> ColumnSelect<E> min(Property<E> property) {
+    public <E> ColumnSelect<E> min(ComparableProperty<E> property) {
+        return column(property.min());
+    }
+
+    /**
+     * <p>Select minimum value of property</p>
+     * @see ObjectSelect#column(Property)
+     */
+    public <E extends Number> ColumnSelect<E> min(NumericProperty<E> property) {
         return column(property.min());
     }
 
@@ -619,26 +606,63 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * <p>Select maximum value of property</p>
      * @see ObjectSelect#column(Property)
      */
-    public <E> ColumnSelect<E> max(Property<E> property) {
+    public <E> ColumnSelect<E> max(ComparableProperty<E> property) {
+        return column(property.max());
+    }
+
+    /**
+     * <p>Select maximum value of property</p>
+     * @see ObjectSelect#column(Property)
+     */
+    public <E extends Number> ColumnSelect<E> max(NumericProperty<E> property) {
         return column(property.max());
     }
 
     /**
      * <p>Select average value of property</p>
      * @see ObjectSelect#column(Property)
+     * @deprecated since 4.2 use {@link #avg(NumericProperty)}
      */
-    public <E> ColumnSelect<E> avg(Property<E> property) {
+    @Deprecated
+    public <E> ColumnSelect<E> avg(org.apache.cayenne.exp.Property<E> property) {
+        return column(property.avg());
+    }
+
+    /**
+     * <p>Select average value of property</p>
+     * @see ObjectSelect#column(Property)
+     */
+    public <E extends Number> ColumnSelect<E> avg(NumericProperty<E> property) {
         return column(property.avg());
     }
 
     /**
      * <p>Select sum of values</p>
      * @see ObjectSelect#column(Property)
+     * @deprecated since 4.2 use {@link #sum(NumericProperty)}
      */
-    public <E extends Number> ColumnSelect<E> sum(Property<E> property) {
+    @Deprecated
+    public <E extends Number> ColumnSelect<E> sum(org.apache.cayenne.exp.Property<E> property) {
         return column(property.sum());
     }
 
+    /**
+     * <p>Select sum of values</p>
+     * @see ObjectSelect#column(Property)
+     */
+    public <E extends Number> ColumnSelect<E> sum(NumericProperty<E> property) {
+        return column(property.sum());
+    }
+
+    /**
+     * @since 4.2
+     * @return this
+     */
+    public ObjectSelect<T> distinct() {
+        this.distinct = true;
+        return this;
+    }
+
     /**
      * <p>Quick way to select count of records</p>
      * <p>Usage:
@@ -654,7 +678,10 @@ public class ObjectSelect<T> extends FluentSelect<T> {
      * @return count of rows
      */
     public long selectCount(ObjectContext context) {
-        return count().selectOne(context);
+        ColumnSelect<Long> count = count();
+        // reset orderings, see CAY-2836
+        count.orderings = Collections.emptyList();
+        return count.selectOne(context);
     }
 
     @Override
@@ -662,7 +689,37 @@ public class ObjectSelect<T> extends FluentSelect<T> {
         return context.selectFirst(limit(1));
     }
 
+    @Override
     public boolean isFetchingDataRows() {
-        return fetchingDataRows;
+        return metaData.isFetchingDataRows();
+    }
+
+    @Override
+    public QueryMetadata getMetaData(EntityResolver resolver) {
+        Object root = resolveRoot(resolver);
+        metaData.resolve(root, resolver, this);
+        return metaData;
+    }
+
+    @Override
+    protected BaseQueryMetadata getBaseMetaData() {
+        return metaData;
+    }
+
+    /**
+     * This method is intended for internal use in a {@link MappedSelect}.
+     *
+     * @param parameters to apply
+     * @return this query with parameters applied to the <b>where</b> qualifier
+     *
+     * @since 4.2
+     */
+    @Override
+    public Query createQuery(Map<String, ?> parameters) {
+        if(where == null) {
+            return this;
+        }
+        where = where.params(parameters, true);
+        return this;
     }
 }
