@@ -39,9 +39,17 @@ public interface SQLActionVisitor {
 
     /**
      * Creates an action to execute a SelectQuery.
+     * @deprecated since 4.2 as part of {@link SelectQuery} deprecation
      */
+    @Deprecated
     <T> SQLAction objectSelectAction(SelectQuery<T> query);
 
+    /**
+     * Creates an action to execute a FluentSelect.
+     * @since 4.2
+     */
+    <T> SQLAction objectSelectAction(FluentSelect<T> query);
+
     /**
      * Creates an action to execute a SQLTemplate.
      */
