@@ -19,14 +19,6 @@
 
 package org.apache.cayenne.query;
 
-import org.apache.cayenne.CayenneRuntimeException;
-import org.apache.cayenne.access.QueryEngine;
-import org.apache.cayenne.map.DataMap;
-import org.apache.cayenne.map.DbEntity;
-import org.apache.cayenne.map.EntityResolver;
-import org.apache.cayenne.map.ObjEntity;
-import org.apache.cayenne.map.SQLResult;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -38,6 +30,14 @@ import java.util.Map;
 import java.util.function.Function;
 import java.util.stream.Stream;
 
+import org.apache.cayenne.CayenneRuntimeException;
+import org.apache.cayenne.access.QueryEngine;
+import org.apache.cayenne.map.DataMap;
+import org.apache.cayenne.map.DbEntity;
+import org.apache.cayenne.map.EntityResolver;
+import org.apache.cayenne.map.ObjEntity;
+import org.apache.cayenne.map.SQLResult;
+
 /**
  * A query that executes unchanged (except for template preprocessing) "raw" SQL
  * specified by the user. <h3>Template Script</h3>
@@ -624,6 +624,22 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery {
 		return metaData.getStatementFetchSize();
 	}
 
+	/**
+	 * Sets query timeout.
+	 * @since 4.2
+	 */
+	public void setQueryTimeout(int queryTimeout) {
+		metaData.setQueryTimeout(queryTimeout);
+	}
+
+	/**
+	 * @return query timeout
+	 * @since 4.2
+	 */
+	public int getQueryTimeout() {
+		return metaData.getQueryTimeout();
+	}
+
 	/**
 	 * Returns a name of the DataNode to use with this SQLTemplate. This
 	 * information will be used during query execution if no other routing
@@ -684,4 +700,11 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery {
 	public boolean isUseScalar() {
 		return useScalar;
 	}
+
+	/**
+	 * @since 4.2
+	 */
+    public void setResultMapper(Function<?,?> resultMapper) {
+		this.metaData.setResultMapper(resultMapper);
+    }
 }
