@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -21,13 +21,13 @@ package org.apache.cayenne.tx;
 
 /**
  * @since 4.1
+ * @deprecated since 4.2, use {@link TransactionDescriptor#defaultDescriptor()}
  */
+@Deprecated
 public class DefaultTransactionDescriptor extends TransactionDescriptor {
 
-    private static final DefaultTransactionDescriptor instance = new DefaultTransactionDescriptor();
-
     public static TransactionDescriptor getInstance() {
-        return instance;
+        return TransactionDescriptor.defaultDescriptor();
     }
 
     private DefaultTransactionDescriptor() {
