@@ -18,9 +18,6 @@
  ****************************************************************/
 package org.apache.cayenne.tx;
 
-import java.sql.Connection;
-import java.sql.SQLException;
-
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.log.JdbcEventLogger;
@@ -40,12 +37,12 @@ public class DefaultTransactionManager implements TransactionManager {
 
     @Override
     public <T> T performInTransaction(TransactionalOperation<T> op) {
-        return performInTransaction(op, DoNothingTransactionListener.getInstance(), DefaultTransactionDescriptor.getInstance());
+        return performInTransaction(op, DoNothingTransactionListener.getInstance(), TransactionDescriptor.defaultDescriptor());
     }
 
     @Override
     public <T> T performInTransaction(TransactionalOperation<T> op, TransactionListener callback) {
-        return performInTransaction(op, callback, DefaultTransactionDescriptor.getInstance());
+        return performInTransaction(op, callback, TransactionDescriptor.defaultDescriptor());
     }
 
     /**
