@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -33,4 +33,20 @@ public interface TransactionListener {
     void willRollback(Transaction tx);
 
     void willAddConnection(Transaction tx, String connectionName, Connection connection);
+
+    /**
+     * This method could be used to decorate or substitute
+     * new connection initiated inside a Cayenne transaction.
+     * <br/>
+     * The default implementation returns the same connection.
+     *
+     * @param tx transaction that initiated connection
+     * @param connection connection (it could be decorated by other listeners)
+     * @return connection
+     *
+     * @since 4.2
+     */
+    default Connection decorateConnection(Transaction tx, Connection connection){
+        return connection;
+    }
 }
