@@ -34,10 +34,10 @@ import org.apache.cayenne.CayenneRuntimeException;
  */
 public class Invocation {
 
-    private WeakReference _target;
-    private Method _method;
-    private Class[] _parameterTypes;
-    private int _hashCode;
+    private WeakReference<?> target;
+    private Method method;
+    private Class<?>[] parameterTypes;
+    private int hashCode;
 
     /**
      * Prevent use of empty default constructor
@@ -59,28 +59,18 @@ public class Invocation {
      * 
      * @see #Invocation(Object, String, Class[])
      */
-    public Invocation(Object target, String methodName, Class parameterType)
-            throws NoSuchMethodException {
-        this(target, methodName, new Class[] {
-            parameterType
-        });
+    public Invocation(Object target, String methodName, Class parameterType) throws NoSuchMethodException {
+        this(target, methodName, new Class[] {parameterType});
     }
 
     /**
      * Constructor for an Invocation with arbitrary arguments in the target's method.
      * 
-     * @param target
-     * @param methodName
-     * @param parameterTypes
-     * @throws NoSuchMethodException if <code>methodName</code> could not be found in
-     *             the target
+     * @throws NoSuchMethodException if <code>methodName</code> could not be found in the target
      * @throws IllegalArgumentException if target or methodName are <code>null</code>,
      *             or parameterTypes is empty or contains <code>null</code> elements
      */
-    public Invocation(Object target, String methodName, Class[] parameterTypes)
-            throws NoSuchMethodException {
-        super();
-
+    public Invocation(Object target, String methodName, Class[] parameterTypes) throws NoSuchMethodException {
         if (target == null) {
             throw new IllegalArgumentException("target argument must not be null");
         }
@@ -93,49 +83,36 @@ public class Invocation {
             if (parameterTypes.length > 0) {
                 for (int i = 0; i < parameterTypes.length; i++) {
                     if (parameterTypes[i] == null) {
-                        throw new IllegalArgumentException("parameter type["
-                                + i
-                                + "] must not be null");
+                        throw new IllegalArgumentException("parameter type[" + i + "] must not be null");
                     }
                 }
-            }
-            else {
+            } else {
                 throw new IllegalArgumentException("parameter types must not be empty");
             }
         }
 
         // allow access to public methods of inaccessible classes, if such methods were
         // declared in a public interface
-
-        _method = lookupMethodInHierarchy(target.getClass(), methodName, parameterTypes);
-
-        if (_method == null) {
-            throw new NoSuchMethodException("No such method: "
-                    + target.getClass().getName()
-                    + "."
-                    + methodName);
+        method = lookupMethodInHierarchy(target.getClass(), methodName, parameterTypes);
+        if (method == null) {
+            throw new NoSuchMethodException("No such method: " + target.getClass().getName() + "." + methodName);
         }
-
-        if (!Util.isAccessible(_method)) {
-            _method.setAccessible(true);
+        if (!Util.isAccessible(method)) {
+            method.setAccessible(true);
         }
 
         // IMPORTANT: include Invocation target object(not a WeakReference) into
         // algorithm is used to compute hashCode.
-        _hashCode = 31 * target.hashCode() + _method.hashCode();
-        _parameterTypes = parameterTypes;
-        _target = new WeakReference(target);
+        this.hashCode = 31 * target.hashCode() + method.hashCode();
+        this.parameterTypes = parameterTypes;
+        this.target = new WeakReference<>(target);
     }
 
-    Method lookupMethodInHierarchy(
-            Class objectClass,
-            String methodName,
-            Class[] parameterTypes) throws SecurityException, NoSuchMethodException {
-
+    Method lookupMethodInHierarchy(Class<?> objectClass, String methodName, Class[] parameterTypes)
+            throws SecurityException, NoSuchMethodException {
         try {
             return objectClass.getDeclaredMethod(methodName, parameterTypes);
-        }
-        catch (NoSuchMethodException e) {
+        } catch (NoSuchMethodException e) {
 
             Class superClass = objectClass.getSuperclass();
             if (superClass == null || superClass.getName().equals(Object.class.getName())) {
@@ -162,9 +139,7 @@ public class Invocation {
      * @see #fire(Object[])
      */
     public boolean fire(Object argument) {
-        return this.fire(new Object[] {
-            argument
-        });
+        return this.fire(new Object[] {argument});
     }
 
     /**
@@ -181,32 +156,29 @@ public class Invocation {
      */
     public boolean fire(Object[] arguments) {
 
-        if (_parameterTypes == null) {
+        if (parameterTypes == null) {
             if (arguments != null) {
                 throw new IllegalArgumentException("arguments unexpectedly != null");
             }
-        }
-        else if (arguments == null) {
+        } else if (arguments == null) {
             throw new IllegalArgumentException("arguments must not be null");
-        }
-        else if (_parameterTypes.length != arguments.length) {
+        } else if (parameterTypes.length != arguments.length) {
             throw new IllegalArgumentException(
                     "inconsistent number of arguments: expected"
-                            + _parameterTypes.length
+                            + parameterTypes.length
                             + ", got "
                             + arguments.length);
         }
 
-        Object currentTarget = _target.get();
+        Object currentTarget = target.get();
         if (currentTarget == null) {
             return false;
         }
 
         try {
-            _method.invoke(currentTarget, arguments);
+            method.invoke(currentTarget, arguments);
             return true;
-        }
-        catch (InvocationTargetException ite) {
+        } catch (InvocationTargetException ite) {
             // this is the only type of exception that can be rethrown, since
             // listener can have a valid need to respond to an event with exception,
             // and this does not indicate that it is being in invalid state
@@ -214,12 +186,10 @@ public class Invocation {
             Throwable cause = ite.getCause();
             if (cause instanceof RuntimeException) {
                 throw (RuntimeException) cause;
-            }
-            else {
+            } else {
                 throw new CayenneRuntimeException(cause);
             }
-        }
-        catch (Exception ex) {
+        } catch (Exception ex) {
             // all other exceptions indicate propblems with the listener,
             // so return invalid status
             return false;
@@ -231,30 +201,27 @@ public class Invocation {
      */
     @Override
     public boolean equals(Object obj) {
-        if ((obj != null) && (obj.getClass().equals(this.getClass()))) {
-            Invocation otherInvocation = (Invocation) obj;
-            if (_method.equals(otherInvocation.getMethod())) {
-                Object otherTarget = otherInvocation.getTarget();
-                Object target = _target.get();
-
-                if ((target == null) && (otherTarget == null)) {
-                    return true;
-                }
-
-                if ((target == null) && (otherTarget != null)) {
-                    return false;
-                }
-
-                if (target != null) {
-                    return target.equals(otherTarget);
-                }
-            }
-
+        if (obj == null || !obj.getClass().equals(this.getClass())) {
             return false;
         }
-        else {
-            return super.equals(obj);
+
+        Invocation otherInvocation = (Invocation) obj;
+        if (!method.equals(otherInvocation.getMethod())) {
+            return false;
         }
+
+        Object otherTarget = otherInvocation.getTarget();
+        Object target = this.getTarget();
+
+        if (target == otherTarget) {
+            return true;
+        }
+
+        if (target == null) {
+            return false;
+        }
+
+        return target.equals(otherTarget);
     }
 
     /**
@@ -262,28 +229,28 @@ public class Invocation {
      */
     @Override
     public int hashCode() {
-        return _hashCode;
+        return hashCode;
     }
 
     /**
      * @return the method to be invoked on the target
      */
     public Method getMethod() {
-        return _method;
+        return method;
     }
 
     /**
      * @return the target object of this Invocation
      */
     public Object getTarget() {
-        return _target.get();
+        return target.get();
     }
 
     /**
      * @return an array of Classes describing the target method's parameters
      */
     public Class[] getParameterTypes() {
-        return _parameterTypes;
+        return parameterTypes;
     }
 
 }
