@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -20,19 +20,24 @@
 package org.apache.cayenne.util;
 
 import org.apache.cayenne.Cayenne;
+import org.apache.cayenne.ConfigurationException;
 import org.apache.cayenne.PersistenceState;
 import org.apache.cayenne.Persistent;
 import org.apache.cayenne.di.AdhocObjectFactory;
 import org.apache.cayenne.di.spi.DefaultAdhocObjectFactory;
 import org.apache.cayenne.di.spi.DefaultClassLoaderManager;
+import org.apache.cayenne.graph.ArcId;
 import org.apache.cayenne.reflect.ArcProperty;
 import org.apache.cayenne.reflect.AttributeProperty;
 import org.apache.cayenne.reflect.PropertyVisitor;
 import org.apache.cayenne.reflect.ToManyProperty;
 import org.apache.cayenne.reflect.ToOneProperty;
+import org.w3c.dom.Document;
 import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
 
+import javax.xml.parsers.DocumentBuilder;
+import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
@@ -42,11 +47,13 @@ import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
 import java.lang.reflect.Member;
 import java.lang.reflect.Modifier;
+import java.math.BigDecimal;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
@@ -203,7 +210,7 @@ public class Util {
 			return builder.isEquals();
 		} else { // It is NOT an array, so use regular equals()
 			return o1.equals(o2);
-		}
+        }
 	}
 
 	/**
@@ -228,10 +235,90 @@ public class Util {
 	/**
 	 * Returns true, if the String is null or an empty string.
 	 */
-	public static boolean isEmptyString(String string) {
+	public static boolean isEmptyString(CharSequence string) {
 		return string == null || string.length() == 0;
 	}
 
+	/**
+	 * Returns true, if string not empty and contains non-whitespace characters.
+	 * @since 4.1
+	 */
+	public static boolean isBlank(CharSequence cs) {
+		int strLen;
+		if (cs != null && (strLen = cs.length()) != 0) {
+			for(int i = 0; i < strLen; ++i) {
+				if (!Character.isWhitespace(cs.charAt(i))) {
+					return false;
+				}
+			}
+
+			return true;
+		} else {
+			return true;
+		}
+	}
+
+	/**
+	 * @since 4.1
+	 */
+	public static boolean isNumeric(CharSequence cs) {
+		if (isEmptyString(cs)) {
+			return false;
+		} else {
+			for(int i = 0; i < cs.length(); ++i) {
+				if (!Character.isDigit(cs.charAt(i))) {
+					return false;
+				}
+			}
+
+			return true;
+		}
+	}
+
+	/**
+	 * Returns how many times the sub appears in the str.
+	 * @since 4.1
+	 */
+	public static int countMatches(final String str, final String sub) {
+		if (isEmptyString(str) || isEmptyString(sub)) {
+			return 0;
+		}
+		int count = 0, idx = 0;
+		while ((idx = str.indexOf(sub, idx)) != -1) {
+			count++;
+			idx += sub.length();
+		}
+		return count;
+	}
+
+	/**
+	 * Capitalizes the first letter of the property name.
+	 *
+	 * @since 4.1
+	 */
+	public static String capitalized(String name) {
+		if (name == null || name.length() == 0) {
+			return name;
+		}
+
+		char c = Character.toUpperCase(name.charAt(0));
+		return (name.length() == 1) ? Character.toString(c) : c + name.substring(1);
+	}
+
+	/**
+	 * Returns string with lowercased first letter
+	 *
+	 * @since 4.2
+	 */
+	public static String uncapitalized(String aString) {
+		if (aString == null || aString.length() == 0) {
+			return aString;
+		}
+
+		char c = Character.toLowerCase(aString.charAt(0));
+		return (aString.length() == 1) ? Character.toString(c) : c + aString.substring(1);
+	}
+
 	/**
 	 * Creates Serializable object copy using serialization/deserialization.
 	 */
@@ -273,6 +360,38 @@ public class Util {
 		return saxParser.getXMLReader();
 	}
 
+	/**
+	 * @since 4.1
+	 * @param url to read
+	 * @return org.w3c.dom.Document from the given URL
+	 */
+	public static Document readDocument(URL url) {
+		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
+		documentBuilderFactory.setNamespaceAware(false);
+		documentBuilderFactory.setXIncludeAware(false);
+		documentBuilderFactory.setExpandEntityReferences(false);
+
+		try {
+			documentBuilderFactory.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
+			documentBuilderFactory.setFeature("http://xml.org/sax/features/external-general-entities", false);
+			documentBuilderFactory.setFeature("http://xml.org/sax/features/external-parameter-entities", false);
+			documentBuilderFactory.setFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd", false);
+		} catch (ParserConfigurationException ex) {
+			throw new ConfigurationException("Unable to configure DocumentBuilderFactory", ex);
+		}
+
+		try {
+			DocumentBuilder domBuilder = documentBuilderFactory.newDocumentBuilder();
+			try (InputStream inputStream = url.openStream()) {
+				return domBuilder.parse(inputStream);
+			} catch (IOException | SAXException e) {
+				throw new ConfigurationException("Error loading configuration from %s", e, url);
+			}
+		} catch (ParserConfigurationException e) {
+			throw new ConfigurationException(e);
+		}
+	}
+
 	/**
 	 * Returns package name for the Java class as a path separated with forward
 	 * slash ("/"). Method is used to lookup resources that are located in
@@ -289,13 +408,15 @@ public class Util {
 	 * @since 3.0
 	 */
 	public static String stripPackageName(String className) {
-		if (className == null || className.length() == 0)
+		if (className == null || className.length() == 0) {
 			return className;
+		}
 
 		int lastDot = className.lastIndexOf('.');
 
-		if ((-1 == lastDot) || ((className.length() - 1) == lastDot))
+		if ((-1 == lastDot) || ((className.length() - 1) == lastDot)) {
 			return className;
+		}
 
 		return className.substring(lastDot + 1);
 	}
@@ -622,7 +743,7 @@ public class Util {
 			});
 
 			sourceObject.getObjectContext().getGraphManager()
-					.arcCreated(targetObject.getObjectId(), sourceObject.getObjectId(), reverseArc.getName());
+					.arcCreated(targetObject.getObjectId(), sourceObject.getObjectId(), new ArcId(reverseArc));
 
 			markAsDirty(targetObject);
 		}
@@ -652,7 +773,7 @@ public class Util {
 			});
 
 			sourceObject.getObjectContext().getGraphManager()
-					.arcDeleted(targetObject.getObjectId(), sourceObject.getObjectId(), reverseArc.getName());
+					.arcDeleted(targetObject.getObjectId(), sourceObject.getObjectId(), new ArcId(reverseArc));
 
 			markAsDirty(targetObject);
 		}
