@@ -22,6 +22,7 @@ package org.apache.cayenne;
 import org.apache.cayenne.access.ToManyList;
 import org.apache.cayenne.configuration.server.ServerRuntime;
 import org.apache.cayenne.di.Inject;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.testmap.ArtGroup;
@@ -328,4 +329,38 @@ public class CayenneDataObjectRelationshipsIT extends ServerCase {
 
         assertFalse(list.isFault());
     }
+
+    @Test
+    public void testTransientInsertAndDeleteOfToManyRelationship() throws Exception {
+        createArtistWithPaintingDataSet();
+
+        Artist artist = ObjectSelect.query(Artist.class).selectOne(context);
+
+        // create and then immediately delete a to-many relationship value
+        Painting object2 = context.newObject(Painting.class);
+        artist.addToPaintingArray(object2);
+        artist.removeFromPaintingArray(object2);
+        context.deleteObject(object2);
+        assertEquals(1, artist.getPaintingArray().size());
+
+        artist.setArtistName("updated artist name"); // this will force the commit to actually execute some SQL
+        context.commitChanges();
+    }
+    
+    @Test
+    public void testTransientSetAndNullOfToOneRelationship() throws Exception {
+        createArtistWithPaintingDataSet();
+
+        Artist artist = ObjectSelect.query(Artist.class).selectOne(context);
+
+        Painting object2 = context.newObject(Painting.class);
+        object2.setPaintingTitle("Title");
+        object2.setToArtist(artist);
+        object2.setToArtist(null);
+        context.commitChanges();
+        
+        context.invalidateObjects(object2);
+        assertNull(object2.getToArtist());
+    }
+    
 }
