@@ -28,8 +28,8 @@ import org.apache.cayenne.map.SQLResult;
 import org.apache.cayenne.query.CapsStrategy;
 import org.apache.cayenne.query.EJBQLQuery;
 import org.apache.cayenne.query.ObjectIdQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.SQLTemplate;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.testmap.Artist;
@@ -152,8 +152,7 @@ public class CayenneIT extends ServerCase {
     public void testObjectForQuery() throws Exception {
         createOneArtist();
 
-        ObjectId id = new ObjectId("Artist", Artist.ARTIST_ID_PK_COLUMN, new Integer(
-                33002));
+        ObjectId id = ObjectId.of("Artist", Artist.ARTIST_ID_PK_COLUMN, 33002);
 
         assertNull(context.getGraphManager().getNode(id));
 
@@ -168,20 +167,18 @@ public class CayenneIT extends ServerCase {
     public void testObjectForSelect() throws Exception {
         createOneArtist();
 
-        SelectQuery<Artist> query = SelectQuery.query(Artist.class, ExpressionFactory.matchDbExp("ARTIST_NAME", "artist2"));
+        ObjectSelect<Artist> query = ObjectSelect.query(Artist.class, ExpressionFactory.matchDbExp("ARTIST_NAME", "artist2"));
 
         Artist object = context.selectOne(query);
 
         assertNotNull(object);
-        assertTrue(object instanceof Artist);
-        assertEquals("artist2", ((Artist) object).getArtistName());
+        assertEquals("artist2", object.getArtistName());
     }
 
     @Test
     public void testObjectForQueryNoObject() throws Exception {
 
-        ObjectId id = new ObjectId("Artist", Artist.ARTIST_ID_PK_COLUMN, new Integer(
-                44001));
+        ObjectId id = ObjectId.of("Artist", Artist.ARTIST_ID_PK_COLUMN, 44001);
 
         Object object = Cayenne.objectForQuery(context, new ObjectIdQuery(id));
         assertNull(object);
@@ -204,16 +201,14 @@ public class CayenneIT extends ServerCase {
         assertSame(o1, Cayenne.objectForPK(context, o1.getObjectId()));
         assertSame(o2, Cayenne.objectForPK(context, o2.getObjectId()));
 
-        assertNull(Cayenne.objectForPK(context, new ObjectId("Artist", new byte[] {
-                1, 2, 3
-        })));
+        assertNull(Cayenne.objectForPK(context, ObjectId.of("Artist", new byte[] {1, 2, 3})));
     }
 
     @Test
     public void testObjectForPKObjectId() throws Exception {
         createOneArtist();
 
-        Object object = Cayenne.objectForPK(context, new ObjectId(
+        Object object = Cayenne.objectForPK(context, ObjectId.of(
                 "Artist",
                 Artist.ARTIST_ID_PK_COLUMN,
                 33002));
@@ -263,9 +258,9 @@ public class CayenneIT extends ServerCase {
     public void testIntPKForObject() throws Exception {
         createOneArtist();
 
-        List<?> objects = context.performQuery(new SelectQuery(Artist.class));
+        List<Artist> objects = ObjectSelect.query(Artist.class).select(context);
         assertEquals(1, objects.size());
-        DataObject object = (DataObject) objects.get(0);
+        DataObject object = objects.get(0);
 
         assertEquals(33002, Cayenne.intPKForObject(object));
     }
@@ -274,11 +269,11 @@ public class CayenneIT extends ServerCase {
     public void testPKForObject() throws Exception {
         createOneArtist();
 
-        List<?> objects = context.performQuery(new SelectQuery(Artist.class));
+        List<Artist> objects = ObjectSelect.query(Artist.class).select(context);
         assertEquals(1, objects.size());
-        DataObject object = (DataObject) objects.get(0);
+        DataObject object = objects.get(0);
 
-        assertEquals(new Long(33002), Cayenne.pkForObject(object));
+        assertEquals(33002L, Cayenne.pkForObject(object));
     }
 
     @Test
@@ -289,7 +284,7 @@ public class CayenneIT extends ServerCase {
         assertEquals(1, objects.size());
         Artist object = (Artist) objects.get(0);
 
-        assertEquals(new Long(33002), Cayenne.pkForObject(object));
+        assertEquals(33002L, Cayenne.pkForObject(object));
     }
 
 }
