@@ -59,7 +59,7 @@ public class ContextStateRecorderTest {
 		assertTrue(recorder.dirtyNodes(PersistenceState.HOLLOW).isEmpty());
 
 		MockPersistentObject modified = new MockPersistentObject();
-		modified.setObjectId(new ObjectId("MockPersistentObject", "key", "value1"));
+		modified.setObjectId(ObjectId.of("MockPersistentObject", "key", "value1"));
 		modified.setPersistenceState(PersistenceState.MODIFIED);
 		
 		when(mockGraphManager.getNode(modified.getObjectId())).thenReturn(modified);
@@ -73,7 +73,7 @@ public class ContextStateRecorderTest {
 		assertTrue(recorder.dirtyNodes(PersistenceState.HOLLOW).isEmpty());
 
 		MockPersistentObject deleted = new MockPersistentObject();
-		deleted.setObjectId(new ObjectId("MockPersistentObject", "key", "value2"));
+		deleted.setObjectId(ObjectId.of("MockPersistentObject", "key", "value2"));
 		deleted.setPersistenceState(PersistenceState.DELETED);
 		when(mockGraphManager.getNode(deleted.getObjectId())).thenReturn(deleted);
 		recorder.nodeRemoved(deleted.getObjectId());
@@ -94,7 +94,7 @@ public class ContextStateRecorderTest {
 
 		// introduce a fake dirty object
 		MockPersistentObject object = new MockPersistentObject();
-		object.setObjectId(new ObjectId("MockPersistentObject", "key", "value"));
+		object.setObjectId(ObjectId.of("MockPersistentObject", "key", "value"));
 		object.setPersistenceState(PersistenceState.MODIFIED);
 
 		when(mockGraphManager.getNode(object.getObjectId())).thenReturn(object);
@@ -116,7 +116,7 @@ public class ContextStateRecorderTest {
 
 		// introduce a fake dirty object
 		MockPersistentObject object = new MockPersistentObject();
-		object.setObjectId(new ObjectId("MockPersistentObject", "key", "value"));
+		object.setObjectId(ObjectId.of("MockPersistentObject", "key", "value"));
 		object.setPersistenceState(PersistenceState.MODIFIED);
 		recorder.nodePropertyChanged(object.getObjectId(), "xyz", "a", "b");
 
