@@ -19,19 +19,21 @@
 
 package org.apache.cayenne;
 
+import java.util.List;
+
 import org.apache.cayenne.access.DataContext;
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.exp.Expression;
-import org.apache.cayenne.exp.ExpressionFactory;
 import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.SQLTemplate;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
+import org.apache.cayenne.testdo.relationships_flattened.Entity1;
+import org.apache.cayenne.testdo.relationships_flattened.Entity3;
 import org.apache.cayenne.testdo.relationships_flattened.FlattenedCircular;
 import org.apache.cayenne.testdo.relationships_flattened.FlattenedTest1;
 import org.apache.cayenne.testdo.relationships_flattened.FlattenedTest2;
 import org.apache.cayenne.testdo.relationships_flattened.FlattenedTest3;
+import org.apache.cayenne.testdo.relationships_flattened.FlattenedTest4;
 import org.apache.cayenne.testdo.relationships_flattened.FlattenedTest5;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
@@ -40,9 +42,6 @@ import org.apache.cayenne.validation.ValidationResult;
 import org.junit.Before;
 import org.junit.Test;
 
-import java.sql.Types;
-import java.util.List;
-
 import static org.junit.Assert.*;
 
 /**
@@ -76,8 +75,7 @@ public class FlattenedRelationshipsIT extends ServerCase {
         tFlattenedTest2.setColumns("FT2_ID", "FT1_ID", "NAME");
 
         tFlattenedTest3 = new TableHelper(dbHelper, "FLATTENED_TEST_3");
-        tFlattenedTest3.setColumns("FT3_ID", "FT2_ID", "NAME").setColumnTypes(
-                Types.INTEGER, Types.INTEGER, Types.VARCHAR);
+        tFlattenedTest3.setColumns("FT3_ID", "FT2_ID", "NAME");
 
         tComplexJoin = new TableHelper(dbHelper, "COMPLEX_JOIN");
         tComplexJoin.setColumns("PK", "FT1_FK", "FT3_FK", "EXTRA_COLUMN");
@@ -89,14 +87,14 @@ public class FlattenedRelationshipsIT extends ServerCase {
         tFlattenedCircularJoin.setColumns("SIDE1_ID", "SIDE2_ID");
     }
 
-    protected void createFlattenedTestDataSet() throws Exception {
+    private void createFlattenedTestDataSet() throws Exception {
         tFlattenedTest1.insert(1, "ft1");
         tFlattenedTest1.insert(2, "ft12");
         tFlattenedTest2.insert(1, 1, "ft2");
         tFlattenedTest3.insert(1, 1, "ft3");
     }
 
-    protected void createFlattenedCircularDataSet() throws Exception {
+    private void createFlattenedCircularDataSet() throws Exception {
         tFlattenedCircular.insert(1);
         tFlattenedCircular.insert(2);
         tFlattenedCircular.insert(3);
@@ -104,7 +102,7 @@ public class FlattenedRelationshipsIT extends ServerCase {
         tFlattenedCircularJoin.insert(1, 3);
     }
 
-    protected void createCircularJoinDataSet() throws Exception {
+    private void createCircularJoinDataSet() throws Exception {
         tFlattenedTest1.insert(2, "ft12");
         tFlattenedTest3.insert(2, null, "ft3-a");
         tFlattenedTest3.insert(3, null, "ft3-b");
@@ -114,7 +112,7 @@ public class FlattenedRelationshipsIT extends ServerCase {
     }
 
     @Test
-    public void testInsertJoinWithPK() throws Exception {
+    public void testInsertJoinWithPK() {
         FlattenedTest1 obj01 = context.newObject(FlattenedTest1.class);
         FlattenedTest3 obj11 = context.newObject(FlattenedTest3.class);
         FlattenedTest3 obj12 = context.newObject(FlattenedTest3.class);
@@ -173,7 +171,7 @@ public class FlattenedRelationshipsIT extends ServerCase {
     }
 
     @Test
-    public void testQualifyOnToManyFlattened() throws Exception {
+    public void testQualifyOnToManyFlattened() {
         FlattenedTest1 obj01 = context.newObject(FlattenedTest1.class);
         FlattenedTest2 obj02 = context.newObject(FlattenedTest2.class);
         FlattenedTest3 obj031 = context.newObject(FlattenedTest3.class);
@@ -200,17 +198,17 @@ public class FlattenedRelationshipsIT extends ServerCase {
         context.commitChanges();
 
         // test 1: qualify on flattened attribute
-        Expression qual1 = ExpressionFactory.matchExp("ft3Array.name", "t031");
-        SelectQuery query1 = new SelectQuery(FlattenedTest1.class, qual1);
-        List<?> objects1 = context.performQuery(query1);
+        List<FlattenedTest1> objects1 = ObjectSelect.query(FlattenedTest1.class)
+                .where(FlattenedTest1.FT3ARRAY.dot(FlattenedTest3.NAME).eq("t031"))
+                .select(context);
 
         assertEquals(1, objects1.size());
         assertSame(obj01, objects1.get(0));
 
         // test 2: qualify on flattened relationship
-        Expression qual2 = ExpressionFactory.matchExp("ft3Array", obj131);
-        SelectQuery query2 = new SelectQuery(FlattenedTest1.class, qual2);
-        List<?> objects2 = context.performQuery(query2);
+        List<FlattenedTest1> objects2 = ObjectSelect.query(FlattenedTest1.class)
+                .where(FlattenedTest1.FT3ARRAY.contains(obj131))
+                .select(context);
 
         assertEquals(1, objects2.size());
         assertSame(obj11, objects2.get(0));
@@ -232,13 +230,11 @@ public class FlattenedRelationshipsIT extends ServerCase {
 
         context.invalidateObjects(ft1, ft2, ft3);
 
-        SelectQuery q = new SelectQuery(FlattenedTest3.class);
-        q.setQualifier(ExpressionFactory.matchExp("name", "FT3Name"));
-        List<?> results = context1.performQuery(q);
+        List<FlattenedTest3> results = ObjectSelect.query(FlattenedTest3.class, FlattenedTest3.NAME.eq("FT3Name")).select(context);
 
         assertEquals(1, results.size());
 
-        FlattenedTest3 fetchedFT3 = (FlattenedTest3) results.get(0);
+        FlattenedTest3 fetchedFT3 = results.get(0);
         FlattenedTest1 fetchedFT1 = fetchedFT3.getToFT1();
         assertEquals("FT1Name", fetchedFT1.getName());
     }
@@ -248,9 +244,9 @@ public class FlattenedRelationshipsIT extends ServerCase {
         createFlattenedTestDataSet();
 
         // fetch
-        List<?> ft3s = context.performQuery(new SelectQuery(FlattenedTest3.class));
+        List<FlattenedTest3> ft3s = ObjectSelect.query(FlattenedTest3.class).select(context);
         assertEquals(1, ft3s.size());
-        FlattenedTest3 ft3 = (FlattenedTest3) ft3s.get(0);
+        FlattenedTest3 ft3 = ft3s.get(0);
 
         assertTrue(ft3.readPropertyDirectly("toFT1") instanceof Fault);
 
@@ -267,14 +263,14 @@ public class FlattenedRelationshipsIT extends ServerCase {
         createFlattenedTestDataSet();
 
         // fetch
-        List<?> ft3s = context.performQuery(new SelectQuery(FlattenedTest3.class));
+        List<FlattenedTest3> ft3s = ObjectSelect.query(FlattenedTest3.class).select(context);
         assertEquals(1, ft3s.size());
-        FlattenedTest3 ft3 = (FlattenedTest3) ft3s.get(0);
+        FlattenedTest3 ft3 = ft3s.get(0);
 
         assertTrue(ft3.readPropertyDirectly("toFT1") instanceof Fault);
 
         // refetch
-        context.performQuery(new SelectQuery(FlattenedTest3.class));
+        ObjectSelect.query(FlattenedTest3.class).select(context);
         assertTrue(ft3.readPropertyDirectly("toFT1") instanceof Fault);
     }
 
@@ -293,10 +289,9 @@ public class FlattenedRelationshipsIT extends ServerCase {
 
     /**
      * Should be able to save/insert an object with flattened (complex) toOne relationship
-     * @throws Exception
      */
     @Test
-    public void testFlattenedComplexToOneRelationship() throws Exception {
+    public void testFlattenedComplexToOneRelationship() {
         FlattenedTest1 ft1 = context.newObject(FlattenedTest1.class);
         ft1.setName("FT1");
 
@@ -312,10 +307,9 @@ public class FlattenedRelationshipsIT extends ServerCase {
 
     /**
      * Should be able to save/insert an object with null flattened (complex) toOne relationship
-     * @throws Exception
      */
     @Test
-    public void testNullFlattenedComplexToOneRelationship() throws Exception {
+    public void testNullFlattenedComplexToOneRelationship() {
         FlattenedTest5 ft5 = context.newObject(FlattenedTest5.class);
         ft5.setName("FT5");
 
@@ -330,4 +324,92 @@ public class FlattenedRelationshipsIT extends ServerCase {
         assertEquals(1, ObjectSelect.query(FlattenedTest5.class).selectCount(context));
     }
 
+    @Test
+    public void testSetFlattenedRelationship() {
+        FlattenedTest1 flattenedTest1 = context.newObject(FlattenedTest1.class);
+        flattenedTest1.setName("f1");
+        FlattenedTest3 flattenedTest3 = context.newObject(FlattenedTest3.class);
+        flattenedTest3.setName("f3");
+        flattenedTest3.setToFT1(flattenedTest1);
+
+        context.commitChanges();
+
+        List<FlattenedTest3> flattenedTest3s = ObjectSelect.query(FlattenedTest3.class)
+                .prefetch(FlattenedTest3.TO_FT1.disjoint())
+                .select(context);
+        assertEquals(1, flattenedTest3s.size());
+        assertEquals("f3", flattenedTest3s.get(0).getName());
+        assertEquals("f1", flattenedTest3s.get(0).getToFT1().getName());
+    }
+
+    @Test
+    public void testSecondToOneReverseToFk() {
+        FlattenedTest1 flattenedTest1 = context.newObject(FlattenedTest1.class);
+        flattenedTest1.setName("f1");
+        FlattenedTest4 flattenedTest4 = context.newObject(FlattenedTest4.class);
+        flattenedTest4.setName("f4");
+        flattenedTest1.addToFt4ArrayFor1(flattenedTest4);
+        context.commitChanges();
+    }
+
+    @Test
+    public void testSecondToOneToFk() {
+        Entity1 entity1 = context.newObject(Entity1.class);
+        Entity3 entity3 = context.newObject(Entity3.class);
+        entity1.setToEntity3(entity3);
+        context.commitChanges();
+
+        List<Entity1> entity1s = ObjectSelect.query(Entity1.class)
+                .prefetch(Entity1.TO_ENTITY3.disjoint())
+                .select(context);
+        assertEquals(1, entity1s.size());
+        assertNotNull(entity1s.get(0).getToEntity3());
+    }
+
+    @Test
+    public void testSetFlattenedCircular() {
+        FlattenedCircular flattenedCircular1 = context.newObject(FlattenedCircular.class);
+        FlattenedCircular flattenedCircular2 = context.newObject(FlattenedCircular.class);
+        flattenedCircular1.addToSide1s(flattenedCircular2);
+        context.commitChanges();
+
+        List<FlattenedCircular> flattenedCirculars = ObjectSelect.query(FlattenedCircular.class)
+                .prefetch(FlattenedCircular.SIDE1S.disjoint())
+                .select(context);
+
+        assertEquals(2, flattenedCirculars.size());
+    }
+
+    @Test
+    public void testFt1ToFt5Flattened() {
+        FlattenedTest1 flattenedTest1 = context.newObject(FlattenedTest1.class);
+        flattenedTest1.setName("f1");
+        FlattenedTest5 flattenedTest5 = context.newObject(FlattenedTest5.class);
+        flattenedTest5.setName("f5");
+        flattenedTest1.addToFt5Array(flattenedTest5);
+        context.commitChanges();
+
+        List<FlattenedTest1> flattenedTest1s = ObjectSelect.query(FlattenedTest1.class)
+                .prefetch(FlattenedTest1.FT5ARRAY.disjoint())
+                .select(context);
+        assertEquals(1, flattenedTest1s.size());
+        assertEquals(1, flattenedTest1s.get(0).getFt5Array().size());
+    }
+
+    @Test
+    public void testFt5ToFt1Flattened() {
+        FlattenedTest5 flattenedTest5 = context.newObject(FlattenedTest5.class);
+        flattenedTest5.setName("f5");
+        FlattenedTest1 flattenedTest1 = context.newObject(FlattenedTest1.class);
+        flattenedTest1.setName("f1");
+        flattenedTest5.setToFT1(flattenedTest1);
+        context.commitChanges();
+
+        List<FlattenedTest5> flattenedTest5s = ObjectSelect.query(FlattenedTest5.class)
+                .prefetch(FlattenedTest5.TO_FT1.disjoint())
+                .select(context);
+        assertEquals(1, flattenedTest5s.size());
+        assertEquals("f5", flattenedTest5s.get(0).getName());
+        assertEquals("f1", flattenedTest5s.get(0).getToFT1().getName());
+    }
 }
