@@ -19,19 +19,19 @@
 
 package org.apache.cayenne;
 
+import java.util.List;
+
 import org.apache.cayenne.access.DataContext;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.SQLTemplate;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
 import org.junit.Test;
 
-import java.util.List;
-
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
@@ -75,9 +75,7 @@ public class GenericMappingIT extends ServerCase {
                 "INSERT INTO GENERIC2 (GENERIC1_ID, ID, NAME) VALUES (1, 1, 'CCCCC')"));
 
         Expression qual = ExpressionFactory.matchExp("name", "AAAA");
-        SelectQuery q = new SelectQuery("Generic1", qual);
-
-        List<?> result = context.performQuery(q);
+        List<?> result = ObjectSelect.query(Object.class, "Generic1").where(qual).select(context);
         assertEquals(1, result.size());
     }
 
