@@ -23,7 +23,6 @@ import java.util.List;
 
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.query.ObjectSelect;
-import org.apache.cayenne.query.SortOrder;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.cay_2032.Team;
@@ -87,7 +86,7 @@ public class Cay2032IT extends ServerCase {
     public void testPrefetchDisjoint() throws Exception {
         List<Team> result = ObjectSelect.query(Team.class)
                 .prefetch(Team.TEAM_USERS.disjoint())
-                .orderBy("db:team_id", SortOrder.ASCENDING)
+                .orderBy(Team.TEAM_ID_PK_PROPERTY.asc())
                 .select(context);
 
         checkResult(result);
@@ -97,7 +96,7 @@ public class Cay2032IT extends ServerCase {
     public void testPrefetchDisjointById() throws Exception {
         List<Team> result = ObjectSelect.query(Team.class)
                 .prefetch(Team.TEAM_USERS.disjointById())
-                .orderBy("db:team_id", SortOrder.ASCENDING)
+                .orderBy(Team.TEAM_ID_PK_PROPERTY.asc())
                 .select(context);
 
         checkResult(result);
@@ -107,7 +106,7 @@ public class Cay2032IT extends ServerCase {
     public void testPrefetchJoint() throws Exception {
         List<Team> result = ObjectSelect.query(Team.class)
                 .prefetch(Team.TEAM_USERS.joint())
-                .orderBy("db:team_id", SortOrder.ASCENDING)
+                .orderBy(Team.TEAM_ID_PK_PROPERTY.asc())
                 .select(context);
 
         checkResult(result);
