@@ -25,8 +25,8 @@ import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.map.EntityResolver;
 import org.apache.cayenne.map.LifecycleEvent;
 import org.apache.cayenne.query.EJBQLQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.RefreshQuery;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.reflect.LifecycleCallbackRegistry;
 import org.apache.cayenne.testdo.testmap.Artist;
 import org.apache.cayenne.testdo.testmap.Painting;
@@ -35,11 +35,7 @@ import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
 import org.junit.Test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.*;
 
 @UseServerRuntime(CayenneProjects.TESTMAP_PROJECT)
 public class DataDomainCallbacksIT extends ServerCase {
@@ -71,8 +67,7 @@ public class DataDomainCallbacksIT extends ServerCase {
         assertEquals(0, a1.getPostLoaded());
         assertNull(listener.getPublicCalledbackEntity());
 
-        SelectQuery q = new SelectQuery(Artist.class);
-        context.performQuery(q);
+        ObjectSelect.query(Artist.class).select(context);
         assertEquals(1, a1.getPostLoaded());
         assertSame(a1, listener.getPublicCalledbackEntity());
 
@@ -153,8 +148,7 @@ public class DataDomainCallbacksIT extends ServerCase {
 
         context.invalidateObjects(a1, p1);
 
-        SelectQuery q = new SelectQuery(Painting.class);
-        p1 = (Painting) context1.performQuery(q).get(0);
+        p1 = ObjectSelect.query(Painting.class).select(context).get(0);
 
         // this should be a hollow object, so no callback just yet
         a1 = p1.getToArtist();
@@ -186,9 +180,9 @@ public class DataDomainCallbacksIT extends ServerCase {
         p1.setPaintingTitle("XXX");
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(Painting.class);
-        q.addPrefetch(Painting.TO_ARTIST.disjoint());
-        p1 = (Painting) context1.performQuery(q).get(0);
+        p1 = ObjectSelect.query(Painting.class)
+                .prefetch(Painting.TO_ARTIST.disjoint())
+                .select(context).get(0);
 
         // artist is prefetched here, and a callback must have been invoked
         a1 = p1.getToArtist();
@@ -252,8 +246,8 @@ public class DataDomainCallbacksIT extends ServerCase {
 
         context.invalidateObjects(a1, p1);
 
-        SelectQuery<Painting> q = new SelectQuery<>(Painting.class);
-        p1 = q.select(context1).get(0);
+        p1 = ObjectSelect.query(Painting.class)
+                .select(context1).get(0);
 
         // this should be a hollow object, so no callback just yet
         a1 = p1.getToArtist();
