@@ -19,13 +19,17 @@
 
 package org.apache.cayenne.access;
 
+import org.apache.cayenne.Cayenne;
 import org.apache.cayenne.di.Inject;
+import org.apache.cayenne.query.SelectById;
 import org.apache.cayenne.testdo.inheritance.BaseEntity;
+import org.apache.cayenne.testdo.inheritance.DirectToSubEntity;
 import org.apache.cayenne.testdo.inheritance.RelatedEntity;
 import org.apache.cayenne.testdo.inheritance.SubEntity;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
+import org.junit.Ignore;
 import org.junit.Test;
 
 import static org.junit.Assert.assertEquals;
@@ -37,10 +41,10 @@ public class EntityInheritanceIT extends ServerCase {
     private DataContext context;
 
     /**
-     * Test for CAY-1008: Reverse relationships may not be correctly set if inheritance is
-     * used.
+     * Test for CAY-1008: Reverse relationships may not be correctly set if inheritance is used.
      */
     @Test
+    @Ignore("This test fails")
     public void testCAY1008() {
         RelatedEntity related = context.newObject(RelatedEntity.class);
 
@@ -56,42 +60,47 @@ public class EntityInheritanceIT extends ServerCase {
         assertEquals(2, related.getBaseEntities().size());
 
         // TODO: andrus 2008/03/28 - this fails...
-        // assertEquals(1, related.getSubEntities().size());
+        assertEquals(1, related.getSubEntities().size());
     }
 
     /**
      * Test for CAY-1009: Bogus runtime relationships can mess up commit.
      */
     @Test
+    @Ignore("Test fails")
     public void testCAY1009() {
-
         // We should have only one relationship. DirectToSubEntity -> SubEntity.
+        assertEquals(1, context
+                .getEntityResolver()
+                .getObjEntity("DirectToSubEntity")
+                .getRelationships()
+                .size());
 
-        // this fails as a result of 'EntityResolver().applyObjectLayerDefaults()'
-        // creating incorrect relationships
-        // assertEquals(1, context
-        // .getEntityResolver()
-        // .getObjEntity("DirectToSubEntity")
-        // .getRelationships()
-        // .size());
+        DirectToSubEntity direct = context.newObject(DirectToSubEntity.class);
 
-        // We should still just have the one mapped relationship, but we in fact now have
-        // two:
-        // DirectToSubEntity -> BaseEntity and DirectToSubEntity -> SubEntity.
+        SubEntity sub = context.newObject(SubEntity.class);
+        sub.setToDirectToSubEntity(direct);
 
-        // TODO: andrus 2008/03/28 - this fails...
-        // assertEquals(1, context.getEntityResolver().getObjEntity("DirectToSubEntity")
-        // .getRelationships().size());
-        //
-        // DirectToSubEntity direct = context.newObject(DirectToSubEntity.class);
-        //
-        // SubEntity sub = context.newObject(SubEntity.class);
-        // sub.setToDirectToSubEntity(direct);
-        //
-        // assertEquals(1, direct.getSubEntities().size());
-        //
-        // context.deleteObject(sub);
-        // assertEquals(0, direct.getSubEntities().size());
+        assertEquals(1, direct.getSubEntities().size());
+
+        context.deleteObject(sub);
+
+        assertEquals(0, direct.getSubEntities().size());
     }
 
+    @Test
+    public void testCAY2091() {
+        RelatedEntity related = context.newObject(RelatedEntity.class);
+        SubEntity subEntity = context.newObject(SubEntity.class);
+        subEntity.setToRelatedEntity(related);
+        context.commitChanges();
+
+        int subEntityId = Cayenne.intPKForObject(subEntity);
+
+        BaseEntity forPkLoadedEntity = Cayenne.objectForPK(context, BaseEntity.class, subEntityId);
+        assertEquals(forPkLoadedEntity.getClass(), SubEntity.class);
+
+        BaseEntity selectLoadedEntity = SelectById.query(BaseEntity.class, subEntityId).selectOne(context);
+        assertEquals(selectLoadedEntity.getClass(), SubEntity.class);
+    }
 }
