@@ -26,12 +26,11 @@ import org.apache.cayenne.PersistenceState;
 import org.apache.cayenne.ValueHolder;
 import org.apache.cayenne.configuration.server.ServerRuntime;
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.map.ObjAttribute;
 import org.apache.cayenne.map.ObjEntity;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.SQLSelect;
 import org.apache.cayenne.query.SQLTemplate;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.query.SortOrder;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
@@ -93,7 +92,7 @@ public class JointPrefetchIT extends ServerCase {
                 "GALLERY_ID");
     }
 
-    protected void createJointPrefetchDataSet() throws Exception {
+    private void createJointPrefetchDataSet() throws Exception {
         tGallery.insert(33001, "G1");
         tGallery.insert(33002, "G2");
         tArtist.insert(33001, "artist1");
@@ -108,13 +107,11 @@ public class JointPrefetchIT extends ServerCase {
     public void testJointPrefetch_ToOne_FetchLimit() throws Exception {
         createJointPrefetchDataSet();
 
-        SelectQuery<Painting> q = new SelectQuery<>(Painting.class);
-        q.setFetchLimit(2);
-        q.setFetchOffset(0);
-        q.addOrdering("db:PAINTING_ID", SortOrder.ASCENDING);
-        q.addPrefetch(Painting.TO_ARTIST.joint());
-
-        final List<Painting> objects = q.select(context);
+        final List<Painting> objects = ObjectSelect.query(Painting.class)
+                .limit(2).offset(0)
+                .orderBy("db:PAINTING_ID", SortOrder.ASCENDING)
+                .prefetch(Painting.TO_ARTIST.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(2, objects.size());
@@ -131,13 +128,11 @@ public class JointPrefetchIT extends ServerCase {
     public void testJointPrefetch_ToMany_FetchLimit() throws Exception {
         createJointPrefetchDataSet();
 
-        SelectQuery<Artist> q = new SelectQuery<>(Artist.class);
-        q.setFetchLimit(2);
-        q.setFetchOffset(0);
-        q.addOrdering("db:ARTIST_ID", SortOrder.ASCENDING);
-        q.addPrefetch(Artist.PAINTING_ARRAY.joint());
-
-        final List<Artist> objects = q.select(context);
+        final List<Artist> objects = ObjectSelect.query(Artist.class)
+                .limit(2).offset(0)
+                .orderBy(Artist.ARTIST_ID_PK_PROPERTY.asc())
+                .prefetch(Artist.PAINTING_ARRAY.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             // herein lies the limitation of prefetching combined with fetch limit -
@@ -159,11 +154,10 @@ public class JointPrefetchIT extends ServerCase {
         createJointPrefetchDataSet();
 
         // query with to-many joint prefetches
-        SelectQuery<DataRow> q = SelectQuery.dataRowQuery(Painting.class);
-        q.addOrdering("db:PAINTING_ID", SortOrder.ASCENDING);
-        q.addPrefetch(Painting.TO_ARTIST.joint());
-
-        final List<DataRow> rows = q.select(context);
+        final List<DataRow> rows = ObjectSelect.dataRowQuery(Painting.class)
+                .orderBy("db:PAINTING_ID", SortOrder.ASCENDING)
+                .prefetch(Painting.TO_ARTIST.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(3, rows.size());
@@ -235,11 +229,10 @@ public class JointPrefetchIT extends ServerCase {
         createJointPrefetchDataSet();
 
         // query with to-many joint prefetches
-        SelectQuery<Painting> q = new SelectQuery<>(Painting.class);
-        q.addOrdering("db:PAINTING_ID", SortOrder.ASCENDING);
-        q.addPrefetch(Painting.TO_ARTIST.joint());
-
-        final List<Painting> objects = q.select(context);
+        final List<Painting> objects = ObjectSelect.query(Painting.class)
+                .orderBy("db:PAINTING_ID", SortOrder.ASCENDING)
+                .prefetch(Painting.TO_ARTIST.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(3, objects.size());
@@ -273,15 +266,14 @@ public class JointPrefetchIT extends ServerCase {
         context.performNonSelectingQuery(paintingSQL);
 
         // test
-        SelectQuery<Painting> q = new SelectQuery<>(Painting.class);
-        q.addPrefetch(Painting.TO_ARTIST.joint());
-
         ObjEntity artistE = context.getEntityResolver().getObjEntity("Artist");
         ObjAttribute dateOfBirth = artistE.getAttribute("dateOfBirth");
         assertEquals("java.util.Date", dateOfBirth.getType());
         dateOfBirth.setType("java.sql.Date");
         try {
-            final List<Painting> objects = q.select(context);
+            final List<Painting> objects = ObjectSelect.query(Painting.class)
+                    .prefetch(Painting.TO_ARTIST.joint())
+                    .select(context);
 
             queryInterceptor.runWithQueriesBlocked(() -> {
                 assertEquals(1, objects.size());
@@ -302,10 +294,9 @@ public class JointPrefetchIT extends ServerCase {
         createJointPrefetchDataSet();
 
         // query with to-many joint prefetches
-        SelectQuery<Artist> q = new SelectQuery<>(Artist.class);
-        q.addPrefetch(Artist.PAINTING_ARRAY.joint());
-
-        final List<Artist> objects = q.select(context);
+        final List<Artist> objects = ObjectSelect.query(Artist.class)
+                .prefetch(Artist.PAINTING_ARRAY.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(3, objects.size());
@@ -329,13 +320,11 @@ public class JointPrefetchIT extends ServerCase {
     public void testJointPrefetchToManyNonConflictingQualifier() throws Exception {
         createJointPrefetchDataSet();
 
-        // query with to-many joint prefetches and qualifier that doesn't match
-        // prefetch....
-        Expression qualifier = Artist.ARTIST_NAME.eq("artist1");
-        SelectQuery<Artist> q = new SelectQuery<>(Artist.class, qualifier);
-        q.addPrefetch(Artist.PAINTING_ARRAY.joint());
-
-        final List<Artist> objects = q.select(context);
+        // query with to-many joint prefetches and qualifier that doesn't match prefetch....
+        final List<Artist> objects = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .prefetch(Artist.PAINTING_ARRAY.joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(1, objects.size());
@@ -363,10 +352,6 @@ public class JointPrefetchIT extends ServerCase {
     public void testJointPrefetchMultiStep() throws Exception {
         createJointPrefetchDataSet();
 
-        // query with to-many joint prefetches
-        SelectQuery<Artist> q = new SelectQuery<>(Artist.class);
-        q.addPrefetch(Artist.PAINTING_ARRAY.dot(Painting.TO_GALLERY).joint());
-
         final DataContext context = this.context;
 
         // make sure phantomly prefetched objects are not deallocated
@@ -374,10 +359,13 @@ public class JointPrefetchIT extends ServerCase {
 
         // sanity check...
         DataObject g1 = (DataObject) context.getGraphManager().getNode(
-                new ObjectId("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001));
+                ObjectId.of("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001));
         assertNull(g1);
 
-        final List<Artist> objects = q.select(context);
+        // query with to-many joint prefetches
+        final List<Artist> objects = ObjectSelect.query(Artist.class)
+                .prefetch(Artist.PAINTING_ARRAY.dot(Painting.TO_GALLERY).joint())
+                .select(context);
 
         queryInterceptor.runWithQueriesBlocked(() -> {
             assertEquals(3, objects.size());
@@ -393,11 +381,11 @@ public class JointPrefetchIT extends ServerCase {
 
             // however both galleries must be in memory...
             DataObject g11 = (DataObject) context.getGraphManager().getNode(
-                    new ObjectId("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001));
+                    ObjectId.of("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001));
             assertNotNull(g11);
             assertEquals(PersistenceState.COMMITTED, g11.getPersistenceState());
             DataObject g2 = (DataObject) context.getGraphManager().getNode(
-                    new ObjectId("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33002));
+                    ObjectId.of("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33002));
             assertNotNull(g2);
             assertEquals(PersistenceState.COMMITTED, g2.getPersistenceState());
         });
@@ -407,8 +395,10 @@ public class JointPrefetchIT extends ServerCase {
     public void testJointPrefetchSQLSelectToMany() throws Exception {
         createJointPrefetchDataSet();
 
-        @SuppressWarnings("unchecked")
-        final List<Artist> objects = SQLSelect.query(Artist.class, "SELECT "
+        List<Artist> objects = SQLSelect.query(Artist.class, "SELECT "
+                + "#result('ESTIMATED_PRICE' 'BigDecimal' '' 'paintingArray.ESTIMATED_PRICE'), "
+                + "#result('PAINTING_TITLE' 'String' '' 'paintingArray.PAINTING_TITLE'), "
+                + "#result('GALLERY_ID' 'int' '' 'paintingArray.GALLERY_ID'), "
                 + "#result('PAINTING_ID' 'int' '' 'paintingArray.PAINTING_ID'), "
                 + "#result('ARTIST_NAME' 'String'), "
                 + "#result('DATE_OF_BIRTH' 'java.util.Date'), "
@@ -417,8 +407,8 @@ public class JointPrefetchIT extends ServerCase {
                 + "WHERE t0.ARTIST_ID = t1.ARTIST_ID")
                 .addPrefetch(Artist.PAINTING_ARRAY.joint())
                 .select(context);
+
         queryInterceptor.runWithQueriesBlocked(() -> {
-            assertNotNull(objects);
             assertEquals(2, objects.size());
 
             for (Artist artist : objects) {
@@ -426,6 +416,7 @@ public class JointPrefetchIT extends ServerCase {
                 assertTrue(paintings.size() > 0);
                 for (Painting painting : paintings) {
                     assertEquals(PersistenceState.COMMITTED, painting.getPersistenceState());
+                    assertNotNull(painting.getPaintingTitle());
                 }
             }
         });
@@ -443,10 +434,84 @@ public class JointPrefetchIT extends ServerCase {
                 .select(context);
         queryInterceptor.runWithQueriesBlocked(() -> {
             DataObject g1 = (DataObject) context.getGraphManager().getNode(
-                    new ObjectId("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001)
+                    ObjectId.of("Gallery", Gallery.GALLERY_ID_PK_COLUMN, 33001)
             );
             assertNotNull(g1);
             assertEquals("G1", g1.readProperty("galleryName"));
         });
     }
+
+    @Test
+    public void testJointPrefetchPreservesPendingToOneArcDiff() throws Exception {
+        createJointPrefetchDataSet();
+
+        Artist artist = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .selectFirst(context);
+
+        Painting painting = ObjectSelect.query(Painting.class)
+                .where(Painting.PAINTING_TITLE.eq("P_artist21"))
+                .selectFirst(context);
+
+        // create pending arc diff
+        painting.setToArtist(artist);
+
+        // refresh the painting (should preserve pending arc diff)
+        ObjectSelect.query(Painting.class)
+                .where(Painting.PAINTING_TITLE.eq("P_artist21"))
+                .selectFirst(context);
+        assertEquals(artist, painting.getToArtist());
+
+        // refresh the artist (should preserve pending arc diff)
+        ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .selectFirst(context);
+        assertEquals(artist, painting.getToArtist());
+
+        // refresh them both together (should preserve pending arc diff)
+        ObjectSelect.query(Painting.class)
+                .where(Painting.PAINTING_TITLE.eq("P_artist21"))
+                .prefetch(Painting.TO_ARTIST.joint())
+                .selectFirst(context);
+
+        assertEquals(artist, painting.getToArtist());
+    }
+
+    @Test
+    public void testJointPrefetchPreservesPendingToManyArcDiff() throws Exception {
+        createJointPrefetchDataSet();
+
+        Artist artist = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .selectFirst(context);
+
+        Painting painting = ObjectSelect.query(Painting.class)
+                .where(Painting.PAINTING_TITLE.eq("P_artist21"))
+                .selectFirst(context);
+
+        // create pending arc diff
+        artist.addToPaintingArray(painting);
+
+        // refresh the painting (should preserve pending arc diff)
+        ObjectSelect.query(Painting.class)
+                .where(Painting.PAINTING_TITLE.eq("P_artist21"))
+                .selectFirst(context);
+        assertEquals(3, artist.getPaintingArray().size());
+        assertTrue(artist.getPaintingArray().contains(painting));
+
+        // refresh the artist (should preserve pending arc diff)
+        ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .selectFirst(context);
+        assertEquals(3, artist.getPaintingArray().size());
+        assertTrue(artist.getPaintingArray().contains(painting));
+
+        // refresh them both together (should preserve pending arc diff)
+        ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.eq("artist1"))
+                .prefetch(Artist.PAINTING_ARRAY.joint())
+                .select(context);
+        assertEquals(3, artist.getPaintingArray().size());
+        assertTrue(artist.getPaintingArray().contains(painting));
+    }
 }
