@@ -19,14 +19,17 @@
 
 package org.apache.cayenne.access;
 
+import java.math.BigDecimal;
+import java.math.BigInteger;
+import java.util.List;
+
 import org.apache.cayenne.ObjectId;
 import org.apache.cayenne.configuration.server.ServerRuntime;
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
-import org.apache.cayenne.exp.Property;
+import org.apache.cayenne.exp.property.NumericProperty;
+import org.apache.cayenne.exp.property.PropertyFactory;
 import org.apache.cayenne.query.ObjectSelect;
-import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.numeric_types.BigDecimalEntity;
@@ -38,22 +41,21 @@ import org.apache.cayenne.testdo.numeric_types.DecimalPKTestEntity;
 import org.apache.cayenne.testdo.numeric_types.LongEntity;
 import org.apache.cayenne.testdo.numeric_types.SmallintTestEntity;
 import org.apache.cayenne.testdo.numeric_types.TinyintTestEntity;
+import org.apache.cayenne.unit.di.CommitStats;
+import org.apache.cayenne.unit.di.DataChannelInterceptor;
+import org.apache.cayenne.unit.di.DataChannelSyncStats;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
+import org.junit.After;
 import org.junit.Before;
+import org.junit.Rule;
 import org.junit.Test;
 
-import java.math.BigDecimal;
-import java.math.BigInteger;
-import java.util.List;
-
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertSame;
+import static org.junit.Assert.*;
 
 /**
+ *
  */
 @UseServerRuntime(CayenneProjects.NUMERIC_TYPES_PROJECT)
 public class NumericTypesIT extends ServerCase {
@@ -70,11 +72,15 @@ public class NumericTypesIT extends ServerCase {
     @Inject
     protected DBHelper dbHelper;
 
+    private final CommitStats commitStats = new CommitStats(() -> runtime.getDataDomain());
+
     protected TableHelper tSmallintTest;
     protected TableHelper tTinyintTest;
 
     @Before
-    public void setUp() throws Exception {
+    public void before() {
+        commitStats.before();
+
         tSmallintTest = new TableHelper(dbHelper, "SMALLINT_TEST");
         tSmallintTest.setColumns("ID", "SMALLINT_COL");
 
@@ -82,6 +88,11 @@ public class NumericTypesIT extends ServerCase {
         tTinyintTest.setColumns("ID", "TINYINT_COL");
     }
 
+    @After
+    public void after() {
+        commitStats.after();
+    }
+
     protected void createShortDataSet() throws Exception {
         tSmallintTest.insert(1, 9999);
         tSmallintTest.insert(2, 3333);
@@ -101,8 +112,8 @@ public class NumericTypesIT extends ServerCase {
         test.setLongField(i);
         context.commitChanges();
 
-        SelectQuery<LongEntity> q = new SelectQuery<>(LongEntity.class);
-        LongEntity testRead = (LongEntity) context.performQuery(q).get(0);
+        LongEntity testRead = ObjectSelect.query(LongEntity.class)
+                .selectFirst(context);
         assertNotNull(testRead.getLongField());
         assertEquals(i, testRead.getLongField());
 
@@ -119,8 +130,8 @@ public class NumericTypesIT extends ServerCase {
         test.setBigIntegerField(i);
         context.commitChanges();
 
-        SelectQuery<BigIntegerEntity> q = new SelectQuery<>(BigIntegerEntity.class);
-        BigIntegerEntity testRead = (BigIntegerEntity) context.performQuery(q).get(0);
+        BigIntegerEntity testRead = ObjectSelect.query(BigIntegerEntity.class)
+                .selectFirst(context);
         assertNotNull(testRead.getBigIntegerField());
         assertEquals(i, testRead.getBigIntegerField());
 
@@ -129,21 +140,70 @@ public class NumericTypesIT extends ServerCase {
     }
 
     @Test
-    public void testBigDecimal() throws Exception {
+    public void testBigDecimal_Decimal() {
 
-        BigDecimalEntity test = context.newObject(BigDecimalEntity.class);
+        // this matches the column scale exactly
+        String v1 = "7890.123456";
+        // this has lower scale than the column
+        String v2 = "7890.1";
+        String v2_padded = "7890.100000";
 
-        BigDecimal i = new BigDecimal("1234567890.44");
-        test.setBigDecimalField(i);
-        context.commitChanges();
+        BigDecimalEntity o = context.newObject(BigDecimalEntity.class);
+        o.setBigDecimalDecimal(new BigDecimal(v1));
+        o.getObjectContext().commitChanges();
+        assertEquals(1, commitStats.getCommitCount());
+        BigDecimalEntity o1 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v1, o1.getBigDecimalDecimal().toString());
 
-        SelectQuery<BigDecimalEntity> q = new SelectQuery<>(BigDecimalEntity.class);
-        BigDecimalEntity testRead = (BigDecimalEntity) context.performQuery(q).get(0);
-        assertNotNull(testRead.getBigDecimalField());
-        assertEquals(i, testRead.getBigDecimalField());
+        o.setBigDecimalDecimal(new BigDecimal(v2));
+        o.getObjectContext().commitChanges();
+        BigDecimalEntity o2 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v2_padded, o2.getBigDecimalDecimal().toString());
+        assertEquals(2, commitStats.getCommitCount());
 
-        test.setBigDecimalField(null);
-        context.commitChanges();
+        o2.setBigDecimalDecimal(new BigDecimal(v2));
+        o2.getObjectContext().commitChanges();
+        assertEquals("Commit was not expected. The difference is purely in value padding", 2, commitStats.getCommitCount());
+        BigDecimalEntity o3 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v2_padded, o3.getBigDecimalDecimal().toString());
+
+        o3.setBigDecimalDecimal(null);
+        o3.getObjectContext().commitChanges();
+        assertEquals(3, commitStats.getCommitCount());
+        BigDecimalEntity o4 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertNull(o4.getBigDecimalDecimal());
+    }
+
+    @Test
+    public void testBigDecimal_Numeric() {
+
+        String v1 = "1234567890.44";
+        String v2 = "1234567890.4";
+        String v2_padded = "1234567890.40";
+
+        BigDecimalEntity o = context.newObject(BigDecimalEntity.class);
+        o.setBigDecimalNumeric(new BigDecimal(v1));
+        o.getObjectContext().commitChanges();
+        assertEquals(1, commitStats.getCommitCount());
+        BigDecimalEntity o1 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v1, o1.getBigDecimalNumeric().toString());
+
+        o1.setBigDecimalNumeric(new BigDecimal(v2));
+        o1.getObjectContext().commitChanges();
+        assertEquals(2, commitStats.getCommitCount());
+        BigDecimalEntity o2 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v2_padded, o2.getBigDecimalNumeric().toString());
+
+        o2.setBigDecimalNumeric(new BigDecimal(v2));
+        assertEquals("Commit was not expected. The difference is purely in value padding", 2, commitStats.getCommitCount());
+        BigDecimalEntity o3 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertEquals(v2_padded, o3.getBigDecimalNumeric().toString());
+
+        o3.setBigDecimalNumeric(null);
+        o3.getObjectContext().commitChanges();
+        assertEquals(3, commitStats.getCommitCount());
+        BigDecimalEntity o4 = ObjectSelect.query(BigDecimalEntity.class).selectFirst(runtime.newContext());
+        assertNull(o4.getBigDecimalNumeric());
     }
 
     @Test
@@ -151,21 +211,20 @@ public class NumericTypesIT extends ServerCase {
         createShortDataSet();
 
         // test
-        Expression qual = ExpressionFactory.matchExp("smallintCol", new Short("9999"));
-        List<?> objects = context.performQuery(new SelectQuery<>(
-                SmallintTestEntity.class,
-                qual));
+        List<SmallintTestEntity> objects = ObjectSelect.query(SmallintTestEntity.class)
+                .where(SmallintTestEntity.SMALLINT_COL.eq(Short.valueOf("9999")))
+                .select(context);
         assertEquals(1, objects.size());
 
-        SmallintTestEntity object = (SmallintTestEntity) objects.get(0);
-        assertEquals(new Short("9999"), object.getSmallintCol());
+        SmallintTestEntity object = objects.get(0);
+        assertEquals(Short.valueOf("9999"), object.getSmallintCol());
     }
 
     @Test
     public void testShortInInsert() throws Exception {
         SmallintTestEntity object = (SmallintTestEntity) (context)
                 .newObject("SmallintTestEntity");
-        object.setSmallintCol(new Short("1"));
+        object.setSmallintCol(Short.valueOf("1"));
         context.commitChanges();
     }
 
@@ -174,14 +233,13 @@ public class NumericTypesIT extends ServerCase {
         createTinyintDataSet();
 
         // test
-        Expression qual = ExpressionFactory.matchExp("tinyintCol", (byte) 81);
-        List<?> objects = context.performQuery(new SelectQuery<>(
-                TinyintTestEntity.class,
-                qual));
+        List<?> objects = ObjectSelect.query(TinyintTestEntity.class)
+                .where(TinyintTestEntity.TINYINT_COL.eq((byte) 81))
+                .select(context);
         assertEquals(1, objects.size());
 
         TinyintTestEntity object = (TinyintTestEntity) objects.get(0);
-        assertEquals(new Byte((byte) 81), object.getTinyintCol());
+        assertEquals(Byte.valueOf((byte) 81), object.getTinyintCol());
     }
 
     @Test
@@ -203,10 +261,9 @@ public class NumericTypesIT extends ServerCase {
         context.invalidateObjects(trueObject, falseObject);
 
         // fetch true...
-        Expression trueQ = ExpressionFactory.matchExp("bitColumn", Boolean.TRUE);
-        List<?> trueResult = context1.performQuery(new SelectQuery<>(
-                BitTestEntity.class,
-                trueQ));
+        List<?> trueResult = ObjectSelect.query(BitTestEntity.class)
+                .where(BitTestEntity.BIT_COLUMN.eq(Boolean.TRUE))
+                .select(context1);
         assertEquals(1, trueResult.size());
 
         BitTestEntity trueRefetched = (BitTestEntity) trueResult.get(0);
@@ -217,10 +274,9 @@ public class NumericTypesIT extends ServerCase {
         assertSame(Boolean.TRUE, trueRefetched.getBitColumn());
 
         // fetch false
-        Expression falseQ = ExpressionFactory.matchExp("bitColumn", Boolean.FALSE);
-        List<?> falseResult = context1.performQuery(new SelectQuery<>(
-                BitTestEntity.class,
-                falseQ));
+        List<?> falseResult = ObjectSelect.query(BitTestEntity.class)
+                .where(BitTestEntity.BIT_COLUMN.eq(Boolean.FALSE))
+                .select(context1);
         assertEquals(1, falseResult.size());
 
         BitTestEntity falseRefetched = (BitTestEntity) falseResult.get(0);
@@ -246,10 +302,9 @@ public class NumericTypesIT extends ServerCase {
         context.invalidateObjects(trueObject, falseObject);
 
         // fetch true...
-        Expression trueQ = ExpressionFactory.matchExp("booleanColumn", Boolean.TRUE);
-        List<?> trueResult = context1.performQuery(new SelectQuery<>(
-                BooleanTestEntity.class,
-                trueQ));
+        List<?> trueResult = ObjectSelect.query(BooleanTestEntity.class)
+                .where(BooleanTestEntity.BOOLEAN_COLUMN.eq(Boolean.TRUE))
+                .select(context1);
         assertEquals(1, trueResult.size());
 
         BooleanTestEntity trueRefetched = (BooleanTestEntity) trueResult.get(0);
@@ -260,10 +315,9 @@ public class NumericTypesIT extends ServerCase {
         assertSame(Boolean.TRUE, trueRefetched.getBooleanColumn());
 
         // fetch false
-        Expression falseQ = ExpressionFactory.matchExp("booleanColumn", Boolean.FALSE);
-        List<?> falseResult = context1.performQuery(new SelectQuery<>(
-                BooleanTestEntity.class,
-                falseQ));
+        List<?> falseResult = ObjectSelect.query(BooleanTestEntity.class)
+                .where(BooleanTestEntity.BOOLEAN_COLUMN.eq(Boolean.FALSE))
+                .select(context1);
         assertEquals(1, falseResult.size());
 
         BooleanTestEntity falseRefetched = (BooleanTestEntity) falseResult.get(0);
@@ -284,7 +338,7 @@ public class NumericTypesIT extends ServerCase {
         object.setDecimalPK(new BigDecimal("1.25"));
         context.commitChanges();
 
-        ObjectId syntheticId = new ObjectId(
+        ObjectId syntheticId = ObjectId.of(
                 "DecimalPKTestEntity",
                 "DECIMAL_PK",
                 new BigDecimal("1.25"));
@@ -304,7 +358,7 @@ public class NumericTypesIT extends ServerCase {
         object.setDecimalPK(1.25);
         context.commitChanges();
 
-        ObjectId syntheticId = new ObjectId("DecimalPKTest1", "DECIMAL_PK", 1.25);
+        ObjectId syntheticId = ObjectId.of("DecimalPKTest1", "DECIMAL_PK", 1.25);
         assertSame(object, context.getGraphManager().getNode(syntheticId));
     }
 
@@ -320,8 +374,8 @@ public class NumericTypesIT extends ServerCase {
 
         assertEquals(i, readValue);
 
-        Property<BigInteger> calculated =
-                Property.create(ExpressionFactory.exp("bigIntegerField + 1"), BigInteger.class);
+        NumericProperty<BigInteger> calculated =
+                PropertyFactory.createNumeric(ExpressionFactory.exp("bigIntegerField + 1"), BigInteger.class);
 
         BigInteger readValue2 = ObjectSelect.query(BigIntegerEntity.class)
                 .column(calculated).selectOne(context);
