@@ -18,10 +18,16 @@
  ****************************************************************/
 package org.apache.cayenne.access;
 
+import java.math.BigDecimal;
+import java.sql.Time;
+import java.util.Arrays;
+import java.util.Calendar;
+import java.util.Date;
+
 import org.apache.cayenne.DataRow;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.query.MappedSelect;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.testdo.return_types.ReturnTypesMap1;
 import org.apache.cayenne.testdo.return_types.ReturnTypesMap2;
 import org.apache.cayenne.testdo.return_types.ReturnTypesMapLobs1;
@@ -32,13 +38,10 @@ import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
 import org.junit.Test;
 
-import java.math.BigDecimal;
-import java.sql.Time;
-import java.util.Arrays;
-import java.util.Calendar;
-import java.util.Date;
-
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertArrayEquals;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.junit.Assume.assumeTrue;
 
 /**
@@ -49,12 +52,12 @@ public class ReturnTypesMappingIT extends ServerCase {
 
     @Inject
     private DataContext context;
-    
+
     @Inject
     private UnitDbAdapter unitDbAdapter;
 
     /*
-     * TODO: olga: We need divided TYPES_MAPPING_TES2 to 2 schemas with lobs columns and not lobs columns 
+     * TODO: olga: We need divided TYPES_MAPPING_TES2 to 2 schemas with lobs columns and not lobs columns
      */
 
     @Test
@@ -65,7 +68,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Long bigintValue = 5326457654783454355l;
         test.setBigintColumn(bigintValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -81,13 +84,14 @@ public class ReturnTypesMappingIT extends ServerCase {
     @Test
     public void testBIGINT2() throws Exception {
        ReturnTypesMap1 test = context.newObject(ReturnTypesMap1.class);
-    
+
         Long bigintValue = 5326457654783454355l;
         test.setBigintColumn(bigintValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Long columnValue = testRead.getBigintColumn();
         assertNotNull(columnValue);
         assertEquals(Long.class, columnValue.getClass());
@@ -99,13 +103,13 @@ public class ReturnTypesMappingIT extends ServerCase {
         if (unitDbAdapter.supportsLobs()) {
             String columnName = "BINARY_COLUMN";
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] binaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setBinaryColumn(binaryValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap2")).get(0);
             Object columnValue = testRead.get(columnName);
             assertNotNull(columnValue);
@@ -118,19 +122,20 @@ public class ReturnTypesMappingIT extends ServerCase {
     public void testBINARY2() throws Exception {
         if (unitDbAdapter.supportsLobs()) {
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] binaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setBinaryColumn(binaryValue);
             context.commitChanges();
-    
-            SelectQuery q = new SelectQuery(ReturnTypesMap2.class);
-            ReturnTypesMap2 testRead = (ReturnTypesMap2) context.performQuery(q).get(0);
+
+            ReturnTypesMap2 testRead = ObjectSelect
+                    .query(ReturnTypesMap2.class)
+                    .selectFirst(context);
             byte[] columnValue = testRead.getBinaryColumn();
             assertNotNull(columnValue);
             assertEquals(byte[].class, columnValue.getClass());
-            assertTrue(Arrays.equals(binaryValue, columnValue));
+            assertArrayEquals(binaryValue, columnValue);
         }
     }
 
@@ -142,7 +147,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Boolean bitValue = true;
         test.setBitColumn(bitValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -160,8 +165,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setBitColumn(bitValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Boolean columnValue = testRead.getBitColumn();
         assertNotNull(columnValue);
         assertEquals(Boolean.class, columnValue.getClass());
@@ -176,13 +182,13 @@ public class ReturnTypesMappingIT extends ServerCase {
         if (unitDbAdapter.supportsLobs()) {
             String columnName = "BLOB_COLUMN";
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] blobValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setBlobColumn(blobValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap2")).get(0);
             Object columnValue = testRead.get(columnName);
             assertNotNull(columnValue);
@@ -195,15 +201,16 @@ public class ReturnTypesMappingIT extends ServerCase {
     public void testBLOB2() throws Exception {
         if (unitDbAdapter.supportsLobs()) {
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] blobValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setBlobColumn(blobValue);
             context.commitChanges();
-    
-            SelectQuery q = new SelectQuery(ReturnTypesMap2.class);
-            ReturnTypesMap2 testRead = (ReturnTypesMap2) context.performQuery(q).get(0);
+
+            ReturnTypesMap2 testRead = ObjectSelect
+                    .query(ReturnTypesMap2.class)
+                    .selectFirst(context);
             byte[] columnValue = testRead.getBlobColumn();
             assertNotNull(columnValue);
             assertEquals(byte[].class, columnValue.getClass());
@@ -219,7 +226,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Boolean booleanValue = true;
         test.setBooleanColumn(booleanValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -238,8 +245,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setBooleanColumn(booleanValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Boolean columnValue = testRead.getBooleanColumn();
         assertNotNull(columnValue);
         assertEquals(Boolean.class, columnValue.getClass());
@@ -254,7 +262,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String charValue = "Char string for tests!";
         test.setCharColumn(charValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -270,7 +278,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String charValue = "درخت‌های جستجوی متوازن، نیازی ندارد که به صورت!";
         test.setNcharColumn(charValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -286,8 +294,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setCharColumn(charValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         String columnValue = testRead.getCharColumn();
         assertNotNull(columnValue);
         assertEquals(String.class, columnValue.getClass());
@@ -299,7 +308,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         if (unitDbAdapter.supportsLobs()) {
             String columnName = "CLOB_COLUMN";
             ReturnTypesMapLobs1 test = context.newObject(ReturnTypesMapLobs1.class);
-    
+
             StringBuffer buffer = new StringBuffer();
             for (int i = 0; i < 10000; i++) {
                 buffer.append("CLOB very large string for tests!!!!\n");
@@ -307,7 +316,7 @@ public class ReturnTypesMappingIT extends ServerCase {
             String clobValue = buffer.toString();
             test.setClobColumn(clobValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesLobsMap1")).get(0);
             Object columnValue = testRead.get(columnName);
             if (columnValue == null && testRead.containsKey(columnName.toLowerCase())) {
@@ -333,7 +342,7 @@ public class ReturnTypesMappingIT extends ServerCase {
             String clobValue = buffer.toString();
             test.setNclobColumn(clobValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesLobsMap1")).get(0);
             Object columnValue = testRead.get(columnName);
             if (columnValue == null && testRead.containsKey(columnName.toLowerCase())) {
@@ -349,7 +358,7 @@ public class ReturnTypesMappingIT extends ServerCase {
     public void testCLOB2() throws Exception {
         if (unitDbAdapter.supportsLobs()) {
             ReturnTypesMapLobs1 test = context.newObject(ReturnTypesMapLobs1.class);
-    
+
             StringBuffer buffer = new StringBuffer();
             for (int i = 0; i < 10000; i++) {
                 buffer.append("CLOB very large string for tests!!!!\n");
@@ -357,9 +366,10 @@ public class ReturnTypesMappingIT extends ServerCase {
             String clobValue = buffer.toString();
             test.setClobColumn(clobValue);
             context.commitChanges();
-    
-            SelectQuery q = new SelectQuery(ReturnTypesMapLobs1.class);
-            ReturnTypesMapLobs1 testRead = (ReturnTypesMapLobs1) context.performQuery(q).get(0);
+
+            ReturnTypesMapLobs1 testRead = ObjectSelect
+                    .query(ReturnTypesMapLobs1.class)
+                    .selectFirst(context);
             String columnValue = testRead.getClobColumn();
             assertNotNull(columnValue);
             assertEquals(String.class, columnValue.getClass());
@@ -378,7 +388,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Date dateValue = cal.getTime();
         test.setDateColumn(dateValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -397,8 +407,10 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setDateColumn(dateValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Date columnValue = testRead.getDateColumn();
         assertNotNull(columnValue);
         assertEquals(Date.class, columnValue.getClass());
@@ -413,7 +425,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         BigDecimal decimalValue = new BigDecimal("578438.57843");
         test.setDecimalColumn(decimalValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -429,8 +441,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setDecimalColumn(decimalValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         BigDecimal columnValue = testRead.getDecimalColumn();
         assertNotNull(columnValue);
         assertEquals(BigDecimal.class, columnValue.getClass());
@@ -445,7 +458,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Double doubleValue = 3298.4349783d;
         test.setDoubleColumn(doubleValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -466,8 +479,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setDoubleColumn(doubleValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Double columnValue = testRead.getDoubleColumn();
         assertNotNull(columnValue);
         assertEquals(Double.class, columnValue.getClass());
@@ -482,7 +496,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Float floatValue = 375.437f;
         test.setFloatColumn(floatValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -503,8 +517,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setFloatColumn(floatValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Float columnValue = testRead.getFloatColumn();
         assertNotNull(columnValue);
         assertEquals(Float.class, columnValue.getClass());
@@ -519,7 +534,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Integer integerValue = 54235;
         test.setIntegerColumn(integerValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -535,8 +550,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setIntegerColumn(integerValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Integer columnValue = testRead.getIntegerColumn();
         assertNotNull(columnValue);
         assertEquals(Integer.class, columnValue.getClass());
@@ -548,13 +564,13 @@ public class ReturnTypesMappingIT extends ServerCase {
         if (unitDbAdapter.supportsLobs()) {
             String columnName = "LONGVARBINARY_COLUMN";
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] longvarbinaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setLongvarbinaryColumn(longvarbinaryValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap2")).get(0);
             Object columnValue = testRead.get(columnName);
             assertNotNull(columnValue);
@@ -567,15 +583,16 @@ public class ReturnTypesMappingIT extends ServerCase {
     public void testLONGVARBINARY2() throws Exception {
         if (unitDbAdapter.supportsLobs()) {
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] longvarbinaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setLongvarbinaryColumn(longvarbinaryValue);
             context.commitChanges();
-    
-            SelectQuery q = new SelectQuery(ReturnTypesMap2.class);
-            ReturnTypesMap2 testRead = (ReturnTypesMap2) context.performQuery(q).get(0);
+
+            ReturnTypesMap2 testRead = ObjectSelect
+                    .query(ReturnTypesMap2.class)
+                    .selectFirst(context);
             byte[] columnValue = testRead.getLongvarbinaryColumn();
             assertNotNull(columnValue);
             assertEquals(byte[].class, columnValue.getClass());
@@ -595,7 +612,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String longvarcharValue = buffer.toString();
         test.setLongvarcharColumn(longvarcharValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -615,7 +632,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String longnvarcharValue = buffer.toString();
         test.setLongnvarcharColumn(longnvarcharValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -635,8 +652,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setLongvarcharColumn(longvarcharValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         String columnValue = testRead.getLongvarcharColumn();
         assertNotNull(columnValue);
         assertEquals(String.class, columnValue.getClass());
@@ -651,7 +669,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         BigDecimal numericValue = new BigDecimal("578438.57843");
         test.setNumericColumn(numericValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -667,8 +685,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setNumericColumn(numericValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         BigDecimal columnValue = testRead.getNumericColumn();
         assertNotNull(columnValue);
         assertEquals(BigDecimal.class, columnValue.getClass());
@@ -683,7 +702,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Float realValue = 5788.57843f;
         test.setRealColumn(realValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -711,8 +730,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setRealColumn(realValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Float columnValue = testRead.getRealColumn();
         assertNotNull(columnValue);
         assertEquals(Float.class, columnValue.getClass());
@@ -728,7 +748,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Integer intValue = 32564;
         test.setSmallintColumn(smallintValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -749,8 +769,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setSmallintColumn(smallintValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Short columnValue = testRead.getSmallintColumn();
         assertNotNull(columnValue);
         assertEquals(Short.class, columnValue.getClass());
@@ -768,7 +789,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Date timeValue = new Time(cal.getTime().getTime());
         test.setTimeColumn(timeValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -788,8 +809,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setTimeColumn(timeValue);
         context.commitChanges();
 
-        SelectQuery<ReturnTypesMap1> q = new SelectQuery<>(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = q.selectOne(context);
+        ReturnTypesMap1 testRead =ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectOne(context);
         Date columnValue = testRead.getTimeColumn();
         assertNotNull(columnValue);
         assertEquals(Date.class, columnValue.getClass());
@@ -804,12 +826,12 @@ public class ReturnTypesMappingIT extends ServerCase {
         Date timestampValue = Calendar.getInstance().getTime();
         test.setTimestampColumn(timestampValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
         assertEquals(Date.class, columnValue.getClass());
-        
+
         // some DB's, noteably MySQL, strip the milliseconds from timestamps,
         // so comparing within 1 second precision
         long delta = timestampValue.getTime() - ((Date) columnValue).getTime();
@@ -824,12 +846,13 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setTimestampColumn(timestampValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Date columnValue = testRead.getTimestampColumn();
         assertNotNull(columnValue);
         assertEquals(Date.class, columnValue.getClass());
-        
+
         // some DB's, noteably MySQL, strip the milliseconds from timestamps,
         // so comparing within 1 second precision
         long delta = timestampValue.getTime() - ((Date) columnValue).getTime();
@@ -844,7 +867,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         Integer intValue = 89;
         test.setTinyintColumn(tinyintValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -864,8 +887,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setTinyintColumn(tinyintValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         Byte columnValue = testRead.getTinyintColumn();
         assertNotNull(columnValue);
         assertEquals(Byte.class, columnValue.getClass());
@@ -877,13 +901,13 @@ public class ReturnTypesMappingIT extends ServerCase {
         if (unitDbAdapter.supportsLobs()) {
             String columnName = "VARBINARY_COLUMN";
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] varbinaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setVarbinaryColumn(varbinaryValue);
             context.commitChanges();
-			
+
             DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap2")).get(0);
             Object columnValue = testRead.get(columnName);
             assertNotNull(columnValue);
@@ -896,15 +920,16 @@ public class ReturnTypesMappingIT extends ServerCase {
     public void testVARBINARY2() throws Exception {
         if (unitDbAdapter.supportsLobs()) {
             ReturnTypesMap2 test = context.newObject(ReturnTypesMap2.class);
-    
+
             byte[] varbinaryValue = {
                     3, 4, 5, -6, 7, 0, 2, 9, 45, 64, 3, 127, -128, -60
             };
             test.setVarbinaryColumn(varbinaryValue);
             context.commitChanges();
-    
-            SelectQuery q = new SelectQuery(ReturnTypesMap2.class);
-            ReturnTypesMap2 testRead = (ReturnTypesMap2) context.performQuery(q).get(0);
+
+            ReturnTypesMap2 testRead = ObjectSelect
+                    .query(ReturnTypesMap2.class)
+                    .selectFirst(context);
             byte[] columnValue = testRead.getVarbinaryColumn();
             assertNotNull(columnValue);
             assertEquals(byte[].class, columnValue.getClass());
@@ -920,7 +945,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String varcharValue = "VARChar string for tests!";
         test.setVarcharColumn(varcharValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -936,7 +961,7 @@ public class ReturnTypesMappingIT extends ServerCase {
         String varcharValue = "ی متوازن، نیازی ندارد که ب";
         test.setNvarcharColumn(varcharValue);
         context.commitChanges();
-		
+
         DataRow testRead = (DataRow) context.performQuery(MappedSelect.query("SelectReturnTypesMap1")).get(0);
         Object columnValue = testRead.get(columnName);
         assertNotNull(columnValue);
@@ -952,8 +977,9 @@ public class ReturnTypesMappingIT extends ServerCase {
         test.setVarcharColumn(varcharValue);
         context.commitChanges();
 
-        SelectQuery q = new SelectQuery(ReturnTypesMap1.class);
-        ReturnTypesMap1 testRead = (ReturnTypesMap1) context.performQuery(q).get(0);
+        ReturnTypesMap1 testRead = ObjectSelect
+                .query(ReturnTypesMap1.class)
+                .selectFirst(context);
         String columnValue = testRead.getVarcharColumn();
         assertNotNull(columnValue);
         assertEquals(String.class, columnValue.getClass());
