@@ -33,6 +33,8 @@ import org.apache.cayenne.testdo.inheritance_vertical.*;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
+import org.junit.After;
+import org.junit.Before;
 import org.junit.Test;
 
 import java.sql.SQLException;
@@ -57,6 +59,29 @@ public class VerticalInheritanceIT extends ServerCase {
 	@Inject
 	protected ServerRuntime runtime;
 
+	TableHelper ivAbstractTable;
+
+	TableHelper ivConcreteTable;
+
+	@Before
+	public void setup() {
+		ivAbstractTable = new TableHelper(dbHelper, "IV_ABSTRACT");
+		ivAbstractTable.setColumns("ID", "PARENT_ID", "TYPE")
+				.setColumnTypes(Types.INTEGER, Types.INTEGER, Types.CHAR);
+		ivConcreteTable = new TableHelper(dbHelper, "IV_CONCRETE");
+		ivConcreteTable.setColumns("ID", "NAME", "RELATED_ABSTRACT_ID")
+				.setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.INTEGER);
+	}
+
+	@After
+	public void cleanUpConcrete() throws SQLException {
+		ivConcreteTable.deleteAll();
+		ivAbstractTable.deleteAll();
+
+		assertEquals(0, ivAbstractTable.getRowCount());
+		assertEquals(0, ivConcreteTable.getRowCount());
+	}
+
     @Test
 	public void testInsert_Root() throws Exception {
 
@@ -595,7 +620,7 @@ public class VerticalInheritanceIT extends ServerCase {
 	}
 
 	@Test
-	public void testUpdateWithRelationship() {
+	public void testUpdateWithRelationship() throws SQLException {
 		IvConcrete parent1 = context.newObject(IvConcrete.class);
 		parent1.setName("Parent1");
 		context.commitChanges();
@@ -619,6 +644,162 @@ public class VerticalInheritanceIT extends ServerCase {
 		context.commitChanges();
 	}
 
+	/**
+     * @link https://issues.apache.org/jira/browse/CAY-2838
+     */
+	@Test
+	public void testNullifyFlattenedAttribute() throws SQLException {
+		IvConcrete concrete = context.newObject(IvConcrete.class);
+		concrete.setName("Concrete");
+		context.commitChanges();
+
+		concrete.setName(null);
+		context.commitChanges();
+
+		assertNull(concrete.getName());
+
+		long id = Cayenne.longPKForObject(concrete);
+		{
+			ObjectContext cleanContext = runtime.newContext();
+			IvConcrete concreteFetched = SelectById.query(IvConcrete.class, id).selectOne(cleanContext);
+			assertNull(concreteFetched.getName());
+		}
+	}
+
+	@Test
+	public void testNullifyFlattenedRelationship() {
+		IvOther other = context.newObject(IvOther.class);
+		other.setName("other");
+
+		IvImpl impl = context.newObject(IvImpl.class);
+		impl.setName("Impl 1");
+		impl.setOther1(other);
+		context.commitChanges();
+
+		impl.setOther1(null);
+		context.commitChanges();
+
+		assertNull(impl.getOther1());
+
+		long id = Cayenne.longPKForObject(impl);
+		{
+			ObjectContext cleanContext = runtime.newContext();
+			IvImpl implFetched = SelectById.query(IvImpl.class, id).selectOne(cleanContext);
+			assertEquals("Impl 1", implFetched.getName());
+			assertNull(implFetched.getOther1());
+		}
+	}
+
+	@Test
+	public void testUpdateFlattenedRelationshipWithInverse() throws SQLException {
+		TableHelper ivOtherTable = new TableHelper(dbHelper, "IV_OTHER");
+		ivOtherTable.setColumns("ID", "NAME").setColumnTypes(Types.INTEGER, Types.VARCHAR);
+
+		TableHelper ivBaseTable = new TableHelper(dbHelper, "IV_BASE");
+		ivBaseTable.setColumns("ID", "NAME", "TYPE").setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.CHAR);
+
+		TableHelper ivImplTable = new TableHelper(dbHelper, "IV_IMPL");
+		ivImplTable.setColumns("ID", "ATTR1", "OTHER3_ID").setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.INTEGER);
+
+		ivOtherTable.insert(1, "other1");
+		ivOtherTable.insert(2, "other2");
+		ivBaseTable.insert(1, "Impl 1", "I");
+		ivImplTable.insert(1, "attr1", 1);
+
+		IvImpl impl = SelectById.query(IvImpl.class, 1).selectOne(context);
+		IvOther other = SelectById.query(IvOther.class, 2).selectOne(context);
+
+		impl.setOther3(other);
+		context.commitChanges();
+		assertEquals("Impl 1", impl.getName());
+		assertEquals("attr1", impl.getAttr1());
+		assertEquals(impl.getOther3(), other);
+
+		{
+			ObjectContext cleanContext = runtime.newContext();
+			IvImpl implFetched = SelectById.query(IvImpl.class, 1).selectOne(cleanContext);
+			IvOther otherFetched = SelectById.query(IvOther.class, 2).selectOne(cleanContext);
+			assertEquals("Impl 1", implFetched.getName());
+			assertEquals("attr1", implFetched.getAttr1());
+			assertEquals(implFetched.getOther3(), otherFetched);
+		}
+	}
+
+	@Test
+	public void testDeleteFlattenedNoValues() throws SQLException {
+		ivAbstractTable.insert(1, null, "S");
+
+		IvConcrete concrete = SelectById.query(IvConcrete.class, 1).selectOne(context);
+		assertNotNull(concrete);
+		assertNull(concrete.getName());
+
+		context.deleteObject(concrete);
+		context.commitChanges();
+
+		assertEquals(0, ivAbstractTable.getRowCount());
+		assertEquals(0, ivConcreteTable.getRowCount());
+	}
+
+	@Test
+	public void testDeleteFlattenedNullValues() throws SQLException {
+		ivAbstractTable.insert(1, null, "S");
+		ivConcreteTable.insert(1, null, null);
+
+		IvConcrete concrete = SelectById.query(IvConcrete.class, 1).selectOne(context);
+		assertNotNull(concrete);
+		assertNull(concrete.getName());
+
+		context.deleteObject(concrete);
+		context.commitChanges();
+
+		assertEquals(0, ivAbstractTable.getRowCount());
+		assertEquals(0, ivConcreteTable.getRowCount());
+	}
+
+	@Test
+	public void testDeleteFlattenedNullifyValues() throws SQLException {
+		ivAbstractTable.insert(1, null, "S");
+		ivConcreteTable.insert(1, "test", null);
+
+		IvConcrete concrete = SelectById.query(IvConcrete.class, 1).selectOne(context);
+		assertNotNull(concrete);
+		assertEquals("test", concrete.getName());
+
+		concrete.setName(null);
+		context.commitChanges();
+        assertNull(concrete.getName());
+
+		assertEquals(1, ivAbstractTable.getRowCount());
+		assertEquals(1, ivConcreteTable.getRowCount());
+
+		context.deleteObject(concrete);
+		context.commitChanges();
+
+		assertEquals(0, ivAbstractTable.getRowCount());
+		assertEquals(0, ivConcreteTable.getRowCount());
+	}
+
+	@Test
+	public void testNullifyFlattenedRelationshipConcreteToAbstract() throws SQLException {
+		ivAbstractTable.insert(1, null, "S");
+		ivConcreteTable.insert(1, "One", null);
+		ivAbstractTable.insert(2, null, "S");
+		ivConcreteTable.insert(2, "Two", 1);
+
+		IvConcrete concrete = SelectById.query(IvConcrete.class, 2).selectOne(context);
+		concrete.setRelatedAbstract(null);
+
+		context.commitChanges();
+		assertNull(concrete.getRelatedAbstract());
+
+		{
+			ObjectContext cleanContext = runtime.newContext();
+			IvConcrete concreteFetched = SelectById.query(IvConcrete.class, 2).selectOne(cleanContext);
+			assertEquals("Two", concreteFetched.getName());
+			assertNull(concreteFetched.getRelatedAbstract());
+		}
+	}
+
 	@Test//(expected = ValidationException.class) // other2 is not mandatory for now
 	public void testInsertWithAttributeAndRelationship() {
 		IvOther other = context.newObject(IvOther.class);
@@ -682,6 +863,36 @@ public class VerticalInheritanceIT extends ServerCase {
 		assertEquals(2, ObjectSelect.query(IvImpl.class).selectCount(context));
 	}
 
+	/**
+	 * @link https://issues.apache.org/jira/browse/CAY-2840
+	 */
+	@Test
+	public void testJointPrefetchBelongsTo() throws SQLException {
+		TableHelper ivOtherTable = new TableHelper(dbHelper, "IV_OTHER");
+		ivOtherTable.setColumns("ID", "NAME", "BASE_ID").setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.INTEGER);
+
+		TableHelper ivBaseTable = new TableHelper(dbHelper, "IV_BASE");
+		ivBaseTable.setColumns("ID", "NAME", "TYPE").setColumnTypes(Types.INTEGER, Types.VARCHAR, Types.CHAR);
+
+		TableHelper ivImplTable = new TableHelper(dbHelper, "IV_IMPL");
+		ivImplTable.setColumns("ID", "ATTR1").setColumnTypes(Types.INTEGER, Types.VARCHAR);
+
+		ivBaseTable.insert(1, "Impl 1", "I");
+		ivImplTable.insert(1, "attr1");
+		ivOtherTable.insert(1, "other1", 1);
+
+		IvOther other = ObjectSelect.query(IvOther.class).prefetch(IvOther.BASE.joint()).selectOne(context);
+		assertNotNull(other);
+		assertNotNull(other.getBase());
+		assertTrue(IvImpl.class.isAssignableFrom(other.getBase().getClass()));
+
+		IvImpl impl = (IvImpl)other.getBase();
+		// Ensure that base attributes were prefetched correctly
+		assertEquals("Impl 1", impl.getName());
+		// Ensure that subclass attributes were prefetched correctly
+		assertEquals("attr1", impl.getAttr1());
+	}
+
 	/**
 	 * @link https://issues.apache.org/jira/browse/CAY-2282
 	 */
