@@ -19,13 +19,15 @@
 
 package org.apache.cayenne.exp;
 
+import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.ObjectContext;
 import org.apache.cayenne.access.DataContext;
 import org.apache.cayenne.configuration.server.ServerRuntime;
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.testdo.testmap.Artist;
 import org.apache.cayenne.testdo.testmap.Painting;
+import org.apache.cayenne.unit.UnitDbAdapter;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
 import org.apache.cayenne.unit.di.server.ServerCase;
 import org.apache.cayenne.unit.di.server.UseServerRuntime;
@@ -50,6 +52,9 @@ public class ExpressionIT extends ServerCase {
 	@Inject
 	private ServerRuntime runtime;
 
+	@Inject
+    private UnitDbAdapter adapter;
+
     @Test
 	public void testMatch() {
 
@@ -65,39 +70,27 @@ public class ExpressionIT extends ServerCase {
 
 		context.commitChanges();
 
-		SelectQuery<Painting> query = new SelectQuery<Painting>(Painting.class);
-		Expression e = Painting.TO_ARTIST.eq(a1);
-		query.setQualifier(e);
-
 		assertNotSame(context2, context);
 
-		List<Painting> objects = context2.select(query);
+		List<Painting> objects = ObjectSelect.query(Painting.class, Painting.TO_ARTIST.eq(a1)).select(context2);
 		assertEquals(1, objects.size());
 
 		// 2 same objects in different contexts
-		assertTrue(e.match(objects.get(0)));
+		assertTrue(Painting.TO_ARTIST.eq(a1).match(objects.get(0)));
 
 		// we change one object - so the objects are different now
 		// (PersistenceState different)
 		a1.setArtistName("newName");
 
-		SelectQuery<Painting> q2 = new SelectQuery<Painting>(Painting.class);
-		Expression ex2 = Painting.TO_ARTIST.eq(a1);
-		q2.setQualifier(ex2);
-
-		assertTrue(ex2.match(objects.get(0)));
+		assertTrue(Painting.TO_ARTIST.eq(a1).match(objects.get(0)));
 
 		Artist a2 = context.newObject(Artist.class);
 		a2.setArtistName("Equals");
 
 		context.commitChanges();
 
-		SelectQuery<Painting> q = new SelectQuery<Painting>(Painting.class);
-		Expression ex = Painting.TO_ARTIST.eq(a2);
-		q.setQualifier(ex);
-
 		// 2 different objects in different contexts
-		assertFalse(ex.match(objects.get(0)));
+		assertFalse(Painting.TO_ARTIST.eq(a2).match(objects.get(0)));
 	}
 
     @Test
@@ -125,4 +118,43 @@ public class ExpressionIT extends ServerCase {
 		assertNull(e4.first(paintingList));
 	}
 
+	@Test
+	public void testLessThanNull() {
+		Artist a1 = context.newObject(Artist.class);
+		a1.setArtistName("Picasso");
+		context.commitChanges();
+
+        List<Artist> artists;
+		try {
+            artists = ObjectSelect.query(Artist.class, Artist.ARTIST_NAME.lt((String) null)).select(context);
+        } catch (CayenneRuntimeException ex) {
+		    if(adapter.supportsNullComparison()) {
+		        throw ex;
+            } else {
+		        return;
+            }
+        }
+
+        assertTrue("Less than 'NULL' never matches anything", artists.isEmpty());
+	}
+
+	@Test
+	public void testInNull() {
+		Artist a1 = context.newObject(Artist.class);
+		a1.setArtistName("Picasso");
+		context.commitChanges();
+
+        List<Artist> artists;
+        try {
+            artists = ObjectSelect.query(Artist.class, Artist.ARTIST_NAME.in("Picasso", (String) null)).select(context);
+        } catch (CayenneRuntimeException ex) {
+            if(adapter.supportsNullComparison()) {
+                throw ex;
+            } else {
+                return;
+            }
+        }
+		assertEquals(1, artists.size());
+	}
+
 }
