@@ -45,13 +45,13 @@ public class ExpressionTest {
 	@Test
 	public void testToEJBQL_numericType_long() {
 		Expression e = ExpressionFactory.matchExp("consignment.parts", 1418342400L);
-		assertEquals("x.consignment.parts = 1418342400", e.toEJBQL("x"));
+		assertEquals("x.consignment.parts = 1418342400L", e.toEJBQL("x"));
 	}
 
 	@Test
 	public void testToEJBQL_numericType_float() {
 		Expression e = ExpressionFactory.greaterOrEqualExp("consignment.parts", Float.valueOf("3.145"));
-		assertEquals("x.consignment.parts >= 3.145", e.toEJBQL("x"));
+		assertEquals("x.consignment.parts >= 3.145f", e.toEJBQL("x"));
 	}
 
 	@Test
@@ -464,4 +464,19 @@ public class ExpressionTest {
 		exp.appendAsString(buffer);
 		assertEquals("db:year.month.day.avg", buffer.toString());
 	}
+
+    @Test
+    public void testNumericsToString() {
+        Expression exp1 = ExpressionFactory.exp("a = 123");
+        assertEquals("a = 123", exp1.toString());
+
+        Expression exp2 = ExpressionFactory.exp("a = 123L");
+        assertEquals("a = 123L", exp2.toString());
+
+        Expression exp3 = ExpressionFactory.exp("a = 123.0");
+        assertEquals("a = 123.0", exp3.toString());
+
+        Expression exp4 = ExpressionFactory.exp("a = 123.0f");
+        assertEquals("a = 123.0f", exp4.toString());
+    }
 }
