@@ -19,9 +19,14 @@
 
 package org.apache.cayenne.exp;
 
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 import org.apache.cayenne.ObjectContext;
 import org.apache.cayenne.di.Inject;
-import org.apache.cayenne.query.SelectQuery;
+import org.apache.cayenne.query.ObjectSelect;
+import org.apache.cayenne.query.PrefetchTreeNode;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
 import org.apache.cayenne.testdo.testmap.Artist;
@@ -32,10 +37,6 @@ import org.apache.cayenne.unit.di.server.UseServerRuntime;
 import org.junit.Before;
 import org.junit.Test;
 
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
 import static org.junit.Assert.assertEquals;
 
 @UseServerRuntime(CayenneProjects.TESTMAP_PROJECT)
@@ -80,12 +81,12 @@ public class ParsedExpQualifierCompatIT extends ServerCase {
         return execute(root, qualifier, null);
     }
 
-    private <T> List<T> execute(Class<T> root, Expression qualifier, String prefecth) {
-        SelectQuery query = new SelectQuery(root, qualifier);
-        if (prefecth != null) {
-            query.addPrefetch(prefecth);
+    private <T> List<T> execute(Class<T> root, Expression qualifier, String prefetch) {
+        ObjectSelect<T> query = ObjectSelect.query(root, qualifier);
+        if (prefetch != null) {
+            query.prefetch(prefetch, PrefetchTreeNode.DISJOINT_PREFETCH_SEMANTICS);
         }
-        return context.performQuery(query);
+        return query.select(context);
     }
 
     @Test
