@@ -18,10 +18,14 @@
  ****************************************************************/
 package org.apache.cayenne.exp;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 import java.util.Arrays;
 import java.util.List;
 
-import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.exp.parser.ASTAbs;
 import org.apache.cayenne.exp.parser.ASTAvg;
 import org.apache.cayenne.exp.parser.ASTConcat;
@@ -41,14 +45,11 @@ import org.apache.cayenne.exp.parser.ASTSum;
 import org.apache.cayenne.exp.parser.ASTTrim;
 import org.apache.cayenne.exp.parser.ASTUpper;
 import org.apache.cayenne.exp.parser.PatternMatchNode;
+import org.apache.cayenne.exp.property.NumericProperty;
 import org.apache.cayenne.reflect.TstJavaBean;
 import org.junit.Test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-
+@Deprecated
 public class PropertyTest {
 
     @Test
@@ -345,15 +346,15 @@ public class PropertyTest {
     @Test
     public void testCount() {
         Property<String> p = Property.create("test", String.class);
-        Property<Long> newProp = p.count();
+        NumericProperty<Long> newProp = p.count();
         assertTrue(newProp.getExpression() instanceof ASTCount);
         assertEquals(p.getExpression(), newProp.getExpression().getOperand(0));
     }
-
+    
     @Test
     public void testCountDistinct() {
         Property<String> p = Property.create("test", String.class);
-        Property<Long> newProp = p.countDistinct();
+        NumericProperty<Long> newProp = p.countDistinct();
         assertTrue(newProp.getExpression() instanceof ASTCount);
         assertTrue(newProp.getExpression().getOperand(0) instanceof ASTDistinct);
         assertEquals(p.getExpression(), ((ASTDistinct)newProp.getExpression().getOperand(0)).getOperand(0));
@@ -490,13 +491,4 @@ public class PropertyTest {
         assertEquals(3, newProp.getExpression().getOperand(2)); // getOperand unwrapping ASTScalar
         assertEquals(p2.getExpression(), newProp.getExpression().getOperand(3));
     }
-
-    @Test(expected = CayenneRuntimeException.class)
-    public void testMixDbAndObjPath() {
-        Property<Integer> dbPathProperty = Property
-                .create(ExpressionFactory.dbPathExp("db_path"), Integer.class);
-        Property<String> objPathProperty = Property
-                .create(ExpressionFactory.pathExp("obj_path"), String.class);
-        objPathProperty.dot(dbPathProperty);
-    }
 }
