@@ -25,7 +25,6 @@ import org.apache.cayenne.ObjectContext;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
-import org.apache.cayenne.exp.Property;
 import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.testdo.testmap.Artist;
 import org.apache.cayenne.unit.di.server.CayenneProjects;
@@ -34,6 +33,7 @@ import org.apache.cayenne.unit.di.server.UseServerRuntime;
 import org.junit.Test;
 
 import static junit.framework.TestCase.assertEquals;
+import static junit.framework.TestCase.assertNull;
 
 /**
  * @since 4.0
@@ -55,58 +55,40 @@ public class ASTFunctionCallStringIT extends ServerCase {
     @Test
     public void testASTTrimInWhere() throws Exception {
         Artist a1 = createArtist("  name  ");
-
-        ASTTrim exp = new ASTTrim(Artist.ARTIST_NAME.path());
-        Property<String> trimmedName = Property.create("trimmedName", exp, String.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(trimmedName.eq("name")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.trim().eq("name")).selectOne(context);
         assertEquals(a1, a2);
     }
 
     @Test
     public void testASTUpperInWhere() throws Exception {
         Artist a1 = createArtist("name");
-
-        ASTUpper exp = new ASTUpper(Artist.ARTIST_NAME.path());
-        Property<String> upperName = Property.create("upperName", exp, String.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(upperName.eq("NAME")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.upper().eq("NAME")).selectOne(context);
         assertEquals(a1, a2);
     }
 
     @Test
     public void testASTLowerInWhere() throws Exception {
         Artist a1 = createArtist("NAME");
-
-        ASTLower exp = new ASTLower(Artist.ARTIST_NAME.path());
-        Property<String> lowerName = Property.create("lowerName", exp, String.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(lowerName.eq("name")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.lower().eq("name")).selectOne(context);
         assertEquals(a1, a2);
     }
 
     @Test
     public void testASTSubstringInWhere() throws Exception {
         Artist a1 = createArtist("1234567890xyz");
-
-        ASTSubstring exp = new ASTSubstring(Artist.ARTIST_NAME.path(), new ASTScalar((Integer)2), new ASTScalar((Integer)8));
-        Property<String> substrName = Property.create("substrName", exp, String.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(substrName.eq("23456789")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.substring(2, 8).eq("23456789")).selectOne(context);
         assertEquals(a1, a2);
     }
 
     @Test
     public void testASTConcat() throws Exception {
         Artist a1 = createArtist("Pablo");
-
-        ASTScalar scalar1 = new ASTScalar(" ");
-        ASTScalar scalar2 = new ASTScalar("Picasso");
-
-        ASTConcat exp = new ASTConcat(Artist.ARTIST_NAME.path(), scalar1, scalar2);
-        Property<String> concatName = Property.create("concatName", exp, String.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(concatName.eq("Pablo Picasso")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.trim().concat(" ", "Picasso").eq("Pablo Picasso")).selectOne(context);
         assertEquals(a1, a2);
     }
 
@@ -114,43 +96,27 @@ public class ASTFunctionCallStringIT extends ServerCase {
     public void testASTLength() throws Exception {
         Artist a1 = createArtist("123456");
 
-        ASTLength exp = new ASTLength(Artist.ARTIST_NAME.path());
-        Property<Integer> nameLength = Property.create("nameLength", exp, Integer.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(nameLength.gt(5)).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class).where(Artist.ARTIST_NAME.length().gt(5)).selectOne(context);
         assertEquals(a1, a2);
 
-        Artist a3 = ObjectSelect.query(Artist.class).where(nameLength.lt(5)).selectOne(context);
-        assertEquals(null, a3);
+        Artist a3 = ObjectSelect.query(Artist.class).where(Artist.ARTIST_NAME.length().lt(5)).selectOne(context);
+        assertNull(a3);
     }
 
     @Test
     public void testASTLocate() throws Exception {
         Artist a1 = createArtist("1267834567890abc");
-
-        ASTScalar substr = new ASTScalar("678");
-//        ASTScalar offset = new ASTScalar((Integer)5); // not all DBs support offset parameter, so skip it
-        ASTLocate exp = new ASTLocate(substr, Artist.ARTIST_NAME.path());
-        Property<Integer> nameLoc = Property.create("nameLoc", exp, Integer.class);
-
-        Artist a2 = ObjectSelect.query(Artist.class).where(nameLoc.eq(3)).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.locate("678").eq(3)).selectOne(context);
         assertEquals(a1, a2);
     }
 
     @Test
     public void testCombinedFunction() throws Exception {
         Artist a1 = createArtist("absdefghij  klmnopq"); // substring with length 10 from 3 is "sdefghij  "
-
-        ASTSubstring substring = new ASTSubstring(
-                Artist.ARTIST_NAME.path(),
-                new ASTScalar((Integer)3),
-                new ASTScalar((Integer)10));
-        ASTTrim trim = new ASTTrim(substring);
-        ASTUpper upper = new ASTUpper(trim);
-        ASTConcat concat = new ASTConcat(upper, new ASTScalar(" "), new ASTScalar("test"));
-
-        Property<String> name = Property.create("substrName", concat, String.class);
-        Artist a2 = ObjectSelect.query(Artist.class).where(name.eq("SDEFGHIJ test")).selectOne(context);
+        Artist a2 = ObjectSelect.query(Artist.class)
+                .where(Artist.ARTIST_NAME.substring(3, 10).trim().upper().concat(" ", "test").eq("SDEFGHIJ test"))
+                .selectOne(context);
         assertEquals(a1, a2);
     }
 
