@@ -270,8 +270,6 @@ public class DbEntityIT extends ServerCase {
         Expression e1 = ExpressionFactory.exp("db:toArtist.ARTIST_NAME = 'aa'");
         Expression translated = paintingE.translateToRelatedEntity(e1, "toArtist");
 
-        assertEquals("failure: " + translated,
-                ExpressionFactory.exp("db:paintingArray.toArtist.ARTIST_NAME = 'aa'"),
-                translated);
+        assertEquals("failure: " + translated, ExpressionFactory.exp("db:paintingArray.toArtist.ARTIST_NAME = 'aa'"), translated);
     }
 }
