@@ -59,6 +59,7 @@ import org.junit.Ignore;
 import org.junit.Test;
 
 import static org.hamcrest.CoreMatchers.instanceOf;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.*;
 
 /**
@@ -1195,6 +1196,24 @@ public class ColumnSelectIT extends ServerCase {
 
     }
 
+    @Test
+    public void testSharedCache() {
+        ColumnSelect<Object[]> query = ObjectSelect.query(Artist.class)
+                .columns(Artist.ARTIST_NAME, Artist.DATE_OF_BIRTH, PropertyFactory.createSelf(Artist.class))
+                .orderBy(Artist.ARTIST_ID_PK_PROPERTY.asc())
+                .cacheStrategy(QueryCacheStrategy.SHARED_CACHE);
+
+        List<Object[]> result = query.select(context);
+        assertEquals(20, result.size());
+        assertThat("Should be an instance of Artist",
+                instanceOf(Artist.class).matches(result.get(0)[2]));
+
+        List<Object[]> result2 = query.select(context);
+        assertEquals(20, result2.size());
+        assertThat("Should be an instance of Artist",
+                instanceOf(Artist.class).matches(result.get(0)[2]));
+    }
+
     static class TestPojo {
         String name;
         Date date;
