@@ -18,13 +18,6 @@
  ****************************************************************/
 package org.apache.cayenne.query;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
@@ -35,6 +28,8 @@ import org.apache.cayenne.exp.ExpressionFactory;
 import org.apache.cayenne.testdo.testmap.Artist;
 import org.junit.Test;
 
+import static org.junit.Assert.*;
+
 public class ObjectSelectTest {
 
 	@Test
@@ -372,11 +367,11 @@ public class ObjectSelectTest {
 	public void testCacheGroups_Collection() {
 		ObjectSelect<DataRow> q = ObjectSelect.dataRowQuery(Artist.class);
 
-		assertNull(q.getCacheStrategy());
+		assertEquals(QueryCacheStrategy.NO_CACHE, q.getCacheStrategy());
 		assertNull(q.getCacheGroup());
 
 		q.cacheGroup("a");
-		assertNull(q.getCacheStrategy());
+		assertEquals(QueryCacheStrategy.NO_CACHE, q.getCacheStrategy());
 		assertEquals("a", q.getCacheGroup());
 	}
 
@@ -384,7 +379,7 @@ public class ObjectSelectTest {
 	public void testCacheStrategy() {
 		ObjectSelect<DataRow> q = ObjectSelect.dataRowQuery(Artist.class);
 
-		assertNull(q.getCacheStrategy());
+		assertEquals(QueryCacheStrategy.NO_CACHE, q.getCacheStrategy());
 		assertNull(q.getCacheGroup());
 
 		q.cacheStrategy(QueryCacheStrategy.LOCAL_CACHE, "b");
@@ -400,7 +395,7 @@ public class ObjectSelectTest {
 	public void testLocalCache() {
 		ObjectSelect<DataRow> q = ObjectSelect.dataRowQuery(Artist.class);
 
-		assertNull(q.getCacheStrategy());
+		assertEquals(QueryCacheStrategy.NO_CACHE, q.getCacheStrategy());
 		assertNull(q.getCacheGroup());
 
 		q.localCache("a");
@@ -416,7 +411,7 @@ public class ObjectSelectTest {
 	public void testSharedCache() {
 		ObjectSelect<DataRow> q = ObjectSelect.dataRowQuery(Artist.class);
 
-		assertNull(q.getCacheStrategy());
+		assertEquals(QueryCacheStrategy.NO_CACHE, q.getCacheStrategy());
 		assertNull(q.getCacheGroup());
 
 		q.sharedCache("b");
@@ -428,4 +423,16 @@ public class ObjectSelectTest {
 		assertNull(q.getCacheGroup());
 	}
 
+	@Test
+	public void testQueryTimeout() {
+		ObjectSelect<Artist> query = ObjectSelect.query(Artist.class);
+		assertEquals(-1, query.getQueryTimeout());
+
+		query.queryTimeout(10);
+		assertEquals(10, query.getQueryTimeout());
+
+		query.queryTimeout(1).queryTimeout(2);
+		assertEquals(2, query.getQueryTimeout());
+	}
+
 }
