@@ -18,6 +18,14 @@
  ****************************************************************/
 package org.apache.cayenne.query;
 
+import java.sql.Date;
+import java.sql.SQLException;
+import java.sql.Types;
+import java.time.LocalDateTime;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.DataRow;
 import org.apache.cayenne.ResultBatchIterator;
@@ -34,14 +42,6 @@ import org.junit.Before;
 import org.junit.Ignore;
 import org.junit.Test;
 
-import java.sql.Date;
-import java.sql.SQLException;
-import java.sql.Types;
-import java.time.LocalDateTime;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.junit.Assert.*;
 
@@ -133,6 +133,18 @@ public class SQLSelectIT extends ServerCase {
 		assertThat(result.get(0).get("DATE_OF_BIRTH"), instanceOf(LocalDateTime.class));
 	}
 
+	@Test
+	public void test_DataRowWithTypesMapped() throws Exception {
+		createArtistDataSet();
+
+		List<Object> result = SQLSelect.dataRowQuery("SELECT * FROM ARTIST_CT", Integer.class, String.class, LocalDateTime.class)
+				.columnNameCaps(CapsStrategy.UPPER)
+				.map(dataRow -> dataRow.get("ARTIST_ID"))
+				.select(context);
+		assertEquals(2, result.size());
+		assertTrue(result.get(0) instanceof Integer);
+	}
+
 	@Test
 	public void test_DataRowWithDirectives() throws Exception {
 		createArtistDataSet();
@@ -156,7 +168,7 @@ public class SQLSelectIT extends ServerCase {
 	public void testObjectArrayWithDefaultTypesReturnAndDirectives() throws Exception {
 		createArtistDataSet();
 
-		List<Object[]> result = SQLSelect.scalarQuery("SELECT #result('ARTIST_ID' 'java.lang.Long'), #result('ARTIST_NAME' 'java.lang.String') FROM ARTIST_CT")
+		List<Object[]> result = SQLSelect.columnQuery("SELECT #result('ARTIST_ID' 'java.lang.Long'), #result('ARTIST_NAME' 'java.lang.String') FROM ARTIST_CT")
 				.select(context);
 
 		assertEquals(2, result.size());
@@ -166,11 +178,25 @@ public class SQLSelectIT extends ServerCase {
 		assertTrue(result.get(0)[1] instanceof String);
 	}
 
+	@Test
+	public void testObjectArrayWithDefaultTypesReturnAndDirectivesMappedToPojo() throws Exception {
+		createArtistDataSet();
+
+		List<ArtistDataWrapper> result = SQLSelect
+				.columnQuery("SELECT #result('ARTIST_ID' 'java.lang.Long'), #result('ARTIST_NAME' 'java.lang.String') FROM ARTIST_CT")
+				.map(ArtistDataWrapper::new)
+				.select(context);
+
+		assertEquals(2, result.size());
+		assertTrue(result.get(0).id > 0);
+		assertNotNull(result.get(0).name);
+	}
+
 	@Test(expected = CayenneRuntimeException.class)
 	public void testObjectArrayReturnAndDirectives() throws Exception {
 		createArtistDataSet();
 
-		SQLSelect.scalarQuery("SELECT #result('ARTIST_ID' 'java.lang.Long'), #result('ARTIST_NAME' 'java.lang.String') FROM ARTIST_CT",
+		SQLSelect.columnQuery("SELECT #result('ARTIST_ID' 'java.lang.Long'), #result('ARTIST_NAME' 'java.lang.String') FROM ARTIST_CT",
 				Integer.class, String.class).select(context);
 	}
 
@@ -178,7 +204,7 @@ public class SQLSelectIT extends ServerCase {
 	public void testObjectArrayWithOneObjectDefaultTypesReturnAndDirectives() throws Exception {
 		createArtistDataSet();
 
-		List<Object[]> result = SQLSelect.scalarQuery("SELECT #result('ARTIST_ID' 'java.lang.Long') FROM ARTIST_CT")
+		List<Object[]> result = SQLSelect.columnQuery("SELECT #result('ARTIST_ID' 'java.lang.Long') FROM ARTIST_CT")
 				.select(context);
 
 		assertEquals(2, result.size());
@@ -191,7 +217,7 @@ public class SQLSelectIT extends ServerCase {
 	public void test_ObjectArrayQueryWithDefaultTypes() throws Exception {
 		createPaintingsDataSet();
 
-		List<Object[]> result = SQLSelect.scalarQuery("SELECT PAINTING_ID, PAINTING_TITLE, ESTIMATED_PRICE FROM PAINTING")
+		List<Object[]> result = SQLSelect.columnQuery("SELECT PAINTING_ID, PAINTING_TITLE, ESTIMATED_PRICE FROM PAINTING")
 				.select(context);
 
 		assertEquals(20, result.size());
@@ -202,7 +228,7 @@ public class SQLSelectIT extends ServerCase {
 	public void test_ObjectQueryWithDefaultType() throws Exception {
 		createPaintingsDataSet();
 
-		List<Object[]> result = SQLSelect.scalarQuery("SELECT PAINTING_ID FROM PAINTING")
+		List<Object[]> result = SQLSelect.columnQuery("SELECT PAINTING_ID FROM PAINTING")
 				.select(context);
 		assertEquals(20, result.size());
 		assertTrue(result.get(0) instanceof Object[]);
@@ -213,7 +239,7 @@ public class SQLSelectIT extends ServerCase {
 	public void test_ObjectArrayQueryException() throws Exception {
 		createPaintingsDataSet();
 
-		SQLSelect<Object[]> query = SQLSelect.scalarQuery("SELECT PAINTING_ID, PAINTING_TITLE, ESTIMATED_PRICE FROM PAINTING", Integer.class, String.class);
+		SQLSelect<Object[]> query = SQLSelect.columnQuery("SELECT PAINTING_ID, PAINTING_TITLE, ESTIMATED_PRICE FROM PAINTING", Integer.class, String.class);
 		context.performQuery(query);
 	}
 
@@ -231,7 +257,7 @@ public class SQLSelectIT extends ServerCase {
 	public void testObjectArrayWithCustomType() throws SQLException {
 		createArtistDataSet();
 
-		List<Object[]> results = SQLSelect.scalarQuery("SELECT * FROM ARTIST_CT",
+		List<Object[]> results = SQLSelect.columnQuery("SELECT * FROM ARTIST_CT",
 				Integer.class, String.class, LocalDateTime.class).select(context);
 
 		assertEquals(2, results.size());
@@ -240,13 +266,28 @@ public class SQLSelectIT extends ServerCase {
 		assertTrue(results.get(0)[2] instanceof LocalDateTime);
 	}
 
+	@Test
+	public void testObjectArrayWithCustomTypeMappedToPojo() throws SQLException {
+		createArtistDataSet();
+
+		List<ArtistDataWrapper> result = SQLSelect.scalarQuery("SELECT * FROM ARTIST_CT",
+				Integer.class, String.class, LocalDateTime.class)
+				.map(ArtistDataWrapper::new)
+				.select(context);
+
+		assertEquals(2, result.size());
+		assertTrue(result.get(0).id > 0);
+		assertNotNull(result.get(0).name);
+		assertNotNull(result.get(0).date);
+	}
+
 	@Test
 	public void test_DataRows_ClassRoot_Parameters() throws Exception {
 		createPaintingsDataSet();
 
 		SQLSelect<Painting> q1 = SQLSelect.query(Painting.class,
 				"SELECT * FROM PAINTING WHERE PAINTING_TITLE = #bind($a)");
-		q1.params("a", "painting3").columnNameCaps(CapsStrategy.UPPER);
+		q1.param("a", "painting3").columnNameCaps(CapsStrategy.UPPER);
 
 		assertFalse(q1.isFetchingDataRows());
 		Painting a = context.selectOne(q1);
@@ -260,14 +301,14 @@ public class SQLSelectIT extends ServerCase {
 		SQLSelect<Painting> q1 = SQLSelect.query(Painting.class,
 				"SELECT * FROM PAINTING WHERE PAINTING_TITLE = #bind($a) OR PAINTING_TITLE = #bind($b)")
 				.columnNameCaps(CapsStrategy.UPPER);
-		q1.params("a", "painting3").params("b", "painting4");
+		q1.param("a", "painting3").param("b", "painting4");
 
 		List<Painting> result = context.select(q1);
 		assertEquals(2, result.size());
 	}
 
 	@Test
-	public void test_DataRows_ColumnNameCaps() throws Exception {
+	public void test_DataRows_ColumnNameCaps() {
 		SQLSelect<DataRow> q1 = SQLSelect.dataRowQuery("SELECT * FROM PAINTING WHERE PAINTING_TITLE = 'painting2'");
 		q1.upperColumnNames();
 
@@ -304,7 +345,7 @@ public class SQLSelectIT extends ServerCase {
 		createPaintingsDataSet();
 
 		SQLSelect<Painting> q1 = SQLSelect.query(Painting.class, "SELECT * FROM PAINTING")
-				.append(" WHERE PAINTING_TITLE = #bind($a)").params("a", "painting3")
+				.append(" WHERE PAINTING_TITLE = #bind($a)").param("a", "painting3")
 				.columnNameCaps(CapsStrategy.UPPER);
 
 		List<Painting> result = context.select(q1);
@@ -317,7 +358,9 @@ public class SQLSelectIT extends ServerCase {
 
 		List<Painting> result = SQLSelect
 				.query(Painting.class, "SELECT * FROM PAINTING WHERE PAINTING_TITLE = #bind($a)")
-				.params("a", "painting3").columnNameCaps(CapsStrategy.UPPER).select(context);
+				.param("a", "painting3")
+				.columnNameCaps(CapsStrategy.UPPER)
+				.select(context);
 
 		assertEquals(1, result.size());
 	}
@@ -327,7 +370,7 @@ public class SQLSelectIT extends ServerCase {
 		createPaintingsDataSet();
 
 		Painting a = SQLSelect.query(Painting.class, "SELECT * FROM PAINTING WHERE PAINTING_TITLE = #bind($a)")
-				.params("a", "painting3").columnNameCaps(CapsStrategy.UPPER).selectOne(context);
+				.param("a", "painting3").columnNameCaps(CapsStrategy.UPPER).selectOne(context);
 
 		assertEquals("painting3", a.getPaintingTitle());
 	}
@@ -406,8 +449,9 @@ public class SQLSelectIT extends ServerCase {
 		createPaintingsDataSet();
 
 		long id = SQLSelect
-				.scalarQuery(Integer.class, "SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a)")
-				.params("a", "painting3").selectOne(context);
+				.scalarQuery( "SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a)",
+						Integer.class)
+				.param("a", "painting3").selectOne(context);
 
 		assertEquals(3L, id);
 	}
@@ -416,8 +460,8 @@ public class SQLSelectIT extends ServerCase {
 	public void test_SelectLongArray() throws Exception {
 		createPaintingsDataSet();
 
-		List<Integer> ids = SQLSelect.scalarQuery(Integer.class,
-				"SELECT PAINTING_ID FROM PAINTING ORDER BY PAINTING_ID").select(context);
+		List<Integer> ids = SQLSelect.scalarQuery("SELECT PAINTING_ID FROM PAINTING ORDER BY PAINTING_ID",
+				Integer.class).select(context);
 
 		assertEquals(20, ids.size());
 		assertEquals(2L, ids.get(1).intValue());
@@ -437,7 +481,8 @@ public class SQLSelectIT extends ServerCase {
 		createPaintingsDataSet();
 
 		Integer id = SQLSelect
-				.scalarQuery(Integer.class, "SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a)")
+				.scalarQuery( "SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a)",
+						Integer.class)
 				.paramsArray("painting3").selectOne(context);
 
 		assertEquals(3L, id.intValue());
@@ -448,8 +493,9 @@ public class SQLSelectIT extends ServerCase {
 		createPaintingsDataSet();
 
 		List<Integer> ids = SQLSelect
-				.scalarQuery(Integer.class,
-						"SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a) OR PAINTING_TITLE = #bind($b) ORDER BY PAINTING_ID")
+				.scalarQuery("SELECT PAINTING_ID FROM PAINTING WHERE PAINTING_TITLE = #bind($a) " +
+						"OR PAINTING_TITLE = #bind($b) ORDER BY PAINTING_ID",
+						Integer.class)
 				.paramsArray("painting3", "painting2").select(context);
 
 		assertEquals(2L, ids.get(0).intValue());
@@ -465,10 +511,10 @@ public class SQLSelectIT extends ServerCase {
 
 		List<Integer> ids = SQLSelect
 				.scalarQuery(
-						Integer.class,
 						"SELECT PAINTING_ID FROM PAINTING #chain('OR' 'WHERE') "
 								+ "#chunk($a) ESTIMATED_PRICE #bindEqual($a) #end "
-								+ "#chunk($b) PAINTING_TITLE #bindEqual($b) #end #end ORDER BY PAINTING_ID")
+								+ "#chunk($b) PAINTING_TITLE #bindEqual($b) #end #end ORDER BY PAINTING_ID",
+						Integer.class)
 				.paramsArray(null, "painting1").select(context);
 
 		assertEquals(1, ids.size());
@@ -488,25 +534,38 @@ public class SQLSelectIT extends ServerCase {
 
 		List<Integer> ids = SQLSelect
 				.scalarQuery(
-						Integer.class,
 						"SELECT PAINTING_ID FROM PAINTING #chain('OR' 'WHERE') "
 								+ "#chunk($a) ESTIMATED_PRICE #bindEqual($a) #end "
-								+ "#chunk($b) PAINTING_TITLE #bindEqual($b) #end #end ORDER BY PAINTING_ID")
+								+ "#chunk($b) PAINTING_TITLE #bindEqual($b) #end #end ORDER BY PAINTING_ID",
+						Integer.class)
 				.params(params).select(context);
 
 		assertEquals(1, ids.size());
 		assertEquals(1L, ids.get(0).longValue());
 	}
 
-    @Test
-    public void testByteArray() throws Exception {
-        byte[] data = {1, 2, 3};
-        tPainting.insert(1, "test", 0);
-        tPaintingInfo.insert(1, data);
+	@Test
+	public void testByteArray() throws Exception {
+		byte[] data = {1, 2, 3};
+		tPainting.insert(1, "test", 0);
+		tPaintingInfo.insert(1, data);
 
-        byte[] bytes = SQLSelect
-                .scalarQuery("SELECT IMAGE_BLOB FROM PAINTING_INFO", byte[].class)
-                .selectOne(context);
-        assertArrayEquals(data, bytes);
-    }
+		byte[] bytes = SQLSelect
+				.scalarQuery("SELECT IMAGE_BLOB FROM PAINTING_INFO", byte[].class)
+				.selectOne(context);
+		assertArrayEquals(data, bytes);
+	}
+
+	static class ArtistDataWrapper {
+		long id;
+		String name;
+		LocalDateTime date;
+		ArtistDataWrapper(Object[] data) {
+			id = ((Number)data[0]).longValue();
+			name = (String)data[1];
+			if(data.length > 2) {
+				date = (LocalDateTime)data[2];
+			}
+		}
+	}
 }
