@@ -35,6 +35,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertSame;
 
 @UseServerRuntime(CayenneProjects.TESTMAP_PROJECT)
+@Deprecated
 public class SelectQueryPrefetchRouterActionIT extends ServerCase {
 
     @Inject
@@ -54,8 +55,8 @@ public class SelectQueryPrefetchRouterActionIT extends ServerCase {
 
         PrefetchSelectQuery prefetch = (PrefetchSelectQuery) router.getQueries().get(0);
 
-        assertSame(paintingEntity, prefetch.getRoot());
-        assertEquals(ExpressionFactory.exp("db:toArtist.ARTIST_NAME = 'abc'"), prefetch.getQualifier());
+        assertEquals(paintingEntity.getName(), prefetch.entityName);
+        assertEquals(ExpressionFactory.exp("db:toArtist.ARTIST_NAME = 'abc'"), prefetch.getWhere());
     }
 
     @Test
@@ -72,9 +73,9 @@ public class SelectQueryPrefetchRouterActionIT extends ServerCase {
         assertEquals(1, router.getQueryCount());
 
         PrefetchSelectQuery prefetch = (PrefetchSelectQuery) router.getQueries().get(0);
-        assertSame(paintingEntity, prefetch.getRoot());
+        assertEquals(paintingEntity.getName(), prefetch.entityName);
         assertEquals(ExpressionFactory.exp("db:toArtist.ARTIST_NAME = 'abc' or db:toArtist.ARTIST_NAME = 'xyz'"),
-                prefetch.getQualifier());
+                prefetch.getWhere());
     }
 
     @Test
@@ -91,7 +92,7 @@ public class SelectQueryPrefetchRouterActionIT extends ServerCase {
 
         PrefetchSelectQuery prefetch = (PrefetchSelectQuery) router.getQueries().get(0);
 
-        assertSame(galleryEntity, prefetch.getRoot());
-        assertEquals(ExpressionFactory.exp("db:paintingArray.toArtist.ARTIST_NAME = 'abc'"), prefetch.getQualifier());
+        assertEquals(galleryEntity.getName(), prefetch.entityName);
+        assertEquals(ExpressionFactory.exp("db:paintingArray.toArtist.ARTIST_NAME = 'abc'"), prefetch.getWhere());
     }
 }
