@@ -21,6 +21,9 @@ package org.apache.cayenne.unit;
 
 import org.apache.cayenne.dba.DbAdapter;
 
+/**
+ * Ingress doesn't support sorting by an aggregate expression (ORDER BY COUNT(some_field))
+ */
 public class IngresUnitDbAdapter extends UnitDbAdapter {
 
     public IngresUnitDbAdapter(DbAdapter adapter) {
@@ -51,4 +54,9 @@ public class IngresUnitDbAdapter extends UnitDbAdapter {
     public boolean supportsSelectBooleanExpression() {
         return false;
     }
+
+    @Override
+    public boolean isLowerCaseNames() {
+        return true;
+    }
 }
