@@ -23,6 +23,7 @@ import org.apache.cayenne.access.DataContext;
 import org.apache.cayenne.di.Inject;
 import org.apache.cayenne.exp.Expression;
 import org.apache.cayenne.exp.ExpressionFactory;
+import org.apache.cayenne.query.ObjectSelect;
 import org.apache.cayenne.query.SelectQuery;
 import org.apache.cayenne.test.jdbc.DBHelper;
 import org.apache.cayenne.test.jdbc.TableHelper;
@@ -81,6 +82,7 @@ public class CAY_115IT extends ServerCase {
     }
 
     @Test
+    @Deprecated
     public void testDistinctClobFetch() throws Exception {
         if (!accessStackAdapter.supportsLobInsertsAsStrings()) {
             return;
@@ -88,10 +90,10 @@ public class CAY_115IT extends ServerCase {
 
         createDistinctClobFetchDataSet();
 
-        SelectQuery noDistinct = new SelectQuery(ClobMaster.class);
+        SelectQuery<ClobMaster> noDistinct = SelectQuery.query(ClobMaster.class);
         noDistinct.addOrdering(ClobMaster.NAME.asc());
 
-        SelectQuery distinct = new SelectQuery(ClobMaster.class);
+        SelectQuery<ClobMaster> distinct = SelectQuery.query(ClobMaster.class);
         distinct.setDistinct(true);
         distinct.addOrdering(ClobMaster.NAME.asc());
 
@@ -111,8 +113,7 @@ public class CAY_115IT extends ServerCase {
         createDistinctClobFetchWithToManyJoin();
 
         Expression qual = ExpressionFactory.exp("details.name like 'cd%'");
-        SelectQuery query = new SelectQuery(ClobMaster.class, qual);
-        List<?> result = context.performQuery(query);
+        List<?> result = ObjectSelect.query(ClobMaster.class, qual).select(context);
 
         assertEquals(3, result.size());
     }
