@@ -301,6 +301,21 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
         test("testAddedFlattenedRelationship");
     }
 
+    @Test
+    public void testImportProcedure() throws Exception {
+        test("testImportProcedure");
+    }
+
+    @Test
+    public void testDropProcedure() throws Exception {
+        test("testDropProcedure");
+    }
+
+    @Test
+    public void testSameProcedures() throws Exception {
+        test("testSameProcedure");
+    }
+
     @Test
     public void testFilteringConfig() throws Exception {
         DbImporterMojo cdbImport = getCdbImport("config/pom-01.xml");
@@ -433,6 +448,15 @@ public class DbImporterMojoTest extends AbstractMojoTestCase {
                     }
                 }
 
+                try(ResultSet procedures = connection.getMetaData()
+                        .getProcedures(null, null,"PROC")) {
+                    while(procedures.next()) {
+                        String schema = procedures.getString("PROCEDURE_SCHEM");
+                        String name = procedures.getString("PROCEDURE_NAME");
+                        execute(stmt, "DROP PROCEDURE " + (isBlank(schema) ? "" : schema + ".") + name);
+                    }
+                }
+
                 try (ResultSet schemas = connection.getMetaData().getSchemas()) {
                     while (schemas.next()) {
                         String schem = schemas.getString("TABLE_SCHEM");
