@@ -6,7 +6,7 @@
 --  "License"); you may not use this file except in compliance
 --  with the License.  You may obtain a copy of the License at
 --
---    http://www.apache.org/licenses/LICENSE-2.0
+--    https://www.apache.org/licenses/LICENSE-2.0
 --
 --  Unless required by applicable law or agreed to in writing,
 --  software distributed under the License is distributed on an
@@ -20,13 +20,13 @@ SET SCHEMA schema_01;
 
 CREATE TABLE schema_01.new_table (
   id INTEGER NOT NULL,
-  COL2 INTEGER,
+  COL2 INTEGER NOT NULL,
   PRIMARY KEY (id)
  );
 
 CREATE TABLE schema_01.existing_table (
   id INTEGER NOT NULL,
-  COL2 INTEGER,
+  COL2 INTEGER NOT NULL,
   PRIMARY KEY (id)
  );
 
