@@ -39,6 +39,7 @@ import org.apache.cayenne.modeler.util.CayenneController;
 import org.apache.cayenne.modeler.util.EntityTreeAttributeRelationshipFilter;
 import org.apache.cayenne.modeler.util.EntityTreeModel;
 import org.apache.cayenne.modeler.util.ModelerUtil;
+import org.apache.cayenne.project.extension.info.ObjectInfo;
 import org.apache.cayenne.swing.BindingBuilder;
 import org.apache.cayenne.util.CayenneMapEntry;
 
@@ -51,6 +52,7 @@ import javax.swing.event.TreeSelectionListener;
 import javax.swing.table.DefaultTableCellRenderer;
 import javax.swing.table.TableColumn;
 import javax.swing.tree.TreePath;
+import java.awt.CardLayout;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.event.KeyEvent;
@@ -63,6 +65,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
+import static org.apache.cayenne.modeler.dialog.objentity.ObjAttributeInfoDialogView.EMBEDDABLE_PANEL;
+import static org.apache.cayenne.modeler.dialog.objentity.ObjAttributeInfoDialogView.FLATTENED_PANEL;
+
 public class ObjAttributeInfoDialog extends CayenneController implements TreeSelectionListener {
 
 	private ObjAttributeTableModel model;
@@ -82,7 +87,7 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 
 	public ObjAttributeInfoDialog(ProjectController mediator, int row, ObjAttributeTableModel model) {
 		super(mediator);
-		this.view = new ObjAttributeInfoDialogView(mediator);
+		this.view = new ObjAttributeInfoDialogView();
 		this.mediator = mediator;
 		this.model = model;
 		this.row = row;
@@ -116,8 +121,27 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 	private void initController(ObjAttribute attr) {
 
 		for (String embeddableName : embeddableNames) {
-			((DefaultComboBoxModel) view.getTypeComboBox().getModel()).addElement(embeddableName);
+			((DefaultComboBoxModel<String>) view.getTypeComboBox().getModel()).addElement(embeddableName);
 		}
+		// need to initialize this early, to react to the later call of the view.getTypeComboBox().setSelectedItem()
+		view.getTypeComboBox().addActionListener(e -> {
+			boolean isType = false;
+			String[] typeNames = ModelerUtil.getRegisteredTypeNames();
+			for (String typeName : typeNames) {
+				if (view.getTypeComboBox().getSelectedItem() == null ||
+						typeName.equals(view.getTypeComboBox().getSelectedItem().toString())) {
+					isType = true;
+				}
+			}
+
+			if (isType || !mediator.getEmbeddableNamesInCurrentDataDomain()
+					.contains((String)view.getTypeComboBox().getSelectedItem())) {
+				((CardLayout) view.getTypeManagerPane().getLayout()).show(view.getTypeManagerPane(), FLATTENED_PANEL);
+			} else {
+				((CardLayout) view.getTypeManagerPane().getLayout()).show(view.getTypeManagerPane(), EMBEDDABLE_PANEL);
+				view.getCurrentPathLabel().setText("");
+			}
+		});
 
 		this.attribute = attr;
 
@@ -129,7 +153,7 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 
 		copyObjAttribute(attributeSaved, attribute);
 
-		relTargets = new ArrayList<DbEntity>(attribute.getEntity().getDataMap().getDbEntities());
+		relTargets = new ArrayList<>(attribute.getEntity().getDataMap().getDbEntities());
 
 		/*
 		 * Register auto-selection of the target
@@ -148,8 +172,13 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 			view.getCurrentPathLabel().setText("");
 		}
 		view.getSourceEntityLabel().setText(attribute.getEntity().getName());
-
 		view.getTypeComboBox().setSelectedItem(attribute.getType());
+		view.getUsedForLockingCheckBox().setSelected(attribute.isUsedForLocking());
+		view.getLazyCheckBox().setSelected(attribute.isLazy());
+		view.getCommentField().setText(ObjectInfo
+				.getFromMetaData(mediator.getApplication().getMetaData(),
+						attr,
+						ObjectInfo.COMMENT));
 
 		BindingBuilder builder = new BindingBuilder(getApplication().getBindingFactory(), this);
 		builder.bindToAction(view.getCancelButton(), "closeAction()");
@@ -341,14 +370,20 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 
 	public boolean setPath(boolean isChange) {
 
-		if (isChange()) {
+		if (isModified()) {
 			if(view.getTypeComboBox().getSelectedItem() != null) {
 				attributeSaved.setType(view.getTypeComboBox().getSelectedItem().toString());
 			}
 			attributeSaved.setName(view.getAttributeName().getText());
+			attributeSaved.setUsedForLocking(view.getUsedForLockingCheckBox().isSelected());
+			attributeSaved.setLazy(view.getLazyCheckBox().isSelected());
+			ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(),
+					attributeSaved,
+					ObjectInfo.COMMENT,
+					view.getCommentField().getText());
 		}
 
-		if (!(attributeSaved instanceof EmbeddedAttribute) || isRegistredType(attributeSaved.getType())) {
+		if (!(attributeSaved instanceof EmbeddedAttribute) || isRegisteredType(attributeSaved.getType())) {
 
 			StringBuilder attributePath = new StringBuilder();
 			StringBuilder pathStr = new StringBuilder();
@@ -405,23 +440,37 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 				}
 			}
 		}
+
 		return false;
 	}
 
-	public boolean isChange() {
-
-		boolean isOverrideTableChange = ((OverrideEmbeddableAttributeTableModel) view.getOverrideAttributeTable()
-				.getModel()).isAttributeOverrideChange();
+	public boolean isModified() {
+		boolean isOverrideTableChange =
+				((OverrideEmbeddableAttributeTableModel) view.getOverrideAttributeTable().getModel())
+						.isAttributeOverrideChange();
+		String comment = ObjectInfo
+				.getFromMetaData(mediator.getApplication().getMetaData(), attribute, ObjectInfo.COMMENT);
 		return isOverrideTableChange
 				|| !attribute.getName().equals(view.getAttributeName().getText())
 				|| (attribute.getType() == null && view.getTypeComboBox().getSelectedItem() != null)
-				|| !Objects.equals(attribute.getType(), view.getTypeComboBox().getSelectedItem());
+				|| !Objects.equals(attribute.getType(), view.getTypeComboBox().getSelectedItem())
+				|| attribute.isUsedForLocking() != view.getUsedForLockingCheckBox().isSelected()
+				|| attribute.isLazy() != view.getLazyCheckBox().isSelected()
+				|| !Objects.equals(comment, view.getCommentField().getText());
+	}
+
+	private void updateTable() {
+		String comment = ObjectInfo
+				.getFromMetaData(mediator.getApplication().getMetaData(), attributeSaved, ObjectInfo.COMMENT);
+		model.setUpdatedValueAt(attributeSaved.getName(), row, 0);
+		model.setUpdatedValueAt(attributeSaved.getType(), row, 1);
+		model.setUpdatedValueAt(attributeSaved.isUsedForLocking(), row, 4);
+		model.setUpdatedValueAt(attributeSaved.isLazy(), row, 5);
+		model.setUpdatedValueAt(comment, row, 6);
 	}
 
 	public void saveMapping() {
-
  		if (setPath(false)) {
-
 			if (JOptionPane.showConfirmDialog(getView(),
 					"You have changed Db Attribute path. Do you want it to be saved?", "Save ObjAttribute",
 					JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION) {
@@ -429,14 +478,12 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 				if (attribute instanceof EmbeddedAttribute) {
 					changeAttributeObject();
 				} else {
-					model.setUpdatedValueAt(attributeSaved.getName(), row, 0);
-					model.setUpdatedValueAt(attributeSaved.getType(), row, 1);
+					updateTable();
 				}
 
 				model.setUpdatedValueAt(attributeSaved.getDbAttributePath(), row, 2);
 			} else {
-				model.setUpdatedValueAt(attributeSaved.getName(), row, 0);
-				model.setUpdatedValueAt(attributeSaved.getType(), row, 1);
+				updateTable();
 			}
 		} else {
 			if ((attributeSaved instanceof EmbeddedAttribute && !(attribute instanceof EmbeddedAttribute))
@@ -450,8 +497,7 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 					compareAndSetOverrideInEmbeddedAttribute(attributeSaved, overrides, currentOverrAttr);
 				}
 
-				model.setUpdatedValueAt(attributeSaved.getName(), row, 0);
-				model.setUpdatedValueAt(attributeSaved.getType(), row, 1);
+				updateTable();
 				model.setUpdatedValueAt(attributeSaved.getDbAttributePath(), row, 2);
 			}
 
@@ -503,17 +549,17 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 	}
 
 	public Map<String, String> getCurrentOverrideAttribute() {
-		Map<String, String> currentEmbeddableOverrite = new HashMap<>();
+		Map<String, String> currentEmbeddableOverride = new HashMap<>();
 		Collection<EmbeddableAttribute> embList = embeddableModel.getEmbeddableList();
 		Embeddable emb = stringToEmbeddables.get(attributeSaved.getType());
 		for (EmbeddableAttribute e : embList) {
 			if ((emb.getAttribute(e.getName()).getDbAttributeName() == null && e.getDbAttributeName() != null)
 					|| (emb.getAttribute(e.getName()).getDbAttributeName() != null && !emb.getAttribute(e.getName())
 					.getDbAttributeName().equals(e.getDbAttributeName()))) {
-				currentEmbeddableOverrite.put(e.getName(), e.getDbAttributeName());
+				currentEmbeddableOverride.put(e.getName(), e.getDbAttributeName());
 			}
 		}
-		return currentEmbeddableOverrite;
+		return currentEmbeddableOverride;
 	}
 
 	public void valueChanged(TreeSelectionEvent e) {
@@ -564,19 +610,18 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 		}
 	}
 
-	public boolean isRegistredType(String typeName) {
-		boolean isType = false;
+	public boolean isRegisteredType(String typeName) {
 		String[] typeNames = ModelerUtil.getRegisteredTypeNames();
 		for (String nextTypeName : typeNames) {
 			if (nextTypeName.equals(typeName)) {
-				isType = true;
+				return true;
 			}
 		}
-		return isType;
+		return false;
 	}
 
 	// custom renderer used for inherited attributes highlighting
-	final class CellRenderer extends DefaultTableCellRenderer {
+	static final class CellRenderer extends DefaultTableCellRenderer {
 
 		@Override
 		public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected,
@@ -604,6 +649,15 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 		attributeSaved.setParent(attribute.getParent());
 		attributeSaved.setType(attribute.getType());
 		attributeSaved.setUsedForLocking(attribute.isUsedForLocking());
+		attributeSaved.setLazy(attribute.isLazy());
+		String comment = ObjectInfo
+				.getFromMetaData(mediator.getApplication().getMetaData(),
+						attribute,
+						ObjectInfo.COMMENT);
+		ObjectInfo.putToMetaData(mediator.getApplication().getMetaData(),
+				attributeSaved,
+				ObjectInfo.COMMENT,
+				comment);
 
 		if (attributeSaved instanceof EmbeddedAttribute) {
 			Map<String, String> attrOverrides;
@@ -620,23 +674,21 @@ public class ObjAttributeInfoDialog extends CayenneController implements TreeSel
 		}
 	}
 
-	private void compareAndSetOverrideInEmbeddedAttribute(ObjAttribute attribute, Map<String, String> overrides,
-			Map<String, String> currentOverrAttr) {
+	private void compareAndSetOverrideInEmbeddedAttribute(ObjAttribute attribute,
+														  Map<String, String> overrides,
+														  Map<String, String> currentOverrAttr) {
 		ArrayList<String> keysForDelete = new ArrayList<>();
 		ArrayList<String> keysForAdd = new ArrayList<>();
 
-		for (Object o : overrides.entrySet()) {
-			Map.Entry obj = (Map.Entry) o;
-
-			String key = (String) obj.getKey();
+		for (Map.Entry<String, String> obj : overrides.entrySet()) {
+			String key = obj.getKey();
 			if (currentOverrAttr.get(key) == null || !(obj.getValue().equals(currentOverrAttr.get(key)))) {
 				keysForDelete.add(key);
 			}
 		}
 
-		for (Object o : currentOverrAttr.entrySet()) {
-			Map.Entry obj = (Map.Entry) o;
-			String key = (String) obj.getKey();
+		for (Map.Entry<String, String> obj : currentOverrAttr.entrySet()) {
+			String key = obj.getKey();
 			if (overrides.get(key) == null || !(obj.getValue().equals(overrides.get(key)))) {
 				keysForAdd.add(key);
 			}
