@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -57,15 +57,11 @@ public class ObjEntityCallbackMethodsTab extends AbstractCallbackMethodsTab  {
                 }
         );
 
-        mediator.addObjEntityDisplayListener(
-                new ObjEntityDisplayListener() {
-                    public void currentObjEntityChanged(EntityDisplayEvent e) {
-                        if (ObjEntityCallbackMethodsTab.this.isVisible()) {
-                            rebuildTables();
-                        }
-                    }
-                }
-        );
+        mediator.addObjEntityDisplayListener(e -> {
+            if (ObjEntityCallbackMethodsTab.this.isVisible()) {
+                rebuildTables();
+            }
+        });
     }
 
 
