@@ -19,54 +19,47 @@
 
 package org.apache.cayenne.modeler.util;
 
-import java.lang.reflect.Method;
+import java.awt.Desktop;
+import java.net.URI;
 
 /**
  * Opens a URL in the system default browser.
  */
 public class BrowserControl {
-
-    private static final String WIN_PATH = "rundll32";
-    private static final String WIN_FLAG = "url.dll,FileProtocolHandler";
-
     /**
      * Display a file in the system browser. If you want to display a file, you must
      * include the absolute path name.
-     * 
+     *
      * @param url the file's url (the url must start with either "http://" or "file://").
      */
     // see public domain code at
     // http://www.centerkey.com/java/browser/myapp/BareBonesBrowserLaunch.java
     public static void displayURL(String url) {
         try {
-            if (OperatingSystem.getOS() == OperatingSystem.WINDOWS) {
-                // cmd = 'rundll32 url.dll,FileProtocolHandler http://...'
-                String cmd = WIN_PATH + " " + WIN_FLAG + " " + url;
+            // use direct Java support for the Desktop if available
+            if (Desktop.isDesktopSupported() && Desktop.getDesktop().isSupported(Desktop.Action.BROWSE)) {
+                Desktop.getDesktop().browse(new URI(url));
+            // failover to a platform-specific hacks
+            } else if (OperatingSystem.getOS() == OperatingSystem.WINDOWS) {
+                String cmd = "rundll32 url.dll,FileProtocolHandler " + url;
                 Runtime.getRuntime().exec(cmd);
-            }
-            else if (OperatingSystem.getOS() == OperatingSystem.MAC_OS_X) {
-                Class<?> fileManager = Class.forName("com.apple.eio.FileManager");
-                Method openURL = fileManager.getDeclaredMethod("openURL", String.class);
-                openURL.invoke(null, url);
-            }
-            else { // assume Unix or Linux
+            } else if (OperatingSystem.getOS() == OperatingSystem.MAC_OS_X) {
+                String cmd = "open " + url;
+                Runtime.getRuntime().exec(cmd);
+            } else { // assume Unix or Linux
                 String[] browsers = {
-                        "firefox", "opera", "konqueror", "epiphany", "mozilla",
-                        "netscape"
+                        "google-chrome", "firefox", "mozilla",
+                        "epiphany", "konqueror", "netscape",
+                        "opera", "links", "lynx"
                 };
                 for (String browser : browsers) {
-                    if (Runtime.getRuntime().exec(new String[] {
-                            "which", browser
-                    }).waitFor() == 0) {
-                        Runtime.getRuntime().exec(new String[] {
-                                browser, url
-                        });
+                    if (Runtime.getRuntime().exec(new String[]{"which", browser}).waitFor() == 0) {
+                        Runtime.getRuntime().exec(new String[]{browser, url});
                         break;
                     }
                 }
             }
-        }
-        catch (Exception ex) {
+        } catch (Exception ex) {
             // could not open browser. Fail silently.
         }
     }
