@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -21,15 +21,36 @@ package org.apache.cayenne.swing.components;
 
 import org.apache.cayenne.modeler.undo.JCheckBoxUndoListener;
 
-import javax.swing.*;
 import java.awt.event.ActionListener;
+import java.awt.event.ItemListener;
+import javax.swing.JCheckBox;
 
 public class JCayenneCheckBox extends JCheckBox {
 
     private ActionListener actionListener;
+    private boolean modelUpdateDisabled;
 
     public JCayenneCheckBox() {
         this.actionListener = new JCheckBoxUndoListener();
         this.addActionListener(this.actionListener);
     }
+
+    @Override
+    public void setSelected(boolean b) {
+        modelUpdateDisabled = true;
+        try {
+            super.setSelected(b);
+        } finally {
+            modelUpdateDisabled = false;
+        }
+    }
+
+    @Override
+    public void addItemListener(ItemListener l) {
+        super.addItemListener(e -> {
+            if(!modelUpdateDisabled) {
+                l.itemStateChanged(e);
+            }
+        });
+    }
 }
\ No newline at end of file
